<?php
/**
 * Theme sprecific functions and definitions
 */


/* Theme setup section
------------------------------------------------------------------- */

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1170; /* pixels */

// Add theme specific actions and filters
// Attention! Function were add theme specific actions and filters handlers must have priority 1
if ( !function_exists( 'cleaning_services_theme_setup' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_theme_setup', 1 );
	function cleaning_services_theme_setup() {

        // Add default posts and comments RSS feed links to head
        add_theme_support( 'automatic-feed-links' );

        // Enable support for Post Thumbnails
        add_theme_support( 'post-thumbnails' );

        // Custom header setup
        add_theme_support( 'custom-header', array('header-text'=>false));

        // Custom backgrounds setup
        add_theme_support( 'custom-background');

        // Supported posts formats
        add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') );

        // Autogenerate title tag
        add_theme_support('title-tag');

        // Add user menu
        add_theme_support('nav-menus');

        // WooCommerce Support
        add_theme_support( 'woocommerce' );

		// Register theme menus
		add_filter( 'cleaning_services_filter_add_theme_menus',		'cleaning_services_add_theme_menus' );

		// Register theme sidebars
		add_filter( 'cleaning_services_filter_add_theme_sidebars',	'cleaning_services_add_theme_sidebars' );

		// Set Theme required plugins
		add_filter( 'cleaning_services_filter_required_plugins',		'cleaning_services_set_required_plugins', 9 );

		// Set options for importer
		add_filter( 'cleaning_services_filter_importer_options',		'cleaning_services_set_importer_options' );

        // Gutenberg support
        add_theme_support( 'align-wide' );

	}
}


// Add/Remove theme nav menus
if ( !function_exists( 'cleaning_services_add_theme_menus' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_add_theme_menus', 'cleaning_services_add_theme_menus' );
	function cleaning_services_add_theme_menus($menus) {
		return $menus;
	}
}


// Add theme specific widgetized areas
if ( !function_exists( 'cleaning_services_add_theme_sidebars' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_add_theme_sidebars',	'cleaning_services_add_theme_sidebars' );
	function cleaning_services_add_theme_sidebars($sidebars=array()) {
		if (is_array($sidebars)) {
			$theme_sidebars = array(
				'sidebar_main'		=> esc_html__( 'Main Sidebar', 'cleaning-services' ),
				'sidebar_footer'	=> esc_html__( 'Footer Sidebar', 'cleaning-services' )
			);
			if (function_exists('cleaning_services_exists_woocommerce') && cleaning_services_exists_woocommerce()) {
				$theme_sidebars['sidebar_cart']  = esc_html__( 'WooCommerce Cart Sidebar', 'cleaning-services' );
			}
			$sidebars = array_merge($theme_sidebars, $sidebars);
		}
		return $sidebars;
	}
}


// Set theme required plugins
if ( !function_exists( 'cleaning_services_set_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_required_plugins', 'cleaning_services_set_required_plugins', 9, 1 );
	function cleaning_services_set_required_plugins($list=array()) {
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['required_plugins'] = array(
// Attention!
// Plugin Booking Calendar not compatible with bbPress and BuddyPress!
// And it generate notice messages, that break AJAX installer!
// Uncomment it if your theme not use bbPress and BuddyPress
			'booked',
			'calcfields',
			'essgrids',
			'instagram_widget',
			'revslider',
			'trx_utils',
            'woocommerce',
			'visual_composer',
            'contact-form-7',
            'gdpr-compliance'
		);
		return $list;
	}
}

// Add page meta to the head
if (!function_exists('cleaning_services_head_add_page_meta')) {
    add_action('wp_head', 'cleaning_services_head_add_page_meta', 1);
    function cleaning_services_head_add_page_meta() {
        $theme_skin = sanitize_file_name(cleaning_services_get_custom_option('theme_skin'));
        ?>
        <meta charset="<?php bloginfo( 'charset' ); ?>" />
        <meta name="viewport" content="width=device-width, initial-scale=1<?php echo (cleaning_services_get_theme_option('responsive_layouts') == 'yes' ? ', maximum-scale=1' : ''); ?>">
        <meta name="format-detection" content="telephone=no">
        <?php
        if (floatval(get_bloginfo('version')) < 4.1) {
            ?><title><?php wp_title( '|', true, 'right' ); ?></title><?php
        }
        ?>

        <link rel="profile" href="http://gmpg.org/xfn/11" />
        <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />

        <?php
        if ( !function_exists('has_site_icon') || !has_site_icon() ) {
            $favicon = cleaning_services_get_custom_option('favicon');
            if (!$favicon) {
                if ( file_exists(cleaning_services_get_file_dir('skins/'.($theme_skin).'/images/favicon.ico')) )
                    $favicon = cleaning_services_get_file_url('skins/'.($theme_skin).'/images/favicon.ico');
                if ( !$favicon && file_exists(cleaning_services_get_file_dir('favicon.ico')) )
                    $favicon = cleaning_services_get_file_url('favicon.ico');
            }
            if ($favicon) {
                ?><link rel="icon" type="image/x-icon" href="<?php echo esc_url($favicon); ?>" /><?php
            }
        }
    }
}

// Add theme required plugins
if ( !function_exists( 'cleaning_services_add_trx_utils' ) ) {
    add_filter( 'trx_utils_active', 'cleaning_services_add_trx_utils' );
    function cleaning_services_add_trx_utils($enable=true) {
        return true;
    }
}

// Return text for the Privacy Policy checkbox
if ( ! function_exists('cleaning_services_get_privacy_text' ) ) {
    function cleaning_services_get_privacy_text() {
        $page = get_option( 'wp_page_for_privacy_policy' );
        $privacy_text = cleaning_services_get_theme_option( 'privacy_text' );
        return apply_filters( 'cleaning_services_filter_privacy_text', wp_kses_post(
                $privacy_text
                . ( ! empty( $page ) && ! empty( $privacy_text )
                    // Translators: Add url to the Privacy Policy page
                    ? ' ' . sprintf( __( 'For further details on handling user data, see our %s', 'cleaning-services' ),
                        '<a href="' . esc_url( get_permalink( $page ) ) . '" target="_blank">'
                        . __( 'Privacy Policy', 'cleaning-services' )
                        . '</a>' )
                    : ''
                )
            )
        );
    }
}

// Return text for the "I agree ..." checkbox
if ( ! function_exists( 'cleaning_services_trx_addons_privacy_text' ) ) {
    add_filter( 'trx_addons_filter_privacy_text', 'cleaning_services_trx_addons_privacy_text' );
    function cleaning_services_trx_addons_privacy_text( $text='' ) {
        return cleaning_services_get_privacy_text();
    }
}

//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( ! function_exists( 'cleaning_services_importer_set_options' ) ) {
    add_filter( 'trx_utils_filter_importer_options', 'cleaning_services_importer_set_options', 9 );
    function cleaning_services_importer_set_options( $options=array() ) {
        if ( is_array( $options ) ) {
            // Save or not installer's messages to the log-file
            $options['debug'] = false;
            // Prepare demo data
            if ( is_dir( CLEANING_SERVICES_THEME_PATH . 'demo/' ) ) {
                $options['demo_url'] = CLEANING_SERVICES_THEME_PATH . 'demo/';
            } else {
                $options['demo_url'] = esc_url( cleaning_services_get_protocol().'://demofiles.ancorathemes.com/cleaning/' ); // Demo-site domain
            }

            // Required plugins
            $options['required_plugins'] =  array(
                'booked',
                'essential-grid',
                'revslider',
                'calculated-fields-form',
                'js_composer',
                'woocommerce'
            );

            $options['theme_slug'] = 'cleaning_services';

            // Set number of thumbnails to regenerate when its imported (if demo data was zipped without cropped images)
            // Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
            $options['regenerate_thumbnails'] = 3;
            // Default demo
            $options['files']['default']['title'] = esc_html__( 'Cleaning Demo', 'cleaning-services' );
            $options['files']['default']['domain_dev'] = esc_url(cleaning_services_get_protocol().'://cleaning.ancorathemes.com'); // Developers domain
            $options['files']['default']['domain_demo']= esc_url(cleaning_services_get_protocol().'://cleaning.ancorathemes.com'); // Demo-site domain

        }
        return $options;
    }
}


/* Include framework core files
------------------------------------------------------------------- */
// If now is WP Heartbeat call - skip loading theme core files
if (!isset($_POST['action']) || $_POST['action']!="heartbeat") {
	require_once get_template_directory().'/fw/loader.php';
}
?>