<?php
/**
 * Cleaning Services Framework: Admin functions
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

/* Admin actions and filters:
------------------------------------------------------------------------ */

if (is_admin()) {

	/* Theme setup section
	-------------------------------------------------------------------- */
	
	if ( !function_exists( 'cleaning_services_admin_theme_setup' ) ) {
		add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_admin_theme_setup', 11 );
		function cleaning_services_admin_theme_setup() {
			if ( is_admin() ) {
				add_action("admin_footer",			'cleaning_services_admin_prepare_scripts', 9);
				add_action("admin_enqueue_scripts",	'cleaning_services_admin_load_scripts');
				add_action('tgmpa_register',		'cleaning_services_admin_register_plugins');

				// AJAX: Get terms for specified post type
				add_action('wp_ajax_cleaning_services_admin_change_post_type', 		'cleaning_services_callback_admin_change_post_type');
				add_action('wp_ajax_nopriv_cleaning_services_admin_change_post_type','cleaning_services_callback_admin_change_post_type');
			}
		}
	}
	
	// Load required styles and scripts for admin mode
	if ( !function_exists( 'cleaning_services_admin_load_scripts' ) ) {
		//Handler of add_action("admin_enqueue_scripts", 'cleaning_services_admin_load_scripts');
		function cleaning_services_admin_load_scripts() {
            if (cleaning_services_get_theme_option('debug_mode')=='yes') {
			    wp_enqueue_script( 'cleaning-services-debug-script', cleaning_services_get_file_url('js/core.debug.js'), array('jquery'), null, true );
            }
				wp_enqueue_style( 'cleaning-services-admin-style', cleaning_services_get_file_url('css/core.admin.css'), array(), null );
				wp_enqueue_script( 'cleaning-services-admin-script', cleaning_services_get_file_url('js/core.admin.js'), array('jquery'), null, true );
			if (cleaning_services_strpos(add_query_arg(array()), 'widgets.php')!==false) {
				wp_enqueue_style( 'fontello-style', cleaning_services_get_file_url('css/fontello-admin/css/fontello-admin.css'), array(), null );
				wp_enqueue_style( 'animations-style', cleaning_services_get_file_url('css/fontello-admin/css/animation.css'), array(), null );
			}
		}
	}
	
	// Prepare required styles and scripts for admin mode
	if ( !function_exists( 'cleaning_services_admin_prepare_scripts' ) ) {
		//Handler of add_action("admin_head", 'cleaning_services_admin_prepare_scripts');
		function cleaning_services_admin_prepare_scripts() {
            $vars = cleaning_services_storage_get('js_vars');
            if (empty($vars) || !is_array($vars)) $vars = array();
            $vars = array_merge($vars, array(
                'admin_mode' => true,
                'ajax_nonce' => wp_create_nonce(admin_url('admin-ajax.php')),
                'ajax_url' => admin_url('admin-ajax.php'),
                'ajax_error' => esc_html__('Invalid server answer', 'cleaning-services'),
                'user_logged_in' => true
            ));
            wp_localize_script('cleaning-services-admin-script', 'CLEANING_SERVICES_GLOBALS', apply_filters('cleaning_services_action_add_scripts_inline', $vars));
            $code = cleaning_services_storage_get('js_code');
            if (!empty($js_code)) {
                $st = '<';
                $ct = '/';
                $et = '>';
                cleaning_services_show_layout($code, "{$st}script{$et}jQuery(document).ready(function(){", "});{$st}{$ct}script{$et}");
            }
		}
	}
	
	// AJAX: Get terms for specified post type
	if ( !function_exists( 'cleaning_services_callback_admin_change_post_type' ) ) {
		//Handler of add_action('wp_ajax_cleaning_services_admin_change_post_type', 		'cleaning_services_callback_admin_change_post_type');
		//Handler of add_action('wp_ajax_nopriv_cleaning_services_admin_change_post_type',	'cleaning_services_callback_admin_change_post_type');
		function cleaning_services_callback_admin_change_post_type() {
			global $CLEANING_SERVICES_GLOBALS;
			if ( !wp_verify_nonce( $_REQUEST['nonce'], $CLEANING_SERVICES_GLOBALS['ajax_url'] ) )
				die();
			$post_type = $_REQUEST['post_type'];
			$terms = cleaning_services_get_list_terms(false, cleaning_services_get_taxonomy_categories_by_post_type($post_type));
			$terms = cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $terms);
			$response = array(
				'error' => '',
				'data' => array(
					'ids' => array_keys($terms),
					'titles' => array_values($terms)
				)
			);
			echo json_encode($response);
			die();
		}
	}

	// Return current post type in dashboard
	if ( !function_exists( 'cleaning_services_admin_get_current_post_type' ) ) {
		function cleaning_services_admin_get_current_post_type() {
			global $post, $typenow, $current_screen;
			if ( $post && $post->post_type )							//we have a post so we can just get the post type from that
				return $post->post_type;
			else if ( $typenow )										//check the global $typenow — set in admin.php
				return $typenow;
			else if ( $current_screen && $current_screen->post_type )	//check the global $current_screen object — set in sceen.php
				return $current_screen->post_type;
			else if ( isset( $_REQUEST['post_type'] ) )					//check the post_type querystring
				return sanitize_key( $_REQUEST['post_type'] );
			else if ( isset( $_REQUEST['post'] ) ) {					//lastly check the post id querystring
				$post = get_post( sanitize_key( $_REQUEST['post'] ) );
				return !empty($post->post_type) ? $post->post_type : '';
			} else														//we do not know the post type!
				return '';
		}
	}

	// Add admin menu pages
	if ( !function_exists( 'cleaning_services_admin_add_menu_item' ) ) {
		function cleaning_services_admin_add_menu_item($mode, $item, $pos='100') {
			static $shift = 0;
			if ($pos=='100') $pos .= '.'.$shift++;
			$fn = join('_', array('add', $mode, 'page'));
			if (empty($item['parent']))
				$fn($item['page_title'], $item['menu_title'], $item['capability'], $item['menu_slug'], $item['callback'], $item['icon'], $pos);
			else
				$fn($item['parent'], $item['page_title'], $item['menu_title'], $item['capability'], $item['menu_slug'], $item['callback'], $item['icon'], $pos);
		}
	}
	
	// Register optional plugins
	if ( !function_exists( 'cleaning_services_admin_register_plugins' ) ) {
		function cleaning_services_admin_register_plugins() {

			$plugins = apply_filters('cleaning_services_filter_required_plugins', array(
				array(
					'name' 		=> 'Cleaning Services Utilities',
					'slug' 		=> 'trx_utils',
					'version'   => '3.0',
					'source'	=> cleaning_services_get_file_dir('plugins/install/trx_utils.zip'),
					'required' 	=> true
				)
			));
            $config = array(
                'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
                'default_path' => '',                      // Default absolute path to bundled plugins.
                'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
                'has_notices'  => true,                    // Show admin notices or not.
                'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
                'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
                'is_automatic' => true,                    // Automatically activate plugins after installation or not.
                'message'      => ''                       // Message to output right before the plugins table.
            );
	
			tgmpa( $plugins, $config );
		}
	}

	require_once cleaning_services_get_file_dir('lib/tgm/class-tgm-plugin-activation.php');
}

?>