<?php
/**
 * Cleaning Services Framework: return lists
 *
 * @package cleaning_services
 * @since cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }



// Return styles list
if ( !function_exists( 'cleaning_services_get_list_styles' ) ) {
	function cleaning_services_get_list_styles($from=1, $to=2, $prepend_inherit=false) {
		$list = array();
		for ($i=$from; $i<=$to; $i++)
			$list[$i] = sprintf(esc_html__('Style %d', 'cleaning-services'), $i);
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the shortcodes margins
if ( !function_exists( 'cleaning_services_get_list_margins' ) ) {
	function cleaning_services_get_list_margins($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_margins']))
			$list = $CLEANING_SERVICES_GLOBALS['list_margins'];
		else {
			$list = array(
				'null'		=> esc_html__('0 (No margin)',	'cleaning-services'),
				'tiny'		=> esc_html__('Tiny',		'cleaning-services'),
				'small'		=> esc_html__('Small',		'cleaning-services'),
				'medium'	=> esc_html__('Medium',		'cleaning-services'),
				'large'		=> esc_html__('Large',		'cleaning-services'),
				'huge'		=> esc_html__('Huge',		'cleaning-services'),
				'tiny-'		=> esc_html__('Tiny (negative)',	'cleaning-services'),
				'small-'	=> esc_html__('Small (negative)',	'cleaning-services'),
				'medium-'	=> esc_html__('Medium (negative)',	'cleaning-services'),
				'large-'	=> esc_html__('Large (negative)',	'cleaning-services'),
				'huge-'		=> esc_html__('Huge (negative)',	'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_margins'] = $list = apply_filters('cleaning_services_filter_list_margins', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the animations
if ( !function_exists( 'cleaning_services_get_list_animations' ) ) {
	function cleaning_services_get_list_animations($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_animations']))
			$list = $CLEANING_SERVICES_GLOBALS['list_animations'];
		else {
			$list = array(
				'none'			=> esc_html__('- None -',	'cleaning-services'),
				'bounced'		=> esc_html__('Bounced',		'cleaning-services'),
				'flash'			=> esc_html__('Flash',		'cleaning-services'),
				'flip'			=> esc_html__('Flip',		'cleaning-services'),
				'pulse'			=> esc_html__('Pulse',		'cleaning-services'),
				'rubberBand'	=> esc_html__('Rubber Band',	'cleaning-services'),
				'shake'			=> esc_html__('Shake',		'cleaning-services'),
				'swing'			=> esc_html__('Swing',		'cleaning-services'),
				'tada'			=> esc_html__('Tada',		'cleaning-services'),
				'wobble'		=> esc_html__('Wobble',		'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_animations'] = $list = apply_filters('cleaning_services_filter_list_animations', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the line styles
if ( !function_exists( 'cleaning_services_get_list_line_styles' ) ) {
	function cleaning_services_get_list_line_styles($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_line_styles']))
			$list = $CLEANING_SERVICES_GLOBALS['list_line_styles'];
		else {
			$list = array(
				'solid'	=> esc_html__('Solid', 'cleaning-services'),
				'dashed'=> esc_html__('Dashed', 'cleaning-services'),
				'dotted'=> esc_html__('Dotted', 'cleaning-services'),
				'double'=> esc_html__('Double', 'cleaning-services'),
				'image'	=> esc_html__('Image', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_line_styles'] = $list = apply_filters('cleaning_services_filter_list_line_styles', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the enter animations
if ( !function_exists( 'cleaning_services_get_list_animations_in' ) ) {
	function cleaning_services_get_list_animations_in($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_animations_in']))
			$list = $CLEANING_SERVICES_GLOBALS['list_animations_in'];
		else {
			$list = array(
				'none'				=> esc_html__('- None -',			'cleaning-services'),
				'bounceIn'			=> esc_html__('Bounce In',			'cleaning-services'),
				'bounceInUp'		=> esc_html__('Bounce In Up',		'cleaning-services'),
				'bounceInDown'		=> esc_html__('Bounce In Down',		'cleaning-services'),
				'bounceInLeft'		=> esc_html__('Bounce In Left',		'cleaning-services'),
				'bounceInRight'		=> esc_html__('Bounce In Right',	'cleaning-services'),
				'fadeIn'			=> esc_html__('Fade In',			'cleaning-services'),
				'fadeInUp'			=> esc_html__('Fade In Up',			'cleaning-services'),
				'fadeInDown'		=> esc_html__('Fade In Down',		'cleaning-services'),
				'fadeInLeft'		=> esc_html__('Fade In Left',		'cleaning-services'),
				'fadeInRight'		=> esc_html__('Fade In Right',		'cleaning-services'),
				'fadeInUpBig'		=> esc_html__('Fade In Up Big',		'cleaning-services'),
				'fadeInDownBig'		=> esc_html__('Fade In Down Big',	'cleaning-services'),
				'fadeInLeftBig'		=> esc_html__('Fade In Left Big',	'cleaning-services'),
				'fadeInRightBig'	=> esc_html__('Fade In Right Big',	'cleaning-services'),
				'flipInX'			=> esc_html__('Flip In X',			'cleaning-services'),
				'flipInY'			=> esc_html__('Flip In Y',			'cleaning-services'),
				'lightSpeedIn'		=> esc_html__('Light Speed In',		'cleaning-services'),
				'rotateIn'			=> esc_html__('Rotate In',			'cleaning-services'),
				'rotateInUpLeft'	=> esc_html__('Rotate In Down Left','cleaning-services'),
				'rotateInUpRight'	=> esc_html__('Rotate In Up Right',	'cleaning-services'),
				'rotateInDownLeft'	=> esc_html__('Rotate In Up Left',	'cleaning-services'),
				'rotateInDownRight'	=> esc_html__('Rotate In Down Right','cleaning-services'),
				'rollIn'			=> esc_html__('Roll In',			'cleaning-services'),
				'slideInUp'			=> esc_html__('Slide In Up',		'cleaning-services'),
				'slideInDown'		=> esc_html__('Slide In Down',		'cleaning-services'),
				'slideInLeft'		=> esc_html__('Slide In Left',		'cleaning-services'),
				'slideInRight'		=> esc_html__('Slide In Right',		'cleaning-services'),
				'zoomIn'			=> esc_html__('Zoom In',			'cleaning-services'),
				'zoomInUp'			=> esc_html__('Zoom In Up',			'cleaning-services'),
				'zoomInDown'		=> esc_html__('Zoom In Down',		'cleaning-services'),
				'zoomInLeft'		=> esc_html__('Zoom In Left',		'cleaning-services'),
				'zoomInRight'		=> esc_html__('Zoom In Right',		'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_animations_in'] = $list = apply_filters('cleaning_services_filter_list_animations_in', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the out animations
if ( !function_exists( 'cleaning_services_get_list_animations_out' ) ) {
	function cleaning_services_get_list_animations_out($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_animations_out']))
			$list = $CLEANING_SERVICES_GLOBALS['list_animations_out'];
		else {
			$list = array(
				'none'				=> esc_html__('- None -',	'cleaning-services'),
				'bounceOut'			=> esc_html__('Bounce Out',			'cleaning-services'),
				'bounceOutUp'		=> esc_html__('Bounce Out Up',		'cleaning-services'),
				'bounceOutDown'		=> esc_html__('Bounce Out Down',		'cleaning-services'),
				'bounceOutLeft'		=> esc_html__('Bounce Out Left',		'cleaning-services'),
				'bounceOutRight'	=> esc_html__('Bounce Out Right',	'cleaning-services'),
				'fadeOut'			=> esc_html__('Fade Out',			'cleaning-services'),
				'fadeOutUp'			=> esc_html__('Fade Out Up',			'cleaning-services'),
				'fadeOutDown'		=> esc_html__('Fade Out Down',		'cleaning-services'),
				'fadeOutLeft'		=> esc_html__('Fade Out Left',		'cleaning-services'),
				'fadeOutRight'		=> esc_html__('Fade Out Right',		'cleaning-services'),
				'fadeOutUpBig'		=> esc_html__('Fade Out Up Big',		'cleaning-services'),
				'fadeOutDownBig'	=> esc_html__('Fade Out Down Big',	'cleaning-services'),
				'fadeOutLeftBig'	=> esc_html__('Fade Out Left Big',	'cleaning-services'),
				'fadeOutRightBig'	=> esc_html__('Fade Out Right Big',	'cleaning-services'),
				'flipOutX'			=> esc_html__('Flip Out X',			'cleaning-services'),
				'flipOutY'			=> esc_html__('Flip Out Y',			'cleaning-services'),
				'hinge'				=> esc_html__('Hinge Out',			'cleaning-services'),
				'lightSpeedOut'		=> esc_html__('Light Speed Out',		'cleaning-services'),
				'rotateOut'			=> esc_html__('Rotate Out',			'cleaning-services'),
				'rotateOutUpLeft'	=> esc_html__('Rotate Out Down Left',	'cleaning-services'),
				'rotateOutUpRight'	=> esc_html__('Rotate Out Up Right',		'cleaning-services'),
				'rotateOutDownLeft'	=> esc_html__('Rotate Out Up Left',		'cleaning-services'),
				'rotateOutDownRight'=> esc_html__('Rotate Out Down Right',	'cleaning-services'),
				'rollOut'			=> esc_html__('Roll Out',		'cleaning-services'),
				'slideOutUp'		=> esc_html__('Slide Out Up',		'cleaning-services'),
				'slideOutDown'		=> esc_html__('Slide Out Down',	'cleaning-services'),
				'slideOutLeft'		=> esc_html__('Slide Out Left',	'cleaning-services'),
				'slideOutRight'		=> esc_html__('Slide Out Right',	'cleaning-services'),
				'zoomOut'			=> esc_html__('Zoom Out',			'cleaning-services'),
				'zoomOutUp'			=> esc_html__('Zoom Out Up',		'cleaning-services'),
				'zoomOutDown'		=> esc_html__('Zoom Out Down',	'cleaning-services'),
				'zoomOutLeft'		=> esc_html__('Zoom Out Left',	'cleaning-services'),
				'zoomOutRight'		=> esc_html__('Zoom Out Right',	'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_animations_out'] = $list = apply_filters('cleaning_services_filter_list_animations_out', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return classes list for the specified animation
if (!function_exists('cleaning_services_get_animation_classes')) {
	function cleaning_services_get_animation_classes($animation, $speed='normal', $loop='none') {
		return cleaning_services_param_is_off($animation) ? '' : 'animated '.esc_attr($animation).' '.esc_attr($speed).(!cleaning_services_param_is_off($loop) ? ' '.esc_attr($loop) : '');
	}
}


// Return list of categories
if ( !function_exists( 'cleaning_services_get_list_categories' ) ) {
	function cleaning_services_get_list_categories($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_categories']))
			$list = $CLEANING_SERVICES_GLOBALS['list_categories'];
		else {
			$list = array();
			$args = array(
				'type'                     => 'post',
				'child_of'                 => 0,
				'parent'                   => '',
				'orderby'                  => 'name',
				'order'                    => 'ASC',
				'hide_empty'               => 0,
				'hierarchical'             => 1,
				'exclude'                  => '',
				'include'                  => '',
				'number'                   => '',
				'taxonomy'                 => 'category',
				'pad_counts'               => false );
			$taxonomies = get_categories( $args );
			if (is_array($taxonomies) && count($taxonomies) > 0) {
				foreach ($taxonomies as $cat) {
					$list[$cat->term_id] = $cat->name;
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_categories'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of taxonomies
if ( !function_exists( 'cleaning_services_get_list_terms' ) ) {
	function cleaning_services_get_list_terms($prepend_inherit=false, $taxonomy='category') {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_taxonomies_'.($taxonomy)]))
			$list = $CLEANING_SERVICES_GLOBALS['list_taxonomies_'.($taxonomy)];
		else {
			$list = array();
			$args = array(
				'child_of'                 => 0,
				'parent'                   => '',
				'orderby'                  => 'name',
				'order'                    => 'ASC',
				'hide_empty'               => 0,
				'hierarchical'             => 1,
				'exclude'                  => '',
				'include'                  => '',
				'number'                   => '',
				'taxonomy'                 => $taxonomy,
				'pad_counts'               => false );
			$taxonomies = get_terms( $taxonomy, $args );
			if (is_array($taxonomies) && count($taxonomies) > 0) {
				foreach ($taxonomies as $cat) {
					$list[$cat->term_id] = $cat->name;
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_taxonomies_'.($taxonomy)] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list of post's types
if ( !function_exists( 'cleaning_services_get_list_posts_types' ) ) {
	function cleaning_services_get_list_posts_types($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_posts_types']))
			$list = $CLEANING_SERVICES_GLOBALS['list_posts_types'];
		else {
			$list = array();
			// Return only theme inheritance supported post types
			$CLEANING_SERVICES_GLOBALS['list_posts_types'] = $list = apply_filters('cleaning_services_filter_list_post_types', array());
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list post items from any post type and taxonomy
if ( !function_exists( 'cleaning_services_get_list_posts' ) ) {
	function cleaning_services_get_list_posts($prepend_inherit=false, $opt=array()) {
		$opt = array_merge(array(
			'post_type'			=> 'post',
			'post_status'		=> 'publish',
			'taxonomy'			=> 'category',
			'taxonomy_value'	=> '',
			'posts_per_page'	=> -1,
			'orderby'			=> 'post_date',
			'order'				=> 'desc',
			'return'			=> 'id'
			), is_array($opt) ? $opt : array('post_type'=>$opt));

		global $CLEANING_SERVICES_GLOBALS;
		$hash = 'list_posts_'.($opt['post_type']).'_'.($opt['taxonomy']).'_'.($opt['taxonomy_value']).'_'.($opt['orderby']).'_'.($opt['order']).'_'.($opt['return']).'_'.($opt['posts_per_page']);
		if (isset($CLEANING_SERVICES_GLOBALS[$hash]))
			$list = $CLEANING_SERVICES_GLOBALS[$hash];
		else {
			$list = array();
			$list['none'] = esc_html__("- Not selected -", 'cleaning-services');
			$args = array(
				'post_type' => $opt['post_type'],
				'post_status' => $opt['post_status'],
				'posts_per_page' => $opt['posts_per_page'],
				'ignore_sticky_posts' => true,
				'orderby'	=> $opt['orderby'],
				'order'		=> $opt['order']
			);
			if (!empty($opt['taxonomy_value'])) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => $opt['taxonomy'],
						'field' => (int) $opt['taxonomy_value'] > 0 ? 'id' : 'slug',
						'terms' => $opt['taxonomy_value']
					)
				);
			}
			$posts = get_posts( $args );
			if (is_array($posts) && count($posts) > 0) {
				foreach ($posts as $post) {
					$list[$opt['return']=='id' ? $post->ID : $post->post_title] = $post->post_title;
				}
			}
			$CLEANING_SERVICES_GLOBALS[$hash] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of registered users
if ( !function_exists( 'cleaning_services_get_list_users' ) ) {
	function cleaning_services_get_list_users($prepend_inherit=false, $roles=array('administrator', 'editor', 'author', 'contributor', 'shop_manager')) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_users']))
			$list = $CLEANING_SERVICES_GLOBALS['list_users'];
		else {
			$list = array();
			$list['none'] = esc_html__("- Not selected -", 'cleaning-services');
			$args = array(
				'orderby'	=> 'display_name',
				'order'		=> 'ASC' );
			$users = get_users( $args );
			if (is_array($users) && count($users) > 0) {
				foreach ($users as $user) {
					$accept = true;
					if (is_array($user->roles)) {
						if (is_array($user->roles) && count($user->roles) > 0) {
							$accept = false;
							foreach ($user->roles as $role) {
								if (in_array($role, $roles)) {
									$accept = true;
									break;
								}
							}
						}
					}
					if ($accept) $list[$user->user_login] = $user->display_name;
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_users'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return slider engines list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_sliders' ) ) {
	function cleaning_services_get_list_sliders($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_sliders']))
			$list = $CLEANING_SERVICES_GLOBALS['list_sliders'];
		else {
			$list = array(
				'swiper' => esc_html__("Posts slider (Swiper)", 'cleaning-services')
			);
			$CLEANING_SERVICES_GLOBALS['list_sliders'] = $list = apply_filters('cleaning_services_filter_list_sliders', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return slider controls list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_slider_controls' ) ) {
	function cleaning_services_get_list_slider_controls($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_slider_controls']))
			$list = $CLEANING_SERVICES_GLOBALS['list_slider_controls'];
		else {
			$list = array(
				'no'		=> esc_html__('None', 'cleaning-services'),
				'side'		=> esc_html__('Side', 'cleaning-services'),
				'bottom'	=> esc_html__('Bottom', 'cleaning-services'),
				'pagination'=> esc_html__('Pagination', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_slider_controls'] = $list = apply_filters('cleaning_services_filter_list_slider_controls', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return slider controls classes
if ( !function_exists( 'cleaning_services_get_slider_controls_classes' ) ) {
	function cleaning_services_get_slider_controls_classes($controls) {
		if (cleaning_services_param_is_off($controls))	$classes = 'sc_slider_nopagination sc_slider_nocontrols';
		else if ($controls=='bottom')			$classes = 'sc_slider_nopagination sc_slider_controls sc_slider_controls_bottom';
		else if ($controls=='pagination')		$classes = 'sc_slider_pagination sc_slider_pagination_bottom sc_slider_nocontrols';
		else									$classes = 'sc_slider_nopagination sc_slider_controls sc_slider_controls_side';
		return $classes;
	}
}

// Return list with popup engines
if ( !function_exists( 'cleaning_services_get_list_popup_engines' ) ) {
	function cleaning_services_get_list_popup_engines($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_popup_engines']))
			$list = $CLEANING_SERVICES_GLOBALS['list_popup_engines'];
		else {
			$list = array(
				"pretty"	=> esc_html__("Pretty photo", 'cleaning-services'),
				"magnific"	=> esc_html__("Magnific popup", 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_popup_engines'] = $list = apply_filters('cleaning_services_filter_list_popup_engines', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return menus list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_menus' ) ) {
	function cleaning_services_get_list_menus($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_menus']))
			$list = $CLEANING_SERVICES_GLOBALS['list_menus'];
		else {
			$list = array();
			$list['default'] = esc_html__("Default", 'cleaning-services');
			$menus = wp_get_nav_menus();
			if (is_array($menus) && count($menus) > 0) {
				foreach ($menus as $menu) {
					$list[$menu->slug] = $menu->name;
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_menus'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return custom sidebars list, prepended inherit and main sidebars item (if need)
if ( !function_exists( 'cleaning_services_get_list_sidebars' ) ) {
	function cleaning_services_get_list_sidebars($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_sidebars'])) {
			$list = $CLEANING_SERVICES_GLOBALS['list_sidebars'];
		} else {
			$list = isset($CLEANING_SERVICES_GLOBALS['registered_sidebars']) ? $CLEANING_SERVICES_GLOBALS['registered_sidebars'] : array();
			$CLEANING_SERVICES_GLOBALS['list_sidebars'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return sidebars positions
if ( !function_exists( 'cleaning_services_get_list_sidebars_positions' ) ) {
	function cleaning_services_get_list_sidebars_positions($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_sidebars_positions']))
			$list = $CLEANING_SERVICES_GLOBALS['list_sidebars_positions'];
		else {
			$list = array(
				'none'  => esc_html__('Hide',  'cleaning-services'),
				'left'  => esc_html__('Left',  'cleaning-services'),
				'right' => esc_html__('Right', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_sidebars_positions'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return sidebars class
if ( !function_exists( 'cleaning_services_get_sidebar_class' ) ) {
	function cleaning_services_get_sidebar_class() {
		$sb_main = cleaning_services_get_custom_option('show_sidebar_main');
		$sb_outer = cleaning_services_get_custom_option('show_sidebar_outer');
		return (cleaning_services_param_is_off($sb_main) ? 'sidebar_hide' : 'sidebar_show sidebar_'.($sb_main))
				. ' ' . (cleaning_services_param_is_off($sb_outer) ? 'sidebar_outer_hide' : 'sidebar_outer_show sidebar_outer_'.($sb_outer));
	}
}

// Return body styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_body_styles' ) ) {
	function cleaning_services_get_list_body_styles($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_body_styles']))
			$list = $CLEANING_SERVICES_GLOBALS['list_body_styles'];
		else {
			$list = array(
				'boxed'	=> esc_html__('Boxed',		'cleaning-services'),
				'wide'	=> esc_html__('Wide',		'cleaning-services')
				);
			if (cleaning_services_get_theme_setting('allow_fullscreen')) {
				$list['fullwide']	= esc_html__('Fullwide',	'cleaning-services');
				$list['fullscreen']	= esc_html__('Fullscreen',	'cleaning-services');
			}
			$CLEANING_SERVICES_GLOBALS['list_body_styles'] = $list = apply_filters('cleaning_services_filter_list_body_styles', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return skins list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_skins' ) ) {
	function cleaning_services_get_list_skins($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_skins']))
			$list = $CLEANING_SERVICES_GLOBALS['list_skins'];
		else
			$CLEANING_SERVICES_GLOBALS['list_skins'] = $list = cleaning_services_get_list_folders("skins");
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return css-themes list
if ( !function_exists( 'cleaning_services_get_list_themes' ) ) {
	function cleaning_services_get_list_themes($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_themes']))
			$list = $CLEANING_SERVICES_GLOBALS['list_themes'];
		else
			$CLEANING_SERVICES_GLOBALS['list_themes'] = $list = cleaning_services_get_list_files("css/themes");
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return templates list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates' ) ) {
	function cleaning_services_get_list_templates($mode='') {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_'.($mode)]))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_'.($mode)];
		else {
			$list = array();
			if (is_array($CLEANING_SERVICES_GLOBALS['registered_templates']) && count($CLEANING_SERVICES_GLOBALS['registered_templates']) > 0) {
				foreach ($CLEANING_SERVICES_GLOBALS['registered_templates'] as $k=>$v) {
					if ($mode=='' || cleaning_services_strpos($v['mode'], $mode)!==false)
						$list[$k] = !empty($v['icon']) 
									? $v['icon'] 
									: (!empty($v['title']) 
										? $v['title'] 
										: cleaning_services_strtoproper($v['layout'])
										);
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_templates_'.($mode)] = $list;
		}
		return $list;
	}
}

// Return blog styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates_blog' ) ) {
	function cleaning_services_get_list_templates_blog($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_blog']))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_blog'];
		else {
			$list = cleaning_services_get_list_templates('blog');
			$CLEANING_SERVICES_GLOBALS['list_templates_blog'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return blogger styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates_blogger' ) ) {
	function cleaning_services_get_list_templates_blogger($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_blogger']))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_blogger'];
		else {
			$list = cleaning_services_array_merge(cleaning_services_get_list_templates('blogger'), cleaning_services_get_list_templates('blog'));
			$CLEANING_SERVICES_GLOBALS['list_templates_blogger'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return single page styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates_single' ) ) {
	function cleaning_services_get_list_templates_single($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_single']))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_single'];
		else {
			$list = cleaning_services_get_list_templates('single');
			$CLEANING_SERVICES_GLOBALS['list_templates_single'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return header styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates_header' ) ) {
	function cleaning_services_get_list_templates_header($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_header']))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_header'];
		else {
			$list = cleaning_services_get_list_templates('header');
			$CLEANING_SERVICES_GLOBALS['list_templates_header'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return form styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_templates_forms' ) ) {
	function cleaning_services_get_list_templates_forms($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_templates_forms']))
			$list = $CLEANING_SERVICES_GLOBALS['list_templates_forms'];
		else {
			$list = cleaning_services_get_list_templates('forms');
			$CLEANING_SERVICES_GLOBALS['list_templates_forms'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return article styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_article_styles' ) ) {
	function cleaning_services_get_list_article_styles($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_article_styles']))
			$list = $CLEANING_SERVICES_GLOBALS['list_article_styles'];
		else {
			$list = array(
				"boxed"   => esc_html__('Boxed', 'cleaning-services'),
				"stretch" => esc_html__('Stretch', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_article_styles'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return post-formats filters list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_post_formats_filters' ) ) {
	function cleaning_services_get_list_post_formats_filters($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_post_formats_filters']))
			$list = $CLEANING_SERVICES_GLOBALS['list_post_formats_filters'];
		else {
			$list = array(
				"no"      => esc_html__('All posts', 'cleaning-services'),
				"thumbs"  => esc_html__('With thumbs', 'cleaning-services'),
				"reviews" => esc_html__('With reviews', 'cleaning-services'),
				"video"   => esc_html__('With videos', 'cleaning-services'),
				"audio"   => esc_html__('With audios', 'cleaning-services'),
				"gallery" => esc_html__('With galleries', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_post_formats_filters'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return portfolio filters list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_portfolio_filters' ) ) {
	function cleaning_services_get_list_portfolio_filters($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_portfolio_filters']))
			$list = $CLEANING_SERVICES_GLOBALS['list_portfolio_filters'];
		else {
			$list = array(
				"hide"		=> esc_html__('Hide', 'cleaning-services'),
				"tags"		=> esc_html__('Tags', 'cleaning-services'),
				"categories"=> esc_html__('Categories', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_portfolio_filters'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return hover styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_hovers' ) ) {
	function cleaning_services_get_list_hovers($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_hovers']))
			$list = $CLEANING_SERVICES_GLOBALS['list_hovers'];
		else {
			$list = array();
			$list['circle effect1']  = esc_html__('Circle Effect 1',  'cleaning-services');
			$list['circle effect2']  = esc_html__('Circle Effect 2',  'cleaning-services');
			$list['circle effect3']  = esc_html__('Circle Effect 3',  'cleaning-services');
			$list['circle effect4']  = esc_html__('Circle Effect 4',  'cleaning-services');
			$list['circle effect5']  = esc_html__('Circle Effect 5',  'cleaning-services');
			$list['circle effect6']  = esc_html__('Circle Effect 6',  'cleaning-services');
			$list['circle effect7']  = esc_html__('Circle Effect 7',  'cleaning-services');
			$list['circle effect8']  = esc_html__('Circle Effect 8',  'cleaning-services');
			$list['circle effect9']  = esc_html__('Circle Effect 9',  'cleaning-services');
			$list['circle effect10'] = esc_html__('Circle Effect 10',  'cleaning-services');
			$list['circle effect11'] = esc_html__('Circle Effect 11',  'cleaning-services');
			$list['circle effect12'] = esc_html__('Circle Effect 12',  'cleaning-services');
			$list['circle effect13'] = esc_html__('Circle Effect 13',  'cleaning-services');
			$list['circle effect14'] = esc_html__('Circle Effect 14',  'cleaning-services');
			$list['circle effect15'] = esc_html__('Circle Effect 15',  'cleaning-services');
			$list['circle effect16'] = esc_html__('Circle Effect 16',  'cleaning-services');
			$list['circle effect17'] = esc_html__('Circle Effect 17',  'cleaning-services');
			$list['circle effect18'] = esc_html__('Circle Effect 18',  'cleaning-services');
			$list['circle effect19'] = esc_html__('Circle Effect 19',  'cleaning-services');
			$list['circle effect20'] = esc_html__('Circle Effect 20',  'cleaning-services');
			$list['square effect1']  = esc_html__('Square Effect 1',  'cleaning-services');
			$list['square effect2']  = esc_html__('Square Effect 2',  'cleaning-services');
			$list['square effect3']  = esc_html__('Square Effect 3',  'cleaning-services');
			$list['square effect5']  = esc_html__('Square Effect 5',  'cleaning-services');
			$list['square effect6']  = esc_html__('Square Effect 6',  'cleaning-services');
			$list['square effect7']  = esc_html__('Square Effect 7',  'cleaning-services');
			$list['square effect8']  = esc_html__('Square Effect 8',  'cleaning-services');
			$list['square effect9']  = esc_html__('Square Effect 9',  'cleaning-services');
			$list['square effect10'] = esc_html__('Square Effect 10',  'cleaning-services');
			$list['square effect11'] = esc_html__('Square Effect 11',  'cleaning-services');
			$list['square effect12'] = esc_html__('Square Effect 12',  'cleaning-services');
			$list['square effect13'] = esc_html__('Square Effect 13',  'cleaning-services');
			$list['square effect14'] = esc_html__('Square Effect 14',  'cleaning-services');
			$list['square effect15'] = esc_html__('Square Effect 15',  'cleaning-services');
			$list['square effect_dir']   = esc_html__('Square Effect Dir',   'cleaning-services');
			$list['square effect_shift'] = esc_html__('Square Effect Shift', 'cleaning-services');
			$list['square effect_book']  = esc_html__('Square Effect Book',  'cleaning-services');
			$list['square effect_more']  = esc_html__('Square Effect More',  'cleaning-services');
			$list['square effect_fade']  = esc_html__('Square Effect Fade',  'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_hovers'] = $list = apply_filters('cleaning_services_filter_portfolio_hovers', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the blog counters
if ( !function_exists( 'cleaning_services_get_list_blog_counters' ) ) {
	function cleaning_services_get_list_blog_counters($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_blog_counters']))
			$list = $CLEANING_SERVICES_GLOBALS['list_blog_counters'];
		else {
			$list = array(
				'views'		=> esc_html__('Views', 'cleaning-services'),
				'likes'		=> esc_html__('Likes', 'cleaning-services'),
				'rating'	=> esc_html__('Rating', 'cleaning-services'),
				'comments'	=> esc_html__('Comments', 'cleaning-services')
				);
			$CLEANING_SERVICES_GLOBALS['list_blog_counters'] = $list = apply_filters('cleaning_services_filter_list_blog_counters', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list of the item sizes for the portfolio alter style, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_alter_sizes' ) ) {
	function cleaning_services_get_list_alter_sizes($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_alter_sizes']))
			$list = $CLEANING_SERVICES_GLOBALS['list_alter_sizes'];
		else {
			$list = array(
					'1_1' => esc_html__('1x1', 'cleaning-services'),
					'1_2' => esc_html__('1x2', 'cleaning-services'),
					'2_1' => esc_html__('2x1', 'cleaning-services'),
					'2_2' => esc_html__('2x2', 'cleaning-services'),
					'1_3' => esc_html__('1x3', 'cleaning-services'),
					'2_3' => esc_html__('2x3', 'cleaning-services'),
					'3_1' => esc_html__('3x1', 'cleaning-services'),
					'3_2' => esc_html__('3x2', 'cleaning-services'),
					'3_3' => esc_html__('3x3', 'cleaning-services')
					);
			$CLEANING_SERVICES_GLOBALS['list_alter_sizes'] = $list = apply_filters('cleaning_services_filter_portfolio_alter_sizes', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return extended hover directions list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_hovers_directions' ) ) {
	function cleaning_services_get_list_hovers_directions($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_hovers_directions']))
			$list = $CLEANING_SERVICES_GLOBALS['list_hovers_directions'];
		else {
			$list = array();
			$list['left_to_right'] = esc_html__('Left to Right',  'cleaning-services');
			$list['right_to_left'] = esc_html__('Right to Left',  'cleaning-services');
			$list['top_to_bottom'] = esc_html__('Top to Bottom',  'cleaning-services');
			$list['bottom_to_top'] = esc_html__('Bottom to Top',  'cleaning-services');
			$list['scale_up']      = esc_html__('Scale Up',  'cleaning-services');
			$list['scale_down']    = esc_html__('Scale Down',  'cleaning-services');
			$list['scale_down_up'] = esc_html__('Scale Down-Up',  'cleaning-services');
			$list['from_left_and_right'] = esc_html__('From Left and Right',  'cleaning-services');
			$list['from_top_and_bottom'] = esc_html__('From Top and Bottom',  'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_hovers_directions'] = $list = apply_filters('cleaning_services_filter_portfolio_hovers_directions', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the label positions in the custom forms
if ( !function_exists( 'cleaning_services_get_list_label_positions' ) ) {
	function cleaning_services_get_list_label_positions($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_label_positions']))
			$list = $CLEANING_SERVICES_GLOBALS['list_label_positions'];
		else {
			$list = array();
			$list['top']	= esc_html__('Top',		'cleaning-services');
			$list['bottom']	= esc_html__('Bottom',		'cleaning-services');
			$list['left']	= esc_html__('Left',		'cleaning-services');
			$list['over']	= esc_html__('Over',		'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_label_positions'] = $list = apply_filters('cleaning_services_filter_label_positions', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the bg image positions
if ( !function_exists( 'cleaning_services_get_list_bg_image_positions' ) ) {
	function cleaning_services_get_list_bg_image_positions($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_bg_image_positions']))
			$list = $CLEANING_SERVICES_GLOBALS['list_bg_image_positions'];
		else {
			$list = array();
			$list['left top']	  = esc_html__('Left Top', 'cleaning-services');
			$list['center top']   = esc_html__("Center Top", 'cleaning-services');
			$list['right top']    = esc_html__("Right Top", 'cleaning-services');
			$list['left center']  = esc_html__("Left Center", 'cleaning-services');
			$list['center center']= esc_html__("Center Center", 'cleaning-services');
			$list['right center'] = esc_html__("Right Center", 'cleaning-services');
			$list['left bottom']  = esc_html__("Left Bottom", 'cleaning-services');
			$list['center bottom']= esc_html__("Center Bottom", 'cleaning-services');
			$list['right bottom'] = esc_html__("Right Bottom", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_bg_image_positions'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the bg image repeat
if ( !function_exists( 'cleaning_services_get_list_bg_image_repeats' ) ) {
	function cleaning_services_get_list_bg_image_repeats($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_bg_image_repeats']))
			$list = $CLEANING_SERVICES_GLOBALS['list_bg_image_repeats'];
		else {
			$list = array();
			$list['repeat']	  = esc_html__('Repeat', 'cleaning-services');
			$list['repeat-x'] = esc_html__('Repeat X', 'cleaning-services');
			$list['repeat-y'] = esc_html__('Repeat Y', 'cleaning-services');
			$list['no-repeat']= esc_html__('No Repeat', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_bg_image_repeats'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the bg image attachment
if ( !function_exists( 'cleaning_services_get_list_bg_image_attachments' ) ) {
	function cleaning_services_get_list_bg_image_attachments($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_bg_image_attachments']))
			$list = $CLEANING_SERVICES_GLOBALS['list_bg_image_attachments'];
		else {
			$list = array();
			$list['scroll']	= esc_html__('Scroll', 'cleaning-services');
			$list['fixed']	= esc_html__('Fixed', 'cleaning-services');
			$list['local']	= esc_html__('Local', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_bg_image_attachments'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}


// Return list of the bg tints
if ( !function_exists( 'cleaning_services_get_list_bg_tints' ) ) {
	function cleaning_services_get_list_bg_tints($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_bg_tints']))
			$list = $CLEANING_SERVICES_GLOBALS['list_bg_tints'];
		else {
			$list = array();
			$list['white']	= esc_html__('White', 'cleaning-services');
			$list['light']	= esc_html__('Light', 'cleaning-services');
			$list['dark']	= esc_html__('Dark', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_bg_tints'] = $list = apply_filters('cleaning_services_filter_bg_tints', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return custom fields types list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_field_types' ) ) {
	function cleaning_services_get_list_field_types($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_field_types']))
			$list = $CLEANING_SERVICES_GLOBALS['list_field_types'];
		else {
			$list = array();
			$list['text']     = esc_html__('Text',  'cleaning-services');
			$list['textarea'] = esc_html__('Text Area','cleaning-services');
			$list['password'] = esc_html__('Password',  'cleaning-services');
			$list['radio']    = esc_html__('Radio',  'cleaning-services');
			$list['checkbox'] = esc_html__('Checkbox',  'cleaning-services');
			$list['select']   = esc_html__('Select',  'cleaning-services');
			$list['date']     = esc_html__('Date','cleaning-services');
			$list['time']     = esc_html__('Time','cleaning-services');
			$list['button']   = esc_html__('Button','cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_field_types'] = $list = apply_filters('cleaning_services_filter_field_types', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return Google map styles
if ( !function_exists( 'cleaning_services_get_list_googlemap_styles' ) ) {
	function cleaning_services_get_list_googlemap_styles($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_googlemap_styles']))
			$list = $CLEANING_SERVICES_GLOBALS['list_googlemap_styles'];
		else {
			$list = array();
			$list['default'] = esc_html__('Default', 'cleaning-services');
			$list['simple'] = esc_html__('Simple', 'cleaning-services');
			$list['greyscale'] = esc_html__('Greyscale', 'cleaning-services');
			$list['greyscale2'] = esc_html__('Greyscale 2', 'cleaning-services');
			$list['invert'] = esc_html__('Invert', 'cleaning-services');
			$list['dark'] = esc_html__('Dark', 'cleaning-services');
			$list['style1'] = esc_html__('Custom style 1', 'cleaning-services');
			$list['style2'] = esc_html__('Custom style 2', 'cleaning-services');
			$list['style3'] = esc_html__('Custom style 3', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_googlemap_styles'] = $list = apply_filters('cleaning_services_filter_googlemap_styles', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return iconed classes list
if ( !function_exists( 'cleaning_services_get_list_icons' ) ) {
	function cleaning_services_get_list_icons($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_icons']))
			$list = $CLEANING_SERVICES_GLOBALS['list_icons'];
		else
			$CLEANING_SERVICES_GLOBALS['list_icons'] = $list = cleaning_services_parse_icons_classes(cleaning_services_get_file_dir("css/fontello/css/fontello-codes.css"));
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return socials list
if ( !function_exists( 'cleaning_services_get_list_socials' ) ) {
	function cleaning_services_get_list_socials($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_socials']))
			$list = $CLEANING_SERVICES_GLOBALS['list_socials'];
		else
			$CLEANING_SERVICES_GLOBALS['list_socials'] = $list = cleaning_services_get_list_files("images/socials", "png");
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return flags list
if ( !function_exists( 'cleaning_services_get_list_flags' ) ) {
	function cleaning_services_get_list_flags($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_flags']))
			$list = $CLEANING_SERVICES_GLOBALS['list_flags'];
		else
			$CLEANING_SERVICES_GLOBALS['list_flags'] = $list = cleaning_services_get_list_files("images/flags", "png");
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with 'Yes' and 'No' items
if ( !function_exists( 'cleaning_services_get_list_yesno' ) ) {
	function cleaning_services_get_list_yesno($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_yesno']))
			$list = $CLEANING_SERVICES_GLOBALS['list_yesno'];
		else {
			$list = array();
			$list["yes"] = esc_html__("Yes", 'cleaning-services');
			$list["no"]  = esc_html__("No", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_yesno'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with 'On' and 'Of' items
if ( !function_exists( 'cleaning_services_get_list_onoff' ) ) {
	function cleaning_services_get_list_onoff($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_onoff']))
			$list = $CLEANING_SERVICES_GLOBALS['list_onoff'];
		else {
			$list = array();
			$list["on"] = esc_html__("On", 'cleaning-services');
			$list["off"] = esc_html__("Off", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_onoff'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with 'Show' and 'Hide' items
if ( !function_exists( 'cleaning_services_get_list_showhide' ) ) {
	function cleaning_services_get_list_showhide($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_showhide']))
			$list = $CLEANING_SERVICES_GLOBALS['list_showhide'];
		else {
			$list = array();
			$list["show"] = esc_html__("Show", 'cleaning-services');
			$list["hide"] = esc_html__("Hide", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_showhide'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with 'Ascending' and 'Descending' items
if ( !function_exists( 'cleaning_services_get_list_orderings' ) ) {
	function cleaning_services_get_list_orderings($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_orderings']))
			$list = $CLEANING_SERVICES_GLOBALS['list_orderings'];
		else {
			$list = array();
			$list["asc"] = esc_html__("Ascending", 'cleaning-services');
			$list["desc"] = esc_html__("Descending", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_orderings'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with 'Horizontal' and 'Vertical' items
if ( !function_exists( 'cleaning_services_get_list_directions' ) ) {
	function cleaning_services_get_list_directions($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_directions']))
			$list = $CLEANING_SERVICES_GLOBALS['list_directions'];
		else {
			$list = array();
			$list["horizontal"] = esc_html__("Horizontal", 'cleaning-services');
			$list["vertical"] = esc_html__("Vertical", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_directions'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with item's shapes
if ( !function_exists( 'cleaning_services_get_list_shapes' ) ) {
	function cleaning_services_get_list_shapes($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_shapes']))
			$list = $CLEANING_SERVICES_GLOBALS['list_shapes'];
		else {
			$list = array();
			$list["round"]  = esc_html__("Round", 'cleaning-services');
			$list["square"] = esc_html__("Square", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_shapes'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with item's sizes
if ( !function_exists( 'cleaning_services_get_list_sizes' ) ) {
	function cleaning_services_get_list_sizes($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_sizes']))
			$list = $CLEANING_SERVICES_GLOBALS['list_sizes'];
		else {
			$list = array();
			$list["tiny"]   = esc_html__("Tiny", 'cleaning-services');
			$list["small"]  = esc_html__("Small", 'cleaning-services');
			$list["medium"] = esc_html__("Medium", 'cleaning-services');
			$list["large"]  = esc_html__("Large", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_sizes'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with float items
if ( !function_exists( 'cleaning_services_get_list_floats' ) ) {
	function cleaning_services_get_list_floats($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_floats']))
			$list = $CLEANING_SERVICES_GLOBALS['list_floats'];
		else {
			$list = array();
			$list["none"] = esc_html__("None", 'cleaning-services');
			$list["left"] = esc_html__("Float Left", 'cleaning-services');
			$list["right"] = esc_html__("Float Right", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_floats'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with alignment items
if ( !function_exists( 'cleaning_services_get_list_alignments' ) ) {
	function cleaning_services_get_list_alignments($justify=false, $prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_alignments']))
			$list = $CLEANING_SERVICES_GLOBALS['list_alignments'];
		else {
			$list = array();
			$list["none"] = esc_html__("None", 'cleaning-services');
			$list["left"] = esc_html__("Left", 'cleaning-services');
			$list["center"] = esc_html__("Center", 'cleaning-services');
			$list["right"] = esc_html__("Right", 'cleaning-services');
			if ($justify) $list["justify"] = esc_html__("Justify", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_alignments'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return sorting list items
if ( !function_exists( 'cleaning_services_get_list_sortings' ) ) {
	function cleaning_services_get_list_sortings($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_sortings']))
			$list = $CLEANING_SERVICES_GLOBALS['list_sortings'];
		else {
			$list = array();
			$list["date"] = esc_html__("Date", 'cleaning-services');
			$list["title"] = esc_html__("Alphabetically", 'cleaning-services');
			$list["views"] = esc_html__("Popular (views count)", 'cleaning-services');
			$list["comments"] = esc_html__("Most commented (comments count)", 'cleaning-services');
			$list["author_rating"] = esc_html__("Author rating", 'cleaning-services');
			$list["users_rating"] = esc_html__("Visitors (users) rating", 'cleaning-services');
			$list["random"] = esc_html__("Random", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_sortings'] = $list = apply_filters('cleaning_services_filter_list_sortings', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list with columns widths
if ( !function_exists( 'cleaning_services_get_list_columns' ) ) {
	function cleaning_services_get_list_columns($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_columns']))
			$list = $CLEANING_SERVICES_GLOBALS['list_columns'];
		else {
			$list = array();
			$list["none"] = esc_html__("None", 'cleaning-services');
			$list["1_1"] = esc_html__("100%", 'cleaning-services');
			$list["1_2"] = esc_html__("1/2", 'cleaning-services');
			$list["1_3"] = esc_html__("1/3", 'cleaning-services');
			$list["2_3"] = esc_html__("2/3", 'cleaning-services');
			$list["1_4"] = esc_html__("1/4", 'cleaning-services');
			$list["3_4"] = esc_html__("3/4", 'cleaning-services');
			$list["1_5"] = esc_html__("1/5", 'cleaning-services');
			$list["2_5"] = esc_html__("2/5", 'cleaning-services');
			$list["3_5"] = esc_html__("3/5", 'cleaning-services');
			$list["4_5"] = esc_html__("4/5", 'cleaning-services');
			$list["1_6"] = esc_html__("1/6", 'cleaning-services');
			$list["5_6"] = esc_html__("5/6", 'cleaning-services');
			$list["1_7"] = esc_html__("1/7", 'cleaning-services');
			$list["2_7"] = esc_html__("2/7", 'cleaning-services');
			$list["3_7"] = esc_html__("3/7", 'cleaning-services');
			$list["4_7"] = esc_html__("4/7", 'cleaning-services');
			$list["5_7"] = esc_html__("5/7", 'cleaning-services');
			$list["6_7"] = esc_html__("6/7", 'cleaning-services');
			$list["1_8"] = esc_html__("1/8", 'cleaning-services');
			$list["3_8"] = esc_html__("3/8", 'cleaning-services');
			$list["5_8"] = esc_html__("5/8", 'cleaning-services');
			$list["7_8"] = esc_html__("7/8", 'cleaning-services');
			$list["1_9"] = esc_html__("1/9", 'cleaning-services');
			$list["2_9"] = esc_html__("2/9", 'cleaning-services');
			$list["4_9"] = esc_html__("4/9", 'cleaning-services');
			$list["5_9"] = esc_html__("5/9", 'cleaning-services');
			$list["7_9"] = esc_html__("7/9", 'cleaning-services');
			$list["8_9"] = esc_html__("8/9", 'cleaning-services');
			$list["1_10"]= esc_html__("1/10", 'cleaning-services');
			$list["3_10"]= esc_html__("3/10", 'cleaning-services');
			$list["7_10"]= esc_html__("7/10", 'cleaning-services');
			$list["9_10"]= esc_html__("9/10", 'cleaning-services');
			$list["1_11"]= esc_html__("1/11", 'cleaning-services');
			$list["2_11"]= esc_html__("2/11", 'cleaning-services');
			$list["3_11"]= esc_html__("3/11", 'cleaning-services');
			$list["4_11"]= esc_html__("4/11", 'cleaning-services');
			$list["5_11"]= esc_html__("5/11", 'cleaning-services');
			$list["6_11"]= esc_html__("6/11", 'cleaning-services');
			$list["7_11"]= esc_html__("7/11", 'cleaning-services');
			$list["8_11"]= esc_html__("8/11", 'cleaning-services');
			$list["9_11"]= esc_html__("9/11", 'cleaning-services');
			$list["10_11"]= esc_html__("10/11", 'cleaning-services');
			$list["1_12"]= esc_html__("1/12", 'cleaning-services');
			$list["5_12"]= esc_html__("5/12", 'cleaning-services');
			$list["7_12"]= esc_html__("7/12", 'cleaning-services');
			$list["10_12"]= esc_html__("10/12", 'cleaning-services');
			$list["11_12"]= esc_html__("11/12", 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_columns'] = $list = apply_filters('cleaning_services_filter_list_columns', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return list of locations for the dedicated content
if ( !function_exists( 'cleaning_services_get_list_dedicated_locations' ) ) {
	function cleaning_services_get_list_dedicated_locations($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_dedicated_locations']))
			$list = $CLEANING_SERVICES_GLOBALS['list_dedicated_locations'];
		else {
			$list = array();
			$list["default"] = esc_html__('As in the post defined', 'cleaning-services');
			$list["center"]  = esc_html__('Above the text of the post', 'cleaning-services');
			$list["left"]    = esc_html__('To the left the text of the post', 'cleaning-services');
			$list["right"]   = esc_html__('To the right the text of the post', 'cleaning-services');
			$list["alter"]   = esc_html__('Alternates for each post', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_dedicated_locations'] = $list = apply_filters('cleaning_services_filter_list_dedicated_locations', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return post-format name
if ( !function_exists( 'cleaning_services_get_post_format_name' ) ) {
	function cleaning_services_get_post_format_name($format, $single=true) {
		$name = '';
		if ($format=='gallery')		$name = $single ? esc_html__('gallery', 'cleaning-services') : esc_html__('galleries', 'cleaning-services');
		else if ($format=='video')	$name = $single ? esc_html__('video', 'cleaning-services') : esc_html__('videos', 'cleaning-services');
		else if ($format=='audio')	$name = $single ? esc_html__('audio', 'cleaning-services') : esc_html__('audios', 'cleaning-services');
		else if ($format=='image')	$name = $single ? esc_html__('image', 'cleaning-services') : esc_html__('images', 'cleaning-services');
		else if ($format=='quote')	$name = $single ? esc_html__('quote', 'cleaning-services') : esc_html__('quotes', 'cleaning-services');
		else if ($format=='link')	$name = $single ? esc_html__('link', 'cleaning-services') : esc_html__('links', 'cleaning-services');
		else if ($format=='status')	$name = $single ? esc_html__('status', 'cleaning-services') : esc_html__('statuses', 'cleaning-services');
		else if ($format=='aside')	$name = $single ? esc_html__('aside', 'cleaning-services') : esc_html__('asides', 'cleaning-services');
		else if ($format=='chat')	$name = $single ? esc_html__('chat', 'cleaning-services') : esc_html__('chats', 'cleaning-services');
		else						$name = $single ? esc_html__('standard', 'cleaning-services') : esc_html__('standards', 'cleaning-services');
		return apply_filters('cleaning_services_filter_list_post_format_name', $name, $format);
	}
}

// Return post-format icon name (from Fontello library)
if ( !function_exists( 'cleaning_services_get_post_format_icon' ) ) {
	function cleaning_services_get_post_format_icon($format) {
		$icon = 'icon-';
		if ($format=='gallery')		$icon .= 'pictures';
		else if ($format=='video')	$icon .= 'video';
		else if ($format=='audio')	$icon .= 'note';
		else if ($format=='image')	$icon .= 'picture';
		else if ($format=='quote')	$icon .= 'quote';
		else if ($format=='link')	$icon .= 'link';
		else if ($format=='status')	$icon .= 'comment';
		else if ($format=='aside')	$icon .= 'doc-text';
		else if ($format=='chat')	$icon .= 'chat';
		else						$icon .= 'book-open';
		return apply_filters('cleaning_services_filter_list_post_format_icon', $icon, $format);
	}
}

// Return fonts styles list, prepended inherit
if ( !function_exists( 'cleaning_services_get_list_fonts_styles' ) ) {
	function cleaning_services_get_list_fonts_styles($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_fonts_styles']))
			$list = $CLEANING_SERVICES_GLOBALS['list_fonts_styles'];
		else {
			$list = array();
			$list['i'] = esc_html__('I','cleaning-services');
			$list['u'] = esc_html__('U', 'cleaning-services');
			$CLEANING_SERVICES_GLOBALS['list_fonts_styles'] = $list;
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return Google fonts list
if ( !function_exists( 'cleaning_services_get_list_fonts' ) ) {
	function cleaning_services_get_list_fonts($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_fonts']))
			$list = $CLEANING_SERVICES_GLOBALS['list_fonts'];
		else {
			$list = array();
			$list = cleaning_services_array_merge($list, cleaning_services_get_list_font_faces());
			$list['Advent Pro'] = array('family'=>'sans-serif');
			$list['Alegreya Sans'] = array('family'=>'sans-serif');
			$list['Arimo'] = array('family'=>'sans-serif');
			$list['Asap'] = array('family'=>'sans-serif');
			$list['Averia Sans Libre'] = array('family'=>'cursive');
			$list['Averia Serif Libre'] = array('family'=>'cursive');
			$list['Bree Serif'] = array('family'=>'serif',);
			$list['Cabin'] = array('family'=>'sans-serif');
			$list['Cabin Condensed'] = array('family'=>'sans-serif');
			$list['Caudex'] = array('family'=>'serif');
			$list['Comfortaa'] = array('family'=>'cursive');
			$list['Cousine'] = array('family'=>'sans-serif');
			$list['Crimson Text'] = array('family'=>'serif');
			$list['Cuprum'] = array('family'=>'sans-serif');
			$list['Dosis'] = array('family'=>'sans-serif');
			$list['Economica'] = array('family'=>'sans-serif');
			$list['Exo'] = array('family'=>'sans-serif');
			$list['Expletus Sans'] = array('family'=>'cursive');
			$list['Karla'] = array('family'=>'sans-serif');
			$list['Lato'] = array('family'=>'sans-serif');
			$list['Lekton'] = array('family'=>'sans-serif');
			$list['Lobster Two'] = array('family'=>'cursive');
			$list['Maven Pro'] = array('family'=>'sans-serif');
			$list['Merriweather'] = array('family'=>'serif');
			$list['Montserrat'] = array('family'=>'sans-serif');
			$list['Neuton'] = array('family'=>'serif');
			$list['Noticia Text'] = array('family'=>'serif');
			$list['Old Standard TT'] = array('family'=>'serif');
			$list['Open Sans'] = array('family'=>'sans-serif');
			$list['Orbitron'] = array('family'=>'sans-serif');
			$list['Oswald'] = array('family'=>'sans-serif');
			$list['Overlock'] = array('family'=>'cursive');
			$list['Oxygen'] = array('family'=>'sans-serif');
			$list['Philosopher'] = array('family'=>'serif');
			$list['PT Serif'] = array('family'=>'serif');
			$list['Puritan'] = array('family'=>'sans-serif');
			$list['Raleway'] = array('family'=>'sans-serif');
			$list['Roboto'] = array('family'=>'sans-serif');
			$list['Roboto Slab'] = array('family'=>'sans-serif');
			$list['Roboto Condensed'] = array('family'=>'sans-serif');
			$list['Rosario'] = array('family'=>'sans-serif');
			$list['Share'] = array('family'=>'cursive');
			$list['Signika'] = array('family'=>'sans-serif');
			$list['Signika Negative'] = array('family'=>'sans-serif');
			$list['Source Sans Pro'] = array('family'=>'sans-serif');
			$list['Tinos'] = array('family'=>'serif');
			$list['Ubuntu'] = array('family'=>'sans-serif');
			$list['Vollkorn'] = array('family'=>'serif');
			$CLEANING_SERVICES_GLOBALS['list_fonts'] = $list = apply_filters('cleaning_services_filter_list_fonts', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Return Custom font-face list
if ( !function_exists( 'cleaning_services_get_list_font_faces' ) ) {
	function cleaning_services_get_list_font_faces($prepend_inherit=false) {
		static $list = false;
		if (is_array($list)) return $list;
		$list = array();
		$dir = cleaning_services_get_folder_dir("css/font-face");
        if ( is_dir($dir) ) {
            $files = glob(sprintf("%s/*", $dir), GLOB_ONLYDIR);
            if ( is_array($files) ) {
                foreach ($files as $file) {
                    $file_name = basename($file);
                    $pi = pathinfo( ($dir) . '/' . ($file_name) );
                    if ( substr($file_name, 0, 1) == '.' || ! is_dir( ($dir) . '/' . ($file_name) ) )
                        continue;
                    $css = file_exists( ($dir) . '/' . ($file_name) . '/' . ($file_name) . '.css' )
                        ? cleaning_services_get_folder_url("css/font-face/".($file_name).'/'.($file_name).'.css')
                        : (file_exists( ($dir) . '/' . ($file_name) . '/stylesheet.css' )
                            ? cleaning_services_get_folder_url("css/font-face/".($file_name).'/stylesheet.css')
                            : '');
                    if ($css != '')
                        $list[$file_name.' ('.esc_html__('uploaded font', 'cleaning-services').')'] = array('css' => $css);
                }
            }
        }
		return $list;
	}
}
?>