<?php
/**
 * Cleaning Services Framework: Theme options custom fields
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'cleaning_services_options_custom_theme_setup' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_options_custom_theme_setup' );
	function cleaning_services_options_custom_theme_setup() {

		if ( is_admin() ) {
			add_action("admin_enqueue_scripts",	'cleaning_services_options_custom_load_scripts');
		}
		
	}
}

// Load required styles and scripts for custom options fields
if ( !function_exists( 'cleaning_services_options_custom_load_scripts' ) ) {
	//Handler of add_action("admin_enqueue_scripts", 'cleaning_services_options_custom_load_scripts');
	function cleaning_services_options_custom_load_scripts() {
		wp_enqueue_script( 'cleaning-services-options-custom-script',	cleaning_services_get_file_url('core/core.options/js/core.options-custom.js'), array(), null, true );
	}
}


// Show theme specific fields in Post (and Page) options
function cleaning_services_show_custom_field($id, $field, $value) {
	$output = '';
	switch ($field['type']) {
		case 'reviews':
			$output .= '<div class="reviews_block">' . trim(cleaning_services_reviews_get_markup($field, $value, true)) . '</div>';
			break;

		case 'mediamanager':
			wp_enqueue_media( );
			$output .= '<a id="'.esc_attr($id).'" class="button mediamanager"
				data-param="' . esc_attr($id) . '"
				data-choose="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Choose Images', 'cleaning-services') : esc_html__( 'Choose Image', 'cleaning-services')).'"
				data-update="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Add to Gallery', 'cleaning-services') : esc_html__( 'Choose Image', 'cleaning-services')).'"
				data-multiple="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? 'true' : 'false').'"
				data-linked-field="'.esc_attr($field['media_field_id']).'"
				onclick="cleaning_services_show_media_manager(this); return false;"
				>' . (isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Choose Images', 'cleaning-services') : esc_html__( 'Choose Image', 'cleaning-services')) . '</a>';
			break;
	}
	return apply_filters('cleaning_services_filter_show_custom_field', $output, $id, $field, $value);
}
?>