<?php
/**
 * Cleaning Services Framework: strings manipulations
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Check multibyte functions
if ( ! defined( 'CLEANING_SERVICES_MULTIBYTE' ) ) define( 'CLEANING_SERVICES_MULTIBYTE', function_exists('mb_strpos') ? 'UTF-8' : false );

if (!function_exists('cleaning_services_strlen')) {
	function cleaning_services_strlen($text) {
		return CLEANING_SERVICES_MULTIBYTE ? mb_strlen($text) : strlen($text);
	}
}

if (!function_exists('cleaning_services_strpos')) {
	function cleaning_services_strpos($text, $char, $from=0) {
		return CLEANING_SERVICES_MULTIBYTE ? mb_strpos($text, $char, $from) : strpos($text, $char, $from);
	}
}

if (!function_exists('cleaning_services_strrpos')) {
	function cleaning_services_strrpos($text, $char, $from=0) {
		return CLEANING_SERVICES_MULTIBYTE ? mb_strrpos($text, $char, $from) : strrpos($text, $char, $from);
	}
}

if (!function_exists('cleaning_services_substr')) {
	function cleaning_services_substr($text, $from, $len=-999999) {
		if ($len==-999999) { 
			if ($from < 0)
				$len = -$from; 
			else
				$len = cleaning_services_strlen($text)-$from;
		}
		return CLEANING_SERVICES_MULTIBYTE ? mb_substr($text, $from, $len) : substr($text, $from, $len);
	}
}

if (!function_exists('cleaning_services_strtolower')) {
	function cleaning_services_strtolower($text) {
		return CLEANING_SERVICES_MULTIBYTE ? mb_strtolower($text) : strtolower($text);
	}
}

if (!function_exists('cleaning_services_strtoupper')) {
	function cleaning_services_strtoupper($text) {
		return CLEANING_SERVICES_MULTIBYTE ? mb_strtoupper($text) : strtoupper($text);
	}
}

if (!function_exists('cleaning_services_strtoproper')) {
	function cleaning_services_strtoproper($text) { 
		$rez = ''; $last = ' ';
		for ($i=0; $i<cleaning_services_strlen($text); $i++) {
			$ch = cleaning_services_substr($text, $i, 1);
			$rez .= cleaning_services_strpos(' .,:;?!()[]{}+=', $last)!==false ? cleaning_services_strtoupper($ch) : cleaning_services_strtolower($ch);
			$last = $ch;
		}
		return $rez;
	}
}

if (!function_exists('cleaning_services_strrepeat')) {
	function cleaning_services_strrepeat($str, $n) {
		$rez = '';
		for ($i=0; $i<$n; $i++)
			$rez .= $str;
		return $rez;
	}
}

if (!function_exists('cleaning_services_strshort')) {
	function cleaning_services_strshort($str, $maxlength, $add='...') {
		if ($maxlength < 0) 
			return $str;
		if ($maxlength < 1 || $maxlength >= cleaning_services_strlen($str)) 
			return strip_tags($str);
		$str = cleaning_services_substr(strip_tags($str), 0, $maxlength - cleaning_services_strlen($add));
		$ch = cleaning_services_substr($str, $maxlength - cleaning_services_strlen($add), 1);
		if ($ch != ' ') {
			for ($i = cleaning_services_strlen($str) - 1; $i > 0; $i--)
				if (cleaning_services_substr($str, $i, 1) == ' ') break;
			$str = trim(cleaning_services_substr($str, 0, $i));
		}
		if (!empty($str) && cleaning_services_strpos(',.:;-', cleaning_services_substr($str, -1))!==false) $str = cleaning_services_substr($str, 0, -1);
		return ($str) . ($add);
	}
}

// Clear string from spaces, line breaks and tags (only around text)
if (!function_exists('cleaning_services_strclear')) {
	function cleaning_services_strclear($text, $tags=array()) {
		if (empty($text)) return $text;
		if (!is_array($tags)) {
			if ($tags != '')
				$tags = explode($tags, ',');
			else
				$tags = array();
		}
		$text = trim(chop($text));
		if (is_array($tags) && count($tags) > 0) {
			foreach ($tags as $tag) {
				$open  = '<'.esc_attr($tag);
				$close = '</'.esc_attr($tag).'>';
				if (cleaning_services_substr($text, 0, cleaning_services_strlen($open))==$open) {
					$pos = cleaning_services_strpos($text, '>');
					if ($pos!==false) $text = cleaning_services_substr($text, $pos+1);
				}
				if (cleaning_services_substr($text, -cleaning_services_strlen($close))==$close) $text = cleaning_services_substr($text, 0, cleaning_services_strlen($text) - cleaning_services_strlen($close));
				$text = trim(chop($text));
			}
		}
		return $text;
	}
}

// Return slug for the any title string
if (!function_exists('cleaning_services_get_slug')) {
	function cleaning_services_get_slug($title) {
		return cleaning_services_strtolower(str_replace(array('\\','/','-',' ','.'), '_', $title));
	}
}

// Replace macros in the string
if (!function_exists('cleaning_services_strmacros')) {
	function cleaning_services_strmacros($str) {
		return str_replace(array("{{", "}}", "((", "))", "||"), array("<i>", "</i>", "<b>", "</b>", "<br>"), $str);
	}
}

// Unserialize string (try replace \n with \r\n)
if (!function_exists('cleaning_services_unserialize')) {
	function cleaning_services_unserialize($str) {
		if ( is_serialized($str) ) {
			try {
				$data = unserialize($str);
			} catch (Exception $e) {
				dcl($e->getMessage());
				$data = false;
			}
			if ($data===false) {
				try {
					$data = @unserialize(str_replace("\n", "\r\n", $str));
				} catch (Exception $e) {
					dcl($e->getMessage());
					$data = false;
				}
			}
			return $data;
		} else
			return $str;
	}
}
?>