<?php
/**
 * Cleaning Services Framework: templates and thumbs management
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('cleaning_services_templates_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_templates_theme_setup' );
	function cleaning_services_templates_theme_setup() {

		// Add custom thumb sizes into media manager
		add_filter( 'image_size_names_choose', 'cleaning_services_show_thumb_sizes');
	}
}



/* Templates
-------------------------------------------------------------------------------- */

// Add template (layout name)
if (!function_exists('cleaning_services_add_template')) {
	function cleaning_services_add_template($tpl) {
		global $CLEANING_SERVICES_GLOBALS;
		if (empty($tpl['mode']))						$tpl['mode'] = 'blog';
		if (empty($tpl['template']))					$tpl['template'] = $tpl['layout'];
		if (empty($tpl['need_content']))				$tpl['need_content'] = false;
		if (empty($tpl['need_terms']))					$tpl['need_terms'] = false;
		if (empty($tpl['need_columns']))				$tpl['need_columns'] = false;
		if (empty($tpl['need_isotope']))				$tpl['need_isotope'] = false;
		if (!isset($tpl['h_crop']) && isset($tpl['h']))	$tpl['h_crop'] = $tpl['h'];
		if (!isset($CLEANING_SERVICES_GLOBALS['registered_templates'])) $CLEANING_SERVICES_GLOBALS['registered_templates'] = array();
		$CLEANING_SERVICES_GLOBALS['registered_templates'][$tpl['layout']] = $tpl;
		if (!empty($tpl['thumb_title']))
			cleaning_services_add_thumb_sizes( $tpl );
		else 
			$tpl['thumb_title'] = '';
	}
}

// Return template file name
if (!function_exists('cleaning_services_get_template_name')) {
	function cleaning_services_get_template_name($layout_name) {
		global $CLEANING_SERVICES_GLOBALS;
		return $CLEANING_SERVICES_GLOBALS['registered_templates'][$layout_name]['template'];
	}
}

// Return true, if template required content
if (!function_exists('cleaning_services_get_template_property')) {
	function cleaning_services_get_template_property($layout_name, $what) {
		global $CLEANING_SERVICES_GLOBALS;
		return !empty($CLEANING_SERVICES_GLOBALS['registered_templates'][$layout_name][$what]) ? $CLEANING_SERVICES_GLOBALS['registered_templates'][$layout_name][$what] : '';
	}
}

// Return template output function name
if (!function_exists('cleaning_services_get_template_function_name')) {
	function cleaning_services_get_template_function_name($layout_name) {
		global $CLEANING_SERVICES_GLOBALS;
		return 'cleaning_services_template_'.str_replace(array('-', '.'), '_', $CLEANING_SERVICES_GLOBALS['registered_templates'][$layout_name]['template']).'_output';
	}
}


/* Thumbs
-------------------------------------------------------------------------------- */

// Add image dimensions with layout name
if (!function_exists('cleaning_services_add_thumb_sizes')) {
	function cleaning_services_add_thumb_sizes($sizes) {
		global $CLEANING_SERVICES_GLOBALS;
		if (!isset($sizes['h_crop']))		$sizes['h_crop'] =  isset($sizes['h']) ? $sizes['h'] : null;
		if (empty($sizes['thumb_title']))	$sizes['thumb_title'] = cleaning_services_strtoproper($sizes['layout']);
		$thumb_slug = cleaning_services_get_slug($sizes['thumb_title']);
		if (empty($CLEANING_SERVICES_GLOBALS['thumb_sizes'][$thumb_slug])) {
			if (empty($CLEANING_SERVICES_GLOBALS['thumb_sizes'])) $CLEANING_SERVICES_GLOBALS['thumb_sizes'] = array();
			$CLEANING_SERVICES_GLOBALS['thumb_sizes'][$thumb_slug] = $sizes;
			add_image_size( 'cleaning_services-'.$thumb_slug, $sizes['w'], $sizes['h'], $sizes['h']!=null );
			if ($sizes['h']!=$sizes['h_crop']) {
				add_image_size( 'cleaning_services-'.$thumb_slug.'_crop', $sizes['w'], $sizes['h_crop'], true );
			}
		}
	}
}

// Return image dimensions
if (!function_exists('cleaning_services_get_thumb_sizes')) {
	function cleaning_services_get_thumb_sizes($opt) {
		$opt = array_merge(array(
			'layout' => 'excerpt'
		), $opt);
		global $CLEANING_SERVICES_GLOBALS;
		$thumb_slug = empty($CLEANING_SERVICES_GLOBALS['registered_templates'][$opt['layout']]['thumb_title']) ? '' : cleaning_services_get_slug($CLEANING_SERVICES_GLOBALS['registered_templates'][$opt['layout']]['thumb_title']);
		$rez = $thumb_slug ? $CLEANING_SERVICES_GLOBALS['thumb_sizes'][$thumb_slug] : array('w'=>null, 'h'=>null, 'h_crop'=>null);
		return $rez;
	}
}

// Show custom thumb sizes into media manager sizes list
if (!function_exists('cleaning_services_show_thumb_sizes')) {
	function cleaning_services_show_thumb_sizes( $sizes ) {
		global $CLEANING_SERVICES_GLOBALS;
		$thumb_sizes = $CLEANING_SERVICES_GLOBALS['thumb_sizes'];
		if (is_array($thumb_sizes) && count($thumb_sizes) > 0) {
			$rez = array();
			foreach ($thumb_sizes as $k=>$v)
				$rez[$k] = !empty($v['thumb_title']) ? $v['thumb_title'] : $k;
			$sizes = array_merge( $sizes, $rez);
		}
		return $sizes;
	}
}

// AJAX callback: Get attachment url
if ( !function_exists( 'cleaning_services_callback_get_attachment_url' ) ) {
	function cleaning_services_callback_get_attachment_url() {
		global $_REQUEST, $CLEANING_SERVICES_GLOBALS;
		
		if ( !wp_verify_nonce( $_REQUEST['nonce'], $CLEANING_SERVICES_GLOBALS['ajax_url'] ) )
			die();
	
		$response = array('error'=>'');
		
		$id = (int) $_REQUEST['attachment_id'];
		
		$response['data'] = wp_get_attachment_url($id);
		
		echo json_encode($response);
		die();
	}
}
?>