<?php
/**
 * Cleaning Services Framework
 *
 * @package cleaning_services
 * @since cleaning_services 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Framework directory path from theme root
if ( ! defined( 'CLEANING_SERVICES_FW_DIR' ) )		define( 'CLEANING_SERVICES_FW_DIR', '/fw/' );
if ( ! defined( 'CLEANING_SERVICES_THEME_PATH' ) )	define( 'CLEANING_SERVICES_THEME_PATH',	trailingslashit( get_template_directory() ) );
if ( ! defined( 'CLEANING_SERVICES_FW_PATH' ) )		define( 'CLEANING_SERVICES_FW_PATH',		CLEANING_SERVICES_THEME_PATH . CLEANING_SERVICES_FW_DIR . '/' );

// Theme timing
if ( ! defined( 'CLEANING_SERVICES_START_TIME' ) )	define( 'CLEANING_SERVICES_START_TIME', microtime());			// Framework start time
if ( ! defined( 'CLEANING_SERVICES_START_MEMORY' ) )	define( 'CLEANING_SERVICES_START_MEMORY', memory_get_usage());	// Memory usage before core loading

// Global variables storage

$CLEANING_SERVICES_GLOBALS = array(
	'theme_slug'	=> 'cleaning_services',	// Theme slug (used as prefix for theme's functions, text domain, global variables, etc.)
	'page_template'	=> '',			// Storage for current page template name (used in the inheritance system)
    'allowed_tags'	=> array(		// Allowed tags list (with attributes) in translations
    	'b' => array(),
    	'strong' => array(),
    	'i' => array(),
    	'em' => array(),
    	'u' => array(),
    	'a' => array(
			'href' => array(),
			'title' => array(),
			'target' => array(),
			'id' => array(),
			'class' => array()
		),
    	'span' => array(
			'id' => array(),
			'class' => array()
		)
    )	
);

/* Theme setup section
-------------------------------------------------------------------- */
if ( !function_exists( 'cleaning_services_loader_theme_setup' ) ) {
	add_action( 'after_setup_theme', 'cleaning_services_loader_theme_setup', 20 );
	function cleaning_services_loader_theme_setup() {
		
		// Init admin url and nonce
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['admin_url']	= get_admin_url();
		$CLEANING_SERVICES_GLOBALS['admin_nonce']= wp_create_nonce($CLEANING_SERVICES_GLOBALS['admin_url']);
		$CLEANING_SERVICES_GLOBALS['ajax_url']	= admin_url('admin-ajax.php');
		$CLEANING_SERVICES_GLOBALS['ajax_nonce']	= wp_create_nonce($CLEANING_SERVICES_GLOBALS['ajax_url']);

		// Before init theme
		do_action('cleaning_services_action_before_init_theme');

		// Load current values for main theme options
		cleaning_services_load_main_options();

		// Theme core init - only for admin side. In frontend it called from header.php
		if ( is_admin() ) {
			cleaning_services_core_init_theme();
		}
	}
}


/* Include core parts
------------------------------------------------------------------------ */

// Manual load important libraries before load all rest files
// core.strings must be first - we use cleaning_services_str...() in the cleaning_services_get_file_dir()
require_once (file_exists(get_stylesheet_directory().(CLEANING_SERVICES_FW_DIR).'core/core.strings.php') ? get_stylesheet_directory() : get_template_directory()).(CLEANING_SERVICES_FW_DIR).'core/core.strings.php';
// core.files must be first - we use cleaning_services_get_file_dir() to include all rest parts
require_once (file_exists(get_stylesheet_directory().(CLEANING_SERVICES_FW_DIR).'core/core.files.php') ? get_stylesheet_directory() : get_template_directory()).(CLEANING_SERVICES_FW_DIR).'core/core.files.php';

// Include theme variables storage
require_once cleaning_services_get_file_dir('core/core.storage.php');

// Include custom theme files
cleaning_services_autoload_folder( 'includes' );

// Include core files
cleaning_services_autoload_folder( 'core' );

// Include theme-specific plugins and post types
cleaning_services_autoload_folder( 'plugins' );

// Include theme templates
cleaning_services_autoload_folder( 'templates' );
?>