<?php
/* Booked Appointments support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_booked_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_booked_theme_setup', 1 );
	function cleaning_services_booked_theme_setup() {
		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_booked()) {
			add_action('cleaning_services_action_shortcodes_list',				'cleaning_services_booked_reg_shortcodes');
			if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
				add_action('cleaning_services_action_shortcodes_list_vc',		'cleaning_services_booked_reg_shortcodes_vc');
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',			'cleaning_services_booked_importer_set_options' );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_booked_importer_required_plugins');
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_booked_required_plugins' );
		}

	}
}


// Check if plugin installed and activated
if ( !function_exists( 'cleaning_services_exists_booked' ) ) {
	function cleaning_services_exists_booked() {
		return class_exists('booked_plugin');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_booked_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_booked_required_plugins');
	function cleaning_services_booked_required_plugins($list=array()) {
		global $CLEANING_SERVICES_GLOBALS;
		if (in_array('booked', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
				'name' 		=> 'Booked',
				'slug' 		=> 'booked',
				'source'	=> cleaning_services_get_file_dir('plugins/install/booked.zip'),
				'required' 	=> false
			);
        $path = cleaning_services_get_file_dir( 'plugins/install/booked-calendar-feeds.zip' );
        if ( !empty($path) && file_exists($path) ) {
            $list[] = array(
                'name'     => esc_html__( 'Booked Calendar Feeds', 'cleaning-services' ),
                'slug'     => 'booked-calendar-feeds',
                'source'   => $path,
                'version'  => '1.1.5',
                'required' => false,
            );
        }
        $path = cleaning_services_get_file_dir( 'plugins/install/booked-frontend-agents.zip' );
        if ( !empty($path) && file_exists($path) ) {
            $list[] = array(
                'name'     => esc_html__( 'Booked Front-End Agents', 'cleaning-services' ),
                'slug'     => 'booked-frontend-agents',
                'source'   => $path,
                'version'  => '1.1.15',
                'required' => false,
            );
        }
        $path = cleaning_services_get_file_dir( 'plugins/install/booked-woocommerce-payments.zip' );
        if ( !empty($path) && file_exists($path) ) {
            $list[] = array(
                'name'     => esc_html__( 'WooCommerce addons - Booked Payments with WooCommerce', 'cleaning-services' ),
                'slug'     => 'booked-woocommerce-payments',
                'source'   => $path,
                'version'  => '1.4.9',
                'required' => false,
            );
        }
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_booked_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_booked_importer_required_plugins');
	function cleaning_services_booked_importer_required_plugins($not_installed='') {
		global $CLEANING_SERVICES_GLOBALS;
		if (in_array('booked',  $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_booked() )
			$not_installed .= '<br>Booked Appointments';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_booked_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_booked_importer_set_options', 10, 1 );
	function cleaning_services_booked_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['additional_options'][] = 'booked_%';		// Add slugs to export options for this plugin
		}
		return $options;
	}
}


// Lists
//------------------------------------------------------------------------

// Return booked calendars list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_booked_calendars' ) ) {
	function cleaning_services_get_list_booked_calendars($prepend_inherit=false) {
		return cleaning_services_exists_booked() ? cleaning_services_get_list_terms($prepend_inherit, 'booked_custom_calendars') : array();
	}
}



// Register plugin's shortcodes
//------------------------------------------------------------------------

// Add shortcode in the shortcodes list
if (!function_exists('cleaning_services_booked_reg_shortcodes')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list',	'cleaning_services_booked_reg_shortcodes');
	function cleaning_services_booked_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$booked_cals = cleaning_services_get_list_booked_calendars();

			$CLEANING_SERVICES_GLOBALS['shortcodes']['booked-appointments'] = array(
				"title" => esc_html__("Booked Appointments", "cleaning-services"),
				"desc" => esc_html__("Display the currently logged in user's upcoming appointments", "cleaning-services"),
				"decorate" => true,
				"container" => false,
				"params" => array()
			);

			$CLEANING_SERVICES_GLOBALS['shortcodes']['booked-calendar'] = array(
				"title" => esc_html__("Booked Calendar", "cleaning-services"),
				"desc" => esc_html__("Insert booked calendar", "cleaning-services"),
				"decorate" => true,
				"container" => false,
				"params" => array(
					"calendar" => array(
						"title" => esc_html__("Calendar", "cleaning-services"),
						"desc" => esc_html__("Select booked calendar to display", "cleaning-services"),
						"value" => "0",
						"type" => "select",
						"options" => cleaning_services_array_merge(array(0 => esc_html__('- Select calendar -', 'cleaning-services')), $booked_cals)
					),
					"year" => array(
						"title" => esc_html__("Year", "cleaning-services"),
						"desc" => esc_html__("Year to display on calendar by default", "cleaning-services"),
						"value" => date("Y"),
						"min" => date("Y"),
						"max" => date("Y")+10,
						"type" => "spinner"
					),
					"month" => array(
						"title" => esc_html__("Month", "cleaning-services"),
						"desc" => esc_html__("Month to display on calendar by default", "cleaning-services"),
						"value" => date("m"),
						"min" => 1,
						"max" => 12,
						"type" => "spinner"
					)
				)
			);
		}
	}
}


// Add shortcode in the VC shortcodes list
if (!function_exists('cleaning_services_booked_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_booked_reg_shortcodes_vc');
	function cleaning_services_booked_reg_shortcodes_vc() {

		$booked_cals = cleaning_services_get_list_booked_calendars();

		// Booked Appointments
		vc_map( array(
			"base" => "booked-appointments",
			"name" => esc_html__("Booked Appointments", "cleaning-services"),
			"description" => esc_html__("Display the currently logged in user's upcoming appointments", "cleaning-services"),
			"category" => esc_html__('Content', 'cleaning-services'),
			'icon' => 'icon_trx_booked',
			"class" => "trx_sc_single trx_sc_booked_appointments",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => false,
			"params" => array()
		) );

		class WPBakeryShortCode_Booked_Appointments extends CLEANING_SERVICES_VC_ShortCodeSingle {}

		// Booked Calendar
		vc_map( array(
			"base" => "booked-calendar",
			"name" => esc_html__("Booked Calendar", "cleaning-services"),
			"description" => esc_html__("Insert booked calendar", "cleaning-services"),
			"category" => esc_html__('Content', 'cleaning-services'),
			'icon' => 'icon_trx_booked',
			"class" => "trx_sc_single trx_sc_booked_calendar",
			"content_element" => true,
			"is_container" => false,
			"show_settings_on_create" => true,
			"params" => array(
				array(
					"param_name" => "calendar",
					"heading" => esc_html__("Calendar", "cleaning-services"),
					"description" => esc_html__("Select booked calendar to display", "cleaning-services"),
					"admin_label" => true,
					"class" => "",
					"std" => "0",
					"value" => array_flip(cleaning_services_array_merge(array(0 => esc_html__('- Select calendar -', 'cleaning-services')), $booked_cals)),
					"type" => "dropdown"
				),
				array(
					"param_name" => "year",
					"heading" => esc_html__("Year", "cleaning-services"),
					"description" => esc_html__("Year to display on calendar by default", "cleaning-services"),
					"admin_label" => true,
					"class" => "",
					"std" => date("Y"),
					"value" => date("Y"),
					"type" => "textfield"
				),
				array(
					"param_name" => "month",
					"heading" => esc_html__("Month", "cleaning-services"),
					"description" => esc_html__("Month to display on calendar by default", "cleaning-services"),
					"admin_label" => true,
					"class" => "",
					"std" => date("m"),
					"value" => date("m"),
					"type" => "textfield"
				)
			)
		) );

		class WPBakeryShortCode_Booked_Calendar extends CLEANING_SERVICES_VC_ShortCodeSingle {}

	}
}
?>