<?php
/* Calculated fields form support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_calcfields_form_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_calcfields_form_theme_setup', 1 );
	function cleaning_services_calcfields_form_theme_setup() {
		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_calcfields_form()) {
			add_action('cleaning_services_action_shortcodes_list',				'cleaning_services_calcfields_form_reg_shortcodes');
			if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
				add_action('cleaning_services_action_shortcodes_list_vc',		'cleaning_services_calcfields_form_reg_shortcodes_vc');
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',			'cleaning_services_calcfields_form_importer_set_options', 10, 1 );
				add_action( 'cleaning_services_action_importer_params',			'cleaning_services_calcfields_form_importer_show_params', 10, 1 );
				add_action( 'cleaning_services_action_importer_import',			'cleaning_services_calcfields_form_importer_import', 10, 2 );
				add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_calcfields_form_importer_import_fields', 10, 1 );
				add_action( 'cleaning_services_action_importer_export',			'cleaning_services_calcfields_form_importer_export', 10, 1 );
				add_action( 'cleaning_services_action_importer_export_fields',	'cleaning_services_calcfields_form_importer_export_fields', 10, 1 );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_calcfields_form_importer_required_plugins');
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_calcfields_form_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'cleaning_services_exists_calcfields_form' ) ) {
	function cleaning_services_exists_calcfields_form() {
		return defined('CP_SCHEME');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_calcfields_form_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_calcfields_form_required_plugins');
	function cleaning_services_calcfields_form_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('calcfields', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Calculated Fields Form',
					'slug' 		=> 'calculated-fields-form',
					'required' 	=> false
					);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_calcfields_form_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_calcfields_form_importer_required_plugins' );
	function cleaning_services_calcfields_form_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('calcfields', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_calcfields_form() )
			$not_installed .= '<br>Calculated Fields Form';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_calcfields_form_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_calcfields_form_importer_set_options', 10, 1 );
	function cleaning_services_calcfields_form_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['file_with_calcfields_form'] = 'demo/calcfields_form.txt';			// Name of the file with Calculated Fields Form data
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'cleaning_services_calcfields_form_importer_show_params' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_params',	'cleaning_services_calcfields_form_importer_show_params', 10, 1 );
	function cleaning_services_calcfields_form_importer_show_params($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<input type="checkbox" <?php echo in_array('calcfields', $CLEANING_SERVICES_GLOBALS['required_plugins']) ? 'checked="checked"' : ''; ?> value="1" name="import_calcfields_form" id="import_calcfields_form" /> <label for="import_calcfields_form"><?php esc_html_e('Import Calculated Fields Form', 'cleaning-services'); ?></label><br>
		<?php
	}
}

// Import posts
if ( !function_exists( 'cleaning_services_calcfields_form_importer_import' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import',	'cleaning_services_calcfields_form_importer_import', 10, 2 );
	function cleaning_services_calcfields_form_importer_import($importer, $action) {
		if ( $action == 'import_calcfields_form' ) {
			$importer->import_dump('calcfields_form', esc_html__('Calculated Fields Form', 'cleaning-services'));
		}
	}
}

// Display import progress
if ( !function_exists( 'cleaning_services_calcfields_form_importer_import_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_calcfields_form_importer_import_fields', 10, 1 );
	function cleaning_services_calcfields_form_importer_import_fields($importer) {
		?>
		<tr class="import_calcfields_form">
			<td class="import_progress_item"><?php esc_html_e('Calculated Fields Form', 'cleaning-services'); ?></td>
			<td class="import_progress_status"></td>
		</tr>
		<?php
	}
}

// Export posts
if ( !function_exists( 'cleaning_services_calcfields_form_importer_export' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_export',	'cleaning_services_calcfields_form_importer_export', 10, 1 );
	function cleaning_services_calcfields_form_importer_export($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['export_calcfields_form'] = serialize( array(
			CP_CALCULATEDFIELDSF_FORMS_TABLE => $importer->export_dump(CP_CALCULATEDFIELDSF_FORMS_TABLE)
			)
		);
	}
}

// Display exported data in the fields
if ( !function_exists( 'cleaning_services_calcfields_form_importer_export_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_export_fields',	'cleaning_services_calcfields_form_importer_export_fields', 10, 1 );
	function cleaning_services_calcfields_form_importer_export_fields($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<tr>
			<th align="left"><?php esc_html_e('Calculated Fields Form', 'cleaning-services'); ?></th>
			<td><?php cleaning_services_fpc(cleaning_services_get_file_dir('core/core.importer/export/calcfields_form.txt'), $CLEANING_SERVICES_GLOBALS['export_calcfields_form']); ?>
				<a download="calcfields_form.txt" href="<?php echo esc_url(cleaning_services_get_file_url('core/core.importer/export/calcfields_form.txt')); ?>"><?php esc_html_e('Download', 'cleaning-services'); ?></a>
			</td>
		</tr>
		<?php
	}
}


// Lists
//------------------------------------------------------------------------

// Return Calculated forms list list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_calcfields_form' ) ) {
	function cleaning_services_get_list_calcfields_form($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_calcfields_form']))
			$list = $CLEANING_SERVICES_GLOBALS['list_calcfields_form'];
		else {
			$list = array();
			if (cleaning_services_exists_calcfields_form()) {
				global $wpdb;
				$rows = $wpdb->get_results( "SELECT id, form_name FROM " . esc_sql($wpdb->prefix . CP_CALCULATEDFIELDSF_FORMS_TABLE) );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->id] = $row->form_name;
					}
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_calcfields_form'] = $list = apply_filters('cleaning_services_filter_list_calcfields_form', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}



// Shortcodes
//------------------------------------------------------------------------

// Add shortcode in the shortcodes list
if (!function_exists('cleaning_services_calcfields_form_reg_shortcodes')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list',	'cleaning_services_calcfields_form_reg_shortcodes');
	function cleaning_services_calcfields_form_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$forms_list = cleaning_services_get_list_calcfields_form();

			cleaning_services_array_insert_after($CLEANING_SERVICES_GLOBALS['shortcodes'], 'trx_button', array(

				// Calculated fields form
				'CP_CALCULATED_FIELDS' => array(
					"title" => esc_html__("Calculated fields form", 'cleaning-services'),
					"desc" => esc_html__("Insert calculated fields form", 'cleaning-services'),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"id" => array(
							"title" => esc_html__("Form ID", 'cleaning-services'),
							"desc" => esc_html__("Select Form to insert into current page", 'cleaning-services'),
							"value" => "",
							"size" => "medium",
							"options" => $forms_list,
							"type" => "select"
						)
					)
				)

			));
		}
	}
}


// Add shortcode in the VC shortcodes list
if (!function_exists('cleaning_services_calcfields_form_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_calcfields_form_reg_shortcodes_vc');
	function cleaning_services_calcfields_form_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;

		$forms_list = cleaning_services_get_list_calcfields_form();

		// Calculated fields form
		vc_map( array(
				"base" => "CP_CALCULATED_FIELDS",
				"name" => esc_html__("Calculated fields form", 'cleaning-services'),
				"description" => esc_html__("Insert calculated fields form", 'cleaning-services'),
				"category" => esc_html__('Content', 'cleaning-services'),
				'icon' => 'icon_trx_calcfields',
				"class" => "trx_sc_single trx_sc_calcfields",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "id",
						"heading" => esc_html__("Form ID", 'cleaning-services'),
						"description" => esc_html__("Select Form to insert into current page", 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($forms_list),
						"type" => "dropdown"
					)
				)
			) );
			
		class WPBakeryShortCode_Cp_Calculated_Fields extends CLEANING_SERVICES_VC_ShortCodeSingle {}

	}
}
?>