<?php
/* Essential Grid support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_essgrids_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_essgrids_theme_setup', 1 );
	function cleaning_services_essgrids_theme_setup() {
		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_essgrids()) {
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',			'cleaning_services_essgrids_importer_set_options', 10, 1 );
				add_action( 'cleaning_services_action_importer_params',			'cleaning_services_essgrids_importer_show_params', 10, 1 );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_essgrids_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_essgrids_required_plugins' );
		}
	}
}


// Check if Ess. Grid installed and activated
if ( !function_exists( 'cleaning_services_exists_essgrids' ) ) {
	function cleaning_services_exists_essgrids() {
		return defined('EG_PLUGIN_PATH');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_essgrids_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_essgrids_required_plugins');
	function cleaning_services_essgrids_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('essgrids', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Essential Grid',
					'slug' 		=> 'essential-grid',
					'source'	=> cleaning_services_get_file_dir('plugins/install/essential-grid.zip'),
					'required' 	=> false
					);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_essgrids_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_essgrids_importer_required_plugins' );
	function cleaning_services_essgrids_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('essgrids', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_essgrids() )
			$not_installed .= '<br>Essential Grids';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_essgrids_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_essgrids_importer_set_options', 10, 1 );
	function cleaning_services_essgrids_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['folder_with_essgrids'] = 'demo/essgrids';			// Name of the folder with Essential Grids
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'cleaning_services_essgrids_importer_show_params' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_params',	'cleaning_services_essgrids_importer_show_params', 10, 1 );
	function cleaning_services_essgrids_importer_show_params($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<input type="checkbox" <?php echo in_array('essgrids', $CLEANING_SERVICES_GLOBALS['required_plugins']) ? 'checked="checked"' : ''; ?> value="1" name="import_essgrids" id="import_essgrids" /> <label for="import_essgrids"><?php esc_html_e('Import Ess.Grids', 'cleaning-services'); ?></label><br>
		<?php
	}
}

// Display import progress
if ( !function_exists( 'cleaning_services_essgrids_importer_import_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_essgrids_importer_import_fields', 10, 1 );
	function cleaning_services_essgrids_importer_import_fields($importer) {
		?>
		<tr class="import_essgrids">
			<td class="import_progress_item"><?php esc_html_e('Essential Grid', 'cleaning-services'); ?></td>
			<td class="import_progress_status"></td>
		</tr>
		<?php
	}
}
?>