<?php
/* LearnDash LMS support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_learndash_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_learndash_theme_setup', 1 );
	function cleaning_services_learndash_theme_setup() {

		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_learndash()) {
			// Detect current page type, taxonomy and title (for custom post_types use priority < 10 to fire it handles early, than for standard post types)
			add_filter('cleaning_services_filter_get_blog_type',			'cleaning_services_learndash_get_blog_type', 9, 2);
			add_filter('cleaning_services_filter_get_blog_title',		'cleaning_services_learndash_get_blog_title', 9, 2);
			add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_learndash_get_current_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_is_taxonomy',			'cleaning_services_learndash_is_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_learndash_get_stream_page_title', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_learndash_get_stream_page_link', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_learndash_get_stream_page_id', 9, 2);
			add_filter('cleaning_services_filter_query_add_filters',		'cleaning_services_learndash_query_add_filters', 9, 2);
			add_filter('cleaning_services_filter_detect_inheritance_key','cleaning_services_learndash_detect_inheritance_key', 9, 1);

			// One-click importer support
			add_filter( 'cleaning_services_filter_importer_options',		'cleaning_services_learndash_importer_set_options' );

			// Get list post_types and taxonomies
			global $CLEANING_SERVICES_GLOBALS;
			$CLEANING_SERVICES_GLOBALS['learndash_post_types'] = array('sfwd-courses', 'sfwd-lessons', 'sfwd-quiz', 'sfwd-topic', 'sfwd-certificates', 'sfwd-transactions');
			$CLEANING_SERVICES_GLOBALS['learndash_taxonomies'] = array('category');
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_learndash_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_learndash_required_plugins' );
		}
	}
}

// Attention! Add action on 'init' instead 'before_init_theme' because LearnDash add post_types and taxonomies on this action
if ( !function_exists( 'cleaning_services_learndash_settings_theme_setup2' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_learndash_settings_theme_setup2', 3 );
	//Handler of add_action( 'init', 'cleaning_services_learndash_settings_theme_setup2', 20 );
	function cleaning_services_learndash_settings_theme_setup2() {
		// Add LearnDash post type and taxonomy into theme inheritance list
		if (cleaning_services_exists_learndash()) {
			global $CLEANING_SERVICES_GLOBALS;
			// Get list post_types and taxonomies
			if (!empty(SFWD_CPT_Instance::$instances) && count(SFWD_CPT_Instance::$instances) > 0) {
				$post_types = array();
				foreach (SFWD_CPT_Instance::$instances as $pt=>$data)
					$post_types[] = $pt;
				if (count($post_types) > 0)
					$CLEANING_SERVICES_GLOBALS['learndash_post_types'] = $post_types;
			}
			// Add in the inheritance list
			cleaning_services_add_theme_inheritance( array('learndash' => array(
				'stream_template' => 'blog-learndash',
				'single_template' => 'single-learndash',
				'taxonomy' => $CLEANING_SERVICES_GLOBALS['learndash_taxonomies'],
				'taxonomy_tags' => array('post_tag'),
				'post_type' => $CLEANING_SERVICES_GLOBALS['learndash_post_types'],
				'override' => 'page'
				) )
			);
		}
	}
}



// Check if Cleaning Services Donations installed and activated
if ( !function_exists( 'cleaning_services_exists_learndash' ) ) {
	function cleaning_services_exists_learndash() {
		return class_exists('SFWD_LMS');
	}
}


// Return true, if current page is donations page
if ( !function_exists( 'cleaning_services_is_learndash_page' ) ) {
	function cleaning_services_is_learndash_page() {
		$is = false;
		if (cleaning_services_exists_learndash()) {
			global $CLEANING_SERVICES_GLOBALS;
			$is = in_array($CLEANING_SERVICES_GLOBALS['page_template'], array('blog-learndash', 'single-learndash'));
			if (!$is) {
				$is = !empty($CLEANING_SERVICES_GLOBALS['pre_query'])
							? $CLEANING_SERVICES_GLOBALS['pre_query']->is_single() && in_array($CLEANING_SERVICES_GLOBALS['pre_query']->get('post_type'), $CLEANING_SERVICES_GLOBALS['learndash_post_types'])
							: is_single() && in_array(get_query_var('post_type'), $CLEANING_SERVICES_GLOBALS['learndash_post_types']);
			}
			if (!$is) {
				if (count($CLEANING_SERVICES_GLOBALS['learndash_post_types']) > 0) {
					foreach ($CLEANING_SERVICES_GLOBALS['learndash_post_types'] as $pt) {
						if (!empty($CLEANING_SERVICES_GLOBALS['pre_query']) ? $CLEANING_SERVICES_GLOBALS['pre_query']->is_post_type_archive($pt) : is_post_type_archive($pt)) {
							$is = true;
							break;
						}
					}
				}
			}
			if (!$is) {
				if (count($CLEANING_SERVICES_GLOBALS['learndash_taxonomies']) > 0) {
					foreach ($CLEANING_SERVICES_GLOBALS['learndash_taxonomies'] as $pt) {
						if (!empty($CLEANING_SERVICES_GLOBALS['pre_query']) ? $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax($pt) : is_tax($pt)) {
							$is = true;
							break;
						}
					}
				}
			}
		}
		return $is;
	}
}

// Filter to detect current page inheritance key
if ( !function_exists( 'cleaning_services_learndash_detect_inheritance_key' ) ) {
	//Handler of add_filter('cleaning_services_filter_detect_inheritance_key',	'cleaning_services_learndash_detect_inheritance_key', 9, 1);
	function cleaning_services_learndash_detect_inheritance_key($key) {
		if (!empty($key)) return $key;
		return cleaning_services_is_learndash_page() ? 'learndash' : '';
	}
}

// Filter to detect current page slug
if ( !function_exists( 'cleaning_services_learndash_get_blog_type' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_type',	'cleaning_services_learndash_get_blog_type', 9, 2);
	function cleaning_services_learndash_get_blog_type($page, $query=null) {
		if (!empty($page)) return $page;
		global $CLEANING_SERVICES_GLOBALS;
		if (count($CLEANING_SERVICES_GLOBALS['learndash_taxonomies']) > 0) {
			foreach ($CLEANING_SERVICES_GLOBALS['learndash_taxonomies'] as $pt) {
				if ($query && $query->is_tax($pt) || is_tax($pt)) {
					$page = 'learndash_'.$pt;
					break;
				}
			}
		}
		if (empty($page)) {
			$pt = $query ? $query->get('post_type') : get_query_var('post_type');
			if (in_array($pt, $CLEANING_SERVICES_GLOBALS['learndash_post_types'])) {
				$page = $query && $query->is_single() || is_single() ? 'learndash_item' : 'learndash';
			}
		}
		return $page;
	}
}

// Filter to detect current page title
if ( !function_exists( 'cleaning_services_learndash_get_blog_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_title',	'cleaning_services_learndash_get_blog_title', 9, 2);
	function cleaning_services_learndash_get_blog_title($title, $page) {
		if (!empty($title)) return $title;
		if ( cleaning_services_strpos($page, 'learndash')!==false ) {
			if ( $page == 'learndash_item' ) {
				$title = cleaning_services_get_post_title();
			} else if ( cleaning_services_strpos($page, 'learndash_')!==false ) {
				$parts = explode('_', $page);
				$term = get_term_by( 'slug', get_query_var( $parts[1] ), $parts[1], OBJECT);
				$title = $term->name;
			} else {
				$title = esc_html__('All courses', 'cleaning-services');
			}
		}

		return $title;
	}
}

// Filter to detect stream page title
if ( !function_exists( 'cleaning_services_learndash_get_stream_page_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_learndash_get_stream_page_title', 9, 2);
	function cleaning_services_learndash_get_stream_page_title($title, $page) {
		if (!empty($title)) return $title;
		if (cleaning_services_strpos($page, 'learndash')!==false) {
			if (($page_id = cleaning_services_learndash_get_stream_page_id(0, $page=='learndash' ? 'blog-learndash' : $page)) > 0)
				$title = cleaning_services_get_post_title($page_id);
			else
				$title = esc_html__('All courses', 'cleaning-services');				
		}
		return $title;
	}
}

// Filter to detect stream page ID
if ( !function_exists( 'cleaning_services_learndash_get_stream_page_id' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_learndash_get_stream_page_id', 9, 2);
	function cleaning_services_learndash_get_stream_page_id($id, $page) {
		if (!empty($id)) return $id;
		if (cleaning_services_strpos($page, 'learndash')!==false) $id = cleaning_services_get_template_page_id('blog-learndash');
		return $id;
	}
}

// Filter to detect stream page URL
if ( !function_exists( 'cleaning_services_learndash_get_stream_page_link' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_learndash_get_stream_page_link', 9, 2);
	function cleaning_services_learndash_get_stream_page_link($url, $page) {
		if (!empty($url)) return $url;
		if (cleaning_services_strpos($page, 'learndash')!==false) {
			$id = cleaning_services_get_template_page_id('blog-learndash');
			if ($id) $url = get_permalink($id);
		}
		return $url;
	}
}

// Filter to detect current taxonomy
if ( !function_exists( 'cleaning_services_learndash_get_current_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_learndash_get_current_taxonomy', 9, 2);
	function cleaning_services_learndash_get_current_taxonomy($tax, $page) {
		if (!empty($tax)) return $tax;
		if ( cleaning_services_strpos($page, 'learndash')!==false ) {
			global $CLEANING_SERVICES_GLOBALS;
			if (count($CLEANING_SERVICES_GLOBALS['learndash_taxonomies']) > 0) {
				$tax = $CLEANING_SERVICES_GLOBALS['learndash_taxonomies'][0];
			}
		}
		return $tax;
	}
}

// Return taxonomy name (slug) if current page is this taxonomy page
if ( !function_exists( 'cleaning_services_learndash_is_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_is_taxonomy',	'cleaning_services_learndash_is_taxonomy', 9, 2);
	function cleaning_services_learndash_is_taxonomy($tax, $query=null) {
		if (!empty($tax))
			return $tax;
		else {
			global $CLEANING_SERVICES_GLOBALS;
			if (count($CLEANING_SERVICES_GLOBALS['learndash_taxonomies']) > 0) {
				foreach ($CLEANING_SERVICES_GLOBALS['learndash_taxonomies'] as $pt) {
					if ($query && ($query->get($pt)!='' || $query->is_tax($pt)) || is_tax($pt)) {
						$tax = $pt;
						break;
					}
				}
			}
			return $tax;
		}
	}
}

// Add custom post type and/or taxonomies arguments to the query
if ( !function_exists( 'cleaning_services_learndash_query_add_filters' ) ) {
	//Handler of add_filter('cleaning_services_filter_query_add_filters',	'cleaning_services_learndash_query_add_filters', 9, 2);
	function cleaning_services_learndash_query_add_filters($args, $filter) {
		if ($filter == 'learndash') {
			//global $CLEANING_SERVICES_GLOBALS;
			$args['post_type'] = 'sfwd-courses';
		}
		return $args;
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_learndash_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_learndash_required_plugins');
	function cleaning_services_learndash_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('learndash', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'LearnDash LMS',
					'slug' 		=> 'sfwd-lms',
					'source'	=> cleaning_services_get_file_dir('plugins/install/sfwd-lms.zip'),
					'required' 	=> false
					);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_learndash_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_learndash_importer_required_plugins' );
	function cleaning_services_learndash_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('learndash', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_learndash() )
			$not_installed .= '<br>LearnDash LMS';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_learndash_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_learndash_importer_set_options' );
	function cleaning_services_learndash_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['additional_options'][] = 'sfwd_cpt_options';		// Add slugs to export options for this plugin
		}
		return $options;
	}
}
?>