<?php
/* Responsive Poll support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_responsive_poll_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_responsive_poll_theme_setup', 1 );
	function cleaning_services_responsive_poll_theme_setup() {
		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_responsive_poll()) {
			add_action('cleaning_services_action_shortcodes_list',				'cleaning_services_responsive_poll_reg_shortcodes');
			if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
				add_action('cleaning_services_action_shortcodes_list_vc',		'cleaning_services_responsive_poll_reg_shortcodes_vc');
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',			'cleaning_services_responsive_poll_importer_set_options', 10, 1 );
				add_action( 'cleaning_services_action_importer_params',			'cleaning_services_responsive_poll_importer_show_params', 10, 1 );
				add_action( 'cleaning_services_action_importer_import',			'cleaning_services_responsive_poll_importer_import', 10, 2 );
				add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_responsive_poll_importer_import_fields', 10, 1 );
				add_action( 'cleaning_services_action_importer_export',			'cleaning_services_responsive_poll_importer_export', 10, 1 );
				add_action( 'cleaning_services_action_importer_export_fields',	'cleaning_services_responsive_poll_importer_export_fields', 10, 1 );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_responsive_poll_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_responsive_poll_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'cleaning_services_exists_responsive_poll' ) ) {
	function cleaning_services_exists_responsive_poll() {
		return class_exists('Weblator_Polling');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_responsive_poll_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_responsive_poll_required_plugins');
	function cleaning_services_responsive_poll_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('responsive_poll', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Responsive Poll',
					'slug' 		=> 'responsive-poll',
					'source'	=> cleaning_services_get_file_dir('plugins/install/responsive-poll.zip'),
					'required' 	=> false
					);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_responsive_poll_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_responsive_poll_importer_required_plugins' );
	function cleaning_services_responsive_poll_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('responsive_poll', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_responsive_poll() )
			$not_installed .= '<br>Responsive Poll';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_responsive_poll_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_responsive_poll_importer_set_options', 10, 1 );
	function cleaning_services_responsive_poll_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['file_with_responsive_poll'] = 'demo/responsive_poll.txt';			// Name of the file with Responsive Poll data
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'cleaning_services_responsive_poll_importer_show_params' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_params',	'cleaning_services_responsive_poll_importer_show_params', 10, 1 );
	function cleaning_services_responsive_poll_importer_show_params($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<input type="checkbox" <?php echo in_array('responsive_poll', $CLEANING_SERVICES_GLOBALS['required_plugins']) ? 'checked="checked"' : ''; ?> value="1" name="import_responsive_poll" id="import_responsive_poll" /> <label for="import_responsive_poll"><?php esc_html_e('Import Responsive Poll', 'cleaning-services'); ?></label><br>
		<?php
	}
}

// Import posts
if ( !function_exists( 'cleaning_services_responsive_poll_importer_import' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import',	'cleaning_services_responsive_poll_importer_import', 10, 2 );
	function cleaning_services_responsive_poll_importer_import($importer, $action) {
		if ( $action == 'import_responsive_poll' ) {
			$importer->import_dump('responsive_poll', esc_html__('Responsive Poll', 'cleaning-services'));
		}
	}
}

// Display import progress
if ( !function_exists( 'cleaning_services_responsive_poll_importer_import_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_responsive_poll_importer_import_fields', 10, 1 );
	function cleaning_services_responsive_poll_importer_import_fields($importer) {
		?>
		<tr class="import_responsive_poll">
			<td class="import_progress_item"><?php esc_html_e('Responsive Poll', 'cleaning-services'); ?></td>
			<td class="import_progress_status"></td>
		</tr>
		<?php
	}
}

// Export posts
if ( !function_exists( 'cleaning_services_responsive_poll_importer_export' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_export',	'cleaning_services_responsive_poll_importer_export', 10, 1 );
	function cleaning_services_responsive_poll_importer_export($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['export_responsive_poll'] = serialize( array(
			'weblator_polls'		=> $importer->export_dump('weblator_polls'),
			'weblator_poll_options'	=> $importer->export_dump('weblator_poll_options'),
			'weblator_poll_votes'	=> $importer->export_dump('weblator_poll_votes')
			)
		);
	}
}

// Display exported data in the fields
if ( !function_exists( 'cleaning_services_responsive_poll_importer_export_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_export_fields',	'cleaning_services_responsive_poll_importer_export_fields', 10, 1 );
	function cleaning_services_responsive_poll_importer_export_fields($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<tr>
			<th align="left"><?php esc_html_e('Responsive Poll', 'cleaning-services'); ?></th>
			<td><?php cleaning_services_fpc(cleaning_services_get_file_dir('core/core.importer/export/responsive_poll.txt'), $CLEANING_SERVICES_GLOBALS['export_responsive_poll']); ?>
				<a download="responsive_poll.txt" href="<?php echo esc_url(cleaning_services_get_file_url('core/core.importer/export/responsive_poll.txt')); ?>"><?php esc_html_e('Download', 'cleaning-services'); ?></a>
			</td>
		</tr>
		<?php
	}
}


// Lists
//------------------------------------------------------------------------

// Return Responsive Pollst list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_responsive_polls' ) ) {
	function cleaning_services_get_list_responsive_polls($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_responsive_polls']))
			$list = $CLEANING_SERVICES_GLOBALS['list_responsive_polls'];
		else {
			$list = array();
			if (cleaning_services_exists_responsive_poll()) {
				global $wpdb;
				$rows = $wpdb->get_results( "SELECT id, poll_name FROM " . esc_sql($wpdb->prefix . 'weblator_polls') );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->id] = $row->poll_name;
					}
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_responsive_polls'] = $list = apply_filters('cleaning_services_filter_list_responsive_polls', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}



// Shortcodes
//------------------------------------------------------------------------

// Add shortcode in the shortcodes list
if (!function_exists('cleaning_services_responsive_poll_reg_shortcodes')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list',	'cleaning_services_responsive_poll_reg_shortcodes');
	function cleaning_services_responsive_poll_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$polls_list = cleaning_services_get_list_responsive_polls();

			cleaning_services_array_insert_before($CLEANING_SERVICES_GLOBALS['shortcodes'], 'trx_popup', array(

				// Calculated fields form
				'poll' => array(
					"title" => esc_html__("Poll", 'cleaning-services'),
					"desc" => esc_html__("Insert poll", 'cleaning-services'),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"id" => array(
							"title" => esc_html__("Poll ID", 'cleaning-services'),
							"desc" => esc_html__("Select Poll to insert into current page", 'cleaning-services'),
							"value" => "",
							"size" => "medium",
							"options" => $polls_list,
							"type" => "select"
						)
					)
				)

			));
		}
	}
}


// Add shortcode in the VC shortcodes list
if (!function_exists('cleaning_services_responsive_poll_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_responsive_poll_reg_shortcodes_vc');
	function cleaning_services_responsive_poll_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;

		$polls_list = cleaning_services_get_list_responsive_polls();

		// Calculated fields form
		vc_map( array(
				"base" => "poll",
				"name" => esc_html__("Poll", 'cleaning-services'),
				"description" => esc_html__("Insert poll", 'cleaning-services'),
				"category" => esc_html__('Content', 'cleaning-services'),
				'icon' => 'icon_trx_poll',
				"class" => "trx_sc_single trx_sc_poll",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "id",
						"heading" => esc_html__("Poll ID", 'cleaning-services'),
						"description" => esc_html__("Select Poll to insert into current page", 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($polls_list),
						"type" => "dropdown"
					)
				)
			) );
			
		class WPBakeryShortCode_Poll extends CLEANING_SERVICES_VC_ShortCodeSingle {}

	}
}
?>