<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_revslider_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_revslider_theme_setup', 1 );
	function cleaning_services_revslider_theme_setup() {
		if (cleaning_services_exists_revslider()) {
			add_filter( 'cleaning_services_filter_list_sliders',					'cleaning_services_revslider_list_sliders' );
			add_filter( 'cleaning_services_filter_shortcodes_params',			'cleaning_services_revslider_shortcodes_params' );
			add_filter( 'cleaning_services_filter_theme_options_params',			'cleaning_services_revslider_theme_options_params' );
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',			'cleaning_services_revslider_importer_set_options' );
				add_action( 'cleaning_services_action_importer_params',			'cleaning_services_revslider_importer_show_params', 10, 1 );
				add_action( 'cleaning_services_action_importer_clear_tables',	'cleaning_services_revslider_importer_clear_tables', 10, 2 );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_revslider_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_revslider_required_plugins' );
		}
	}
}

if ( !function_exists( 'cleaning_services_revslider_settings_theme_setup2' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_revslider_settings_theme_setup2', 3 );
	function cleaning_services_revslider_settings_theme_setup2() {
		if (cleaning_services_exists_revslider()) {

			// Add Revslider specific options in the Theme Options
			global $CLEANING_SERVICES_GLOBALS;

			cleaning_services_array_insert_after($CLEANING_SERVICES_GLOBALS['options'], 'slider_engine', array(
		
				"slider_alias" => array(
					"title" => esc_html__('Revolution Slider: Select slider',  'cleaning-services'),
					"desc" => wp_kses( __("Select slider to show (if engine=revo in the field above)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"override" => "category,services_group,page",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('revo')
					),
					"std" => "",
					"options" => $CLEANING_SERVICES_GLOBALS['options_params']['list_revo_sliders'],
					"type" => "select")
				
				)
			);

		}
	}
}

// Check if RevSlider installed and activated
if ( !function_exists( 'cleaning_services_exists_revslider' ) ) {
	function cleaning_services_exists_revslider() {
		return function_exists('rev_slider_shortcode');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_revslider_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_revslider_required_plugins');
	function cleaning_services_revslider_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('revslider', $CLEANING_SERVICES_GLOBALS['required_plugins'])){
			$list[] = array(
					'name' 		=> 'Revolution Slider',
					'slug' 		=> 'revslider',
					'source'	=> cleaning_services_get_file_dir('plugins/install/revslider.zip'),
					'required' 	=> false
				);
		}
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check RevSlider in the required plugins
if ( !function_exists( 'cleaning_services_revslider_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_revslider_importer_required_plugins' );
	function cleaning_services_revslider_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('revslider', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_revslider() )
			$not_installed .= '<br>Revolution Slider';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_revslider_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_revslider_importer_set_options', 10, 1 );
	function cleaning_services_revslider_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['folder_with_revsliders'] = 'demo/revslider';			// Name of the folder with Revolution slider data
			$options['import_sliders'] = true;								// Import Revolution Sliders
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'cleaning_services_revslider_importer_show_params' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_params',	'cleaning_services_revslider_importer_show_params', 10, 1 );
	function cleaning_services_revslider_importer_show_params($importer) {
		global $CLEANING_SERVICES_GLOBALS;
		?>
		<input type="checkbox" <?php echo in_array('revslider', $CLEANING_SERVICES_GLOBALS['required_plugins']) ? 'checked="checked"' : ''; ?> value="1" name="import_revslider" id="import_revslider" /> <label for="import_revslider"><?php esc_html_e('Import Revolution Sliders', 'cleaning-services'); ?></label><br>
		<?php
	}
}

// Clear tables
if ( !function_exists( 'cleaning_services_revslider_importer_clear_tables' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_clear_tables',	'cleaning_services_revslider_importer_clear_tables', 10, 2 );
	function cleaning_services_revslider_importer_clear_tables($importer, $clear_tables) {
		if (cleaning_services_strpos($clear_tables, 'revslider')!==false && $importer->last_slider==0) {
			if ($importer->options['debug']) dfl(esc_html__('Clear Revolution Slider tables', 'cleaning-services'));
			global $wpdb;
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_sliders");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_sliders".', 'cleaning-services' ) . ' ' . ($res->get_error_message()) );
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_slides");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_slides".', 'cleaning-services' ) . ' ' . ($res->get_error_message()) );
			$res = $wpdb->query("TRUNCATE TABLE " . esc_sql($wpdb->prefix) . "revslider_static_slides");
			if ( is_wp_error( $res ) ) dfl( esc_html__( 'Failed truncate table "revslider_static_slides".', 'cleaning-services' ) . ' ' . ($res->get_error_message()) );
		}
	}
}

// Display import progress
if ( !function_exists( 'cleaning_services_revslider_importer_import_fields' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_import_fields',	'cleaning_services_revslider_importer_import_fields', 10, 1 );
	function cleaning_services_revslider_importer_import_fields($importer) {
		?>
		<tr class="import_revslider">
			<td class="import_progress_item"><?php esc_html_e('Revolution Slider', 'cleaning-services'); ?></td>
			<td class="import_progress_status"></td>
		</tr>
		<?php
	}
}


// Lists
//------------------------------------------------------------------------

// Add RevSlider in the sliders list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_revslider_list_sliders' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_list_sliders',					'cleaning_services_revslider_list_sliders' );
	function cleaning_services_revslider_list_sliders($list=array()) {
		$list["revo"] = esc_html__("Layer slider (Revolution)", 'cleaning-services');
		return $list;
	}
}

// Return Revo Sliders list, prepended inherit (if need)
if ( !function_exists( 'cleaning_services_get_list_revo_sliders' ) ) {
	function cleaning_services_get_list_revo_sliders($prepend_inherit=false) {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['list_revo_sliders']))
			$list = $CLEANING_SERVICES_GLOBALS['list_revo_sliders'];
		else {
			$list = array();
			if (cleaning_services_exists_revslider()) {
				global $wpdb;
				$rows = $wpdb->get_results( "SELECT alias, title FROM " . esc_sql($wpdb->prefix) . "revslider_sliders" );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->alias] = $row->title;
					}
				}
			}
			$CLEANING_SERVICES_GLOBALS['list_revo_sliders'] = $list = apply_filters('cleaning_services_filter_list_revo_sliders', $list);
		}
		return $prepend_inherit ? cleaning_services_array_merge(array('inherit' => esc_html__("Inherit", 'cleaning-services')), $list) : $list;
	}
}

// Add RevSlider in the shortcodes params
if ( !function_exists( 'cleaning_services_revslider_shortcodes_params' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_shortcodes_params',			'cleaning_services_revslider_shortcodes_params' );
	function cleaning_services_revslider_shortcodes_params($list=array()) {
		$list["revo_sliders"] = cleaning_services_get_list_revo_sliders();
		return $list;
	}
}

// Add RevSlider in the Theme Options params
if ( !function_exists( 'cleaning_services_revslider_theme_options_params' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_theme_options_params',			'cleaning_services_revslider_theme_options_params' );
	function cleaning_services_revslider_theme_options_params($list=array()) {
		global $CLEANING_SERVICES_GLOBALS;
		$list["list_revo_sliders"] = array('$'.$CLEANING_SERVICES_GLOBALS['theme_slug'].'_get_list_revo_sliders' => '');
		return $list;
	}
}
?>