<?php
/* Cleaning Services Donations support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_trx_donations_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_trx_donations_theme_setup', 1 );
	function cleaning_services_trx_donations_theme_setup() {

		// Add shortcode in the shortcodes list
		if (cleaning_services_exists_trx_donations()) {
			// Detect current page type, taxonomy and title (for custom post_types use priority < 10 to fire it handles early, than for standard post types)
			add_filter('cleaning_services_filter_get_blog_type',			'cleaning_services_trx_donations_get_blog_type', 9, 2);
			add_filter('cleaning_services_filter_get_blog_title',		'cleaning_services_trx_donations_get_blog_title', 9, 2);
			add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_trx_donations_get_current_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_is_taxonomy',			'cleaning_services_trx_donations_is_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_trx_donations_get_stream_page_title', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_trx_donations_get_stream_page_link', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_trx_donations_get_stream_page_id', 9, 2);
			add_filter('cleaning_services_filter_query_add_filters',		'cleaning_services_trx_donations_query_add_filters', 9, 2);
			add_filter('cleaning_services_filter_detect_inheritance_key','cleaning_services_trx_donations_detect_inheritance_key', 9, 1);
			add_filter('cleaning_services_filter_list_post_types',		'cleaning_services_trx_donations_list_post_types');
			// Add shortcodes in the list
			add_action('cleaning_services_action_shortcodes_list',		'cleaning_services_trx_donations_reg_shortcodes');
			if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
				add_action('cleaning_services_action_shortcodes_list_vc','cleaning_services_trx_donations_reg_shortcodes_vc');
			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',				'cleaning_services_trx_donations_importer_set_options' );
			}
		}
		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_trx_donations_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',				'cleaning_services_trx_donations_required_plugins' );
		}
	}
}

if ( !function_exists( 'cleaning_services_trx_donations_settings_theme_setup2' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_trx_donations_settings_theme_setup2', 3 );
	function cleaning_services_trx_donations_settings_theme_setup2() {
		// Add Donations post type and taxonomy into theme inheritance list
		if (cleaning_services_exists_trx_donations()) {
			cleaning_services_add_theme_inheritance( array('donations' => array(
				'stream_template' => 'blog-donations',
				'single_template' => 'single-donation',
				'taxonomy' => array(CLEANING_SERVICES_Donations::TAXONOMY),
				'taxonomy_tags' => array(),
				'post_type' => array(CLEANING_SERVICES_Donations::POST_TYPE),
				'override' => 'page'
				) )
			);
		}
	}
}

// Check if Cleaning Services Donations installed and activated
if ( !function_exists( 'cleaning_services_exists_trx_donations' ) ) {
	function cleaning_services_exists_trx_donations() {
		return class_exists('CLEANING_SERVICES_Donations');
	}
}


// Return true, if current page is donations page
if ( !function_exists( 'cleaning_services_is_trx_donations_page' ) ) {
	function cleaning_services_is_trx_donations_page() {
		$is = false;
		if (cleaning_services_exists_trx_donations()) {
			global $CLEANING_SERVICES_GLOBALS;
			$is = in_array($CLEANING_SERVICES_GLOBALS['page_template'], array('blog-donations', 'single-donation'));
			if (!$is) {
				if (!empty($CLEANING_SERVICES_GLOBALS['pre_query']))
					$is = ($CLEANING_SERVICES_GLOBALS['pre_query']->is_single() && $CLEANING_SERVICES_GLOBALS['pre_query']->get('post_type') == CLEANING_SERVICES_Donations::POST_TYPE) 
							|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_post_type_archive(CLEANING_SERVICES_Donations::POST_TYPE) 
							|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax(CLEANING_SERVICES_Donations::TAXONOMY);
				else
					$is = (is_single() && get_query_var('post_type') == CLEANING_SERVICES_Donations::POST_TYPE) 
							|| is_post_type_archive(CLEANING_SERVICES_Donations::POST_TYPE) 
							|| is_tax(CLEANING_SERVICES_Donations::TAXONOMY);
			}
		}
		return $is;
	}
}

// Filter to detect current page inheritance key
if ( !function_exists( 'cleaning_services_trx_donations_detect_inheritance_key' ) ) {
	//Handler of add_filter('cleaning_services_filter_detect_inheritance_key',	'cleaning_services_trx_donations_detect_inheritance_key', 9, 1);
	function cleaning_services_trx_donations_detect_inheritance_key($key) {
		if (!empty($key)) return $key;
		return cleaning_services_is_trx_donations_page() ? 'donations' : '';
	}
}

// Filter to detect current page slug
if ( !function_exists( 'cleaning_services_trx_donations_get_blog_type' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_type',	'cleaning_services_trx_donations_get_blog_type', 9, 2);
	function cleaning_services_trx_donations_get_blog_type($page, $query=null) {
		if (!empty($page)) return $page;
		if ($query && $query->is_tax(CLEANING_SERVICES_Donations::TAXONOMY) || is_tax(CLEANING_SERVICES_Donations::TAXONOMY))
			$page = 'donations_category';
		else if ($query && $query->get('post_type')==CLEANING_SERVICES_Donations::POST_TYPE || get_query_var('post_type')==CLEANING_SERVICES_Donations::POST_TYPE)
			$page = $query && $query->is_single() || is_single() ? 'donations_item' : 'donations';
		return $page;
	}
}

// Filter to detect current page title
if ( !function_exists( 'cleaning_services_trx_donations_get_blog_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_title',	'cleaning_services_trx_donations_get_blog_title', 9, 2);
	function cleaning_services_trx_donations_get_blog_title($title, $page) {
		if (!empty($title)) return $title;
		if ( cleaning_services_strpos($page, 'donations')!==false ) {
			if ( $page == 'donations_category' ) {
				$term = get_term_by( 'slug', get_query_var( CLEANING_SERVICES_Donations::TAXONOMY ), CLEANING_SERVICES_Donations::TAXONOMY, OBJECT);
				$title = $term->name;
			} else if ( $page == 'donations_item' ) {
				$title = cleaning_services_get_post_title();
			} else {
				$title = esc_html__('All donations', 'cleaning-services');
			}
		}

		return $title;
	}
}

// Filter to detect stream page title
if ( !function_exists( 'cleaning_services_trx_donations_get_stream_page_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_trx_donations_get_stream_page_title', 9, 2);
	function cleaning_services_trx_donations_get_stream_page_title($title, $page) {
		if (!empty($title)) return $title;
		if (cleaning_services_strpos($page, 'donations')!==false) {
			if (($page_id = cleaning_services_trx_donations_get_stream_page_id(0, $page=='donations' ? 'blog-donations' : $page)) > 0)
				$title = cleaning_services_get_post_title($page_id);
			else
				$title = esc_html__('All donations', 'cleaning-services');				
		}
		return $title;
	}
}

// Filter to detect stream page ID
if ( !function_exists( 'cleaning_services_trx_donations_get_stream_page_id' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_trx_donations_get_stream_page_id', 9, 2);
	function cleaning_services_trx_donations_get_stream_page_id($id, $page) {
		if (!empty($id)) return $id;
		if (cleaning_services_strpos($page, 'donations')!==false) $id = cleaning_services_get_template_page_id('blog-donations');
		return $id;
	}
}

// Filter to detect stream page URL
if ( !function_exists( 'cleaning_services_trx_donations_get_stream_page_link' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_trx_donations_get_stream_page_link', 9, 2);
	function cleaning_services_trx_donations_get_stream_page_link($url, $page) {
		if (!empty($url)) return $url;
		if (cleaning_services_strpos($page, 'donations')!==false) {
			$id = cleaning_services_get_template_page_id('blog-donations');
			if ($id) $url = get_permalink($id);
		}
		return $url;
	}
}

// Filter to detect current taxonomy
if ( !function_exists( 'cleaning_services_trx_donations_get_current_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_trx_donations_get_current_taxonomy', 9, 2);
	function cleaning_services_trx_donations_get_current_taxonomy($tax, $page) {
		if (!empty($tax)) return $tax;
		if ( cleaning_services_strpos($page, 'donations')!==false ) {
			$tax = CLEANING_SERVICES_Donations::TAXONOMY;
		}
		return $tax;
	}
}

// Return taxonomy name (slug) if current page is this taxonomy page
if ( !function_exists( 'cleaning_services_trx_donations_is_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_is_taxonomy',	'cleaning_services_trx_donations_is_taxonomy', 9, 2);
	function cleaning_services_trx_donations_is_taxonomy($tax, $query=null) {
		if (!empty($tax))
			return $tax;
		else 
			return $query && $query->get(CLEANING_SERVICES_Donations::TAXONOMY)!='' || is_tax(CLEANING_SERVICES_Donations::TAXONOMY) ? CLEANING_SERVICES_Donations::TAXONOMY : '';
	}
}

// Add custom post type and/or taxonomies arguments to the query
if ( !function_exists( 'cleaning_services_trx_donations_query_add_filters' ) ) {
	//Handler of add_filter('cleaning_services_filter_query_add_filters',	'cleaning_services_trx_donations_query_add_filters', 9, 2);
	function cleaning_services_trx_donations_query_add_filters($args, $filter) {
		if ($filter == 'donations') {
			$args['post_type'] = CLEANING_SERVICES_Donations::POST_TYPE;
		}
		return $args;
	}
}

// Add custom post type to the list
if ( !function_exists( 'cleaning_services_trx_donations_list_post_types' ) ) {
	//Handler of add_filter('cleaning_services_filter_list_post_types',		'cleaning_services_trx_donations_list_post_types');
	function cleaning_services_trx_donations_list_post_types($list) {
		$list[CLEANING_SERVICES_Donations::POST_TYPE] = esc_html__('Donations', 'cleaning-services');
		return $list;
	}
}


// Add shortcode in the shortcodes list
if (!function_exists('cleaning_services_trx_donations_reg_shortcodes')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list',	'cleaning_services_trx_donations_reg_shortcodes');
	function cleaning_services_trx_donations_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$plugin = CLEANING_SERVICES_Donations::get_instance();
			$donations_groups = cleaning_services_get_list_terms(false, CLEANING_SERVICES_Donations::TAXONOMY);

			cleaning_services_array_insert_before($CLEANING_SERVICES_GLOBALS['shortcodes'], 'trx_dropcaps', array(

				// Cleaning Services Donations form
				"trx_donations_form" => array(
					"title" => esc_html__("Donations form", 'cleaning-services'),
					"desc" => esc_html__("Insert Cleaning Services Donations form", 'cleaning-services'),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"title" => array(
							"title" => esc_html__("Title", 'cleaning-services'),
							"desc" => esc_html__("Title for the donations form", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"subtitle" => array(
							"title" => esc_html__("Subtitle", 'cleaning-services'),
							"desc" => esc_html__("Subtitle for the donations form", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"description" => array(
							"title" => esc_html__("Description", 'cleaning-services'),
							"desc" => esc_html__("Short description for the donations form", 'cleaning-services'),
							"value" => "",
							"type" => "textarea"
						),
						"align" => array(
							"title" => esc_html__("Alignment", 'cleaning-services'),
							"desc" => esc_html__("Alignment of the donations form", 'cleaning-services'),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['align']
						),
						"account" => array(
							"title" => esc_html__("PayPal account", 'cleaning-services'),
							"desc" => esc_html__("PayPal account's e-mail. If empty - used from Cleaning Services Donations settings", 'cleaning-services'),
							"divider" => true,
							"value" => "",
							"type" => "text"
						),
						"sandbox" => array(
							"title" => esc_html__("Sandbox mode", 'cleaning-services'),
							"desc" => esc_html__("Use PayPal sandbox to test payments", 'cleaning-services'),
							"dependency" => array(
								'account' => array('not_empty')
							),
							"value" => "yes",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"amount" => array(
							"title" => esc_html__("Default amount", 'cleaning-services'),
							"desc" => esc_html__("Specify amount, initially selected in the form", 'cleaning-services'),
							"dependency" => array(
								'account' => array('not_empty')
							),
							"value" => 5,
							"min" => 1,
							"step" => 5,
							"type" => "spinner"
						),
						"currency" => array(
							"title" => esc_html__("Currency", 'cleaning-services'),
							"desc" => esc_html__("Select payment's currency", 'cleaning-services'),
							"dependency" => array(
								'account' => array('not_empty')
							),
							"divider" => true,
							"value" => "",
							"type" => "select",
							"style" => "list",
							"multiple" => true,
							"options" => cleaning_services_array_merge(array(0 => esc_html__('- Select currency -', 'cleaning-services')), $plugin->currency_codes)
						),
						"width" => cleaning_services_shortcodes_width(),
						"top" => $CLEANING_SERVICES_GLOBALS['sc_params']['top'],
						"bottom" => $CLEANING_SERVICES_GLOBALS['sc_params']['bottom'],
						"left" => $CLEANING_SERVICES_GLOBALS['sc_params']['left'],
						"right" => $CLEANING_SERVICES_GLOBALS['sc_params']['right'],
						"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
						"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
						"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
					)
				),
				
				
				// Cleaning Services Donations form
				"trx_donations_list" => array(
					"title" => esc_html__("Donations list", 'cleaning-services'),
					"desc" => esc_html__("Insert Cleaning Services Doantions list", 'cleaning-services'),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"title" => array(
							"title" => esc_html__("Title", 'cleaning-services'),
							"desc" => esc_html__("Title for the donations list", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"subtitle" => array(
							"title" => esc_html__("Subtitle", 'cleaning-services'),
							"desc" => esc_html__("Subtitle for the donations list", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"description" => array(
							"title" => esc_html__("Description", 'cleaning-services'),
							"desc" => esc_html__("Short description for the donations list", 'cleaning-services'),
							"value" => "",
							"type" => "textarea"
						),
						"link" => array(
							"title" => esc_html__("Button URL", 'cleaning-services'),
							"desc" => esc_html__("Link URL for the button at the bottom of the block", 'cleaning-services'),
							"divider" => true,
							"value" => "",
							"type" => "text"
						),
						"link_caption" => array(
							"title" => esc_html__("Button caption", 'cleaning-services'),
							"desc" => esc_html__("Caption for the button at the bottom of the block", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"style" => array(
							"title" => esc_html__("List style", 'cleaning-services'),
							"desc" => esc_html__("Select style to display donations", 'cleaning-services'),
							"value" => "excerpt",
							"type" => "select",
							"options" => array(
								'excerpt' => esc_html__('Excerpt', 'cleaning-services')
							)
						),
						"readmore" => array(
							"title" => esc_html__("Read more text", 'cleaning-services'),
							"desc" => esc_html__("Text of the 'Read more' link", 'cleaning-services'),
							"value" => esc_html__('Read more', 'cleaning-services'),
							"type" => "text"
						),
						"cat" => array(
							"title" => esc_html__("Categories", 'cleaning-services'),
							"desc" => esc_html__("Select categories (groups) to show donations. If empty - select donations from any category (group) or from IDs list", 'cleaning-services'),
							"divider" => true,
							"value" => "",
							"type" => "select",
							"style" => "list",
							"multiple" => true,
							"options" => cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $donations_groups)
						),
						"count" => array(
							"title" => esc_html__("Number of donations", 'cleaning-services'),
							"desc" => esc_html__("How many donations will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'),
							"value" => 3,
							"min" => 1,
							"max" => 100,
							"type" => "spinner"
						),
						"columns" => array(
							"title" => esc_html__("Columns", 'cleaning-services'),
							"desc" => esc_html__("How many columns use to show donations list", 'cleaning-services'),
							"value" => 3,
							"min" => 2,
							"max" => 6,
							"step" => 1,
							"type" => "spinner"
						),
						"offset" => array(
							"title" => esc_html__("Offset before select posts", 'cleaning-services'),
							"desc" => esc_html__("Skip posts before select next part.", 'cleaning-services'),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 0,
							"min" => 0,
							"type" => "spinner"
						),
						"orderby" => array(
							"title" => esc_html__("Donadions order by", 'cleaning-services'),
							"desc" => esc_html__("Select desired sorting method", 'cleaning-services'),
							"value" => "date",
							"type" => "select",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['sorting']
						),
						"order" => array(
							"title" => esc_html__("Donations order", 'cleaning-services'),
							"desc" => esc_html__("Select donations order", 'cleaning-services'),
							"value" => "desc",
							"type" => "switch",
							"size" => "big",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
						),
						"ids" => array(
							"title" => esc_html__("Donations IDs list", 'cleaning-services'),
							"desc" => esc_html__("Comma separated list of donations ID. If set - parameters above are ignored!", 'cleaning-services'),
							"value" => "",
							"type" => "text"
						),
						"top" => $CLEANING_SERVICES_GLOBALS['sc_params']['top'],
						"bottom" => $CLEANING_SERVICES_GLOBALS['sc_params']['bottom'],
						"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
						"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
						"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
					)
				)

			));
		}
	}
}


// Add shortcode in the VC shortcodes list
if (!function_exists('cleaning_services_trx_donations_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_trx_donations_reg_shortcodes_vc');
	function cleaning_services_trx_donations_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;

		$plugin = CLEANING_SERVICES_Donations::get_instance();
		$donations_groups = cleaning_services_get_list_terms(false, CLEANING_SERVICES_Donations::TAXONOMY);

		// Cleaning Services Donations form
		vc_map( array(
				"base" => "trx_donations_form",
				"name" => esc_html__("Donations form", 'cleaning-services'),
				"description" => esc_html__("Insert Cleaning Services Donations form", 'cleaning-services'),
				"category" => esc_html__('Content', 'cleaning-services'),
				'icon' => 'icon_trx_donations_form',
				"class" => "trx_sc_single trx_sc_donations_form",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", 'cleaning-services'),
						"description" => esc_html__("Title for the donations form", 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => esc_html__("Subtitle", 'cleaning-services'),
						"description" => esc_html__("Subtitle for the donations form", 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => esc_html__("Description", 'cleaning-services'),
						"description" => esc_html__("Description for the donations form", 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textarea"
					),
					array(
						"param_name" => "align",
						"heading" => esc_html__("Alignment", 'cleaning-services'),
						"description" => esc_html__("Alignment of the donations form", 'cleaning-services'),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "account",
						"heading" => esc_html__("PayPal account", 'cleaning-services'),
						"description" => esc_html__("PayPal account's e-mail. If empty - used from Cleaning Services Donations settings", 'cleaning-services'),
						"admin_label" => true,
						"group" => esc_html__('PayPal', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "sandbox",
						"heading" => esc_html__("Sandbox mode", 'cleaning-services'),
						"description" => esc_html__("Use PayPal sandbox to test payments", 'cleaning-services'),
						"admin_label" => true,
						"group" => esc_html__('PayPal', 'cleaning-services'),
						'dependency' => array(
							'element' => 'account',
							'not_empty' => true
						),
						"class" => "",
						"value" => array("Sandbox mode" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "amount",
						"heading" => esc_html__("Default amount", 'cleaning-services'),
						"description" => esc_html__("Specify amount, initially selected in the form", 'cleaning-services'),
						"admin_label" => true,
						"group" => esc_html__('PayPal', 'cleaning-services'),
						"class" => "",
						"value" => "5",
						"type" => "textfield"
					),
					array(
						"param_name" => "currency",
						"heading" => esc_html__("Currency", 'cleaning-services'),
						"description" => esc_html__("Select payment's currency", 'cleaning-services'),
						"class" => "",
						"value" => array_flip(cleaning_services_array_merge(array(0 => esc_html__('- Select currency -', 'cleaning-services')), $plugin->currency_codes)),
						"type" => "dropdown"
					),
					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css'],
					cleaning_services_vc_width(),
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_top'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_bottom'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_left'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_right']
				)
			) );
			
		class WPBakeryShortCode_Trx_Donations_Form extends CLEANING_SERVICES_VC_ShortCodeSingle {}



		// Cleaning Services Donations list
		vc_map( array(
				"base" => "trx_donations_list",
				"name" => esc_html__("Donations list", 'cleaning-services'),
				"description" => esc_html__("Insert Cleaning Services Donations list", 'cleaning-services'),
				"category" => esc_html__('Content', 'cleaning-services'),
				'icon' => 'icon_trx_donations_list',
				"class" => "trx_sc_single trx_sc_donations_list",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => esc_html__("List style", 'cleaning-services'),
						"description" => esc_html__("Select style to display donations", 'cleaning-services'),
						"class" => "",
						"value" => array(
							esc_html__('Excerpt', 'cleaning-services') => 'excerpt'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", 'cleaning-services'),
						"description" => esc_html__("Title for the donations form", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => esc_html__("Subtitle", 'cleaning-services'),
						"description" => esc_html__("Subtitle for the donations form", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => esc_html__("Description", 'cleaning-services'),
						"description" => esc_html__("Description for the donations form", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textarea"
					),
					array(
						"param_name" => "link",
						"heading" => esc_html__("Button URL", 'cleaning-services'),
						"description" => esc_html__("Link URL for the button at the bottom of the block", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link_caption",
						"heading" => esc_html__("Button caption", 'cleaning-services'),
						"description" => esc_html__("Caption for the button at the bottom of the block", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "readmore",
						"heading" => esc_html__("Read more text", 'cleaning-services'),
						"description" => esc_html__("Text of the 'Read more' link", 'cleaning-services'),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => esc_html__('Read more', 'cleaning-services'),
						"type" => "textfield"
					),
					array(
						"param_name" => "cat",
						"heading" => esc_html__("Categories", 'cleaning-services'),
						"description" => esc_html__("Select category to show donations. If empty - select donations from any category (group) or from IDs list", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"class" => "",
						"value" => array_flip(cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $donations_groups)),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => esc_html__("How many columns use to show donations", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => esc_html__("Number of posts", 'cleaning-services'),
						"description" => esc_html__("How many posts will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => esc_html__("Offset before select posts", 'cleaning-services'),
						"description" => esc_html__("Skip posts before select next part.", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Post sorting", 'cleaning-services'),
						"description" => esc_html__("Select desired posts sorting method", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Post order", 'cleaning-services'),
						"description" => esc_html__("Select desired posts order", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("client's IDs list", 'cleaning-services'),
						"description" => esc_html__("Comma separated list of donation's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'cleaning-services'),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'cats',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),

					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_top'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_bottom']
				)
			) );
			
		class WPBakeryShortCode_Trx_Donations_List extends CLEANING_SERVICES_VC_ShortCodeSingle {}

	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_trx_donations_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_trx_donations_required_plugins');
	function cleaning_services_trx_donations_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('trx_donations', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'Cleaning Services Donations',
					'slug' 		=> 'trx_donations',
					'source'	=> cleaning_services_get_file_dir('plugins/install/trx_donations.zip'),
					'required' 	=> false
					);
		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check in the required plugins
if ( !function_exists( 'cleaning_services_trx_donations_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_trx_donations_importer_required_plugins' );
	function cleaning_services_trx_donations_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('trx_donations', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_trx_donations() )
			$not_installed .= '<br>Cleaning Services Donations';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_trx_donations_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_trx_donations_importer_set_options' );
	function cleaning_services_trx_donations_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['additional_options'][] = 'trx_donations_options';		// Add slugs to export options for this plugin

		}
		return $options;
	}
}
?>