<?php
/* Woocommerce support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('cleaning_services_woocommerce_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_woocommerce_theme_setup', 1 );
	function cleaning_services_woocommerce_theme_setup() {

		if (cleaning_services_exists_woocommerce()) {
			add_action('cleaning_services_action_add_styles', 				'cleaning_services_woocommerce_frontend_scripts' );

			// Detect current page type, taxonomy and title (for custom post_types use priority < 10 to fire it handles early, than for standard post types)
			add_filter('cleaning_services_filter_get_blog_type',				'cleaning_services_woocommerce_get_blog_type', 9, 2);
			add_filter('cleaning_services_filter_get_blog_title',			'cleaning_services_woocommerce_get_blog_title', 9, 2);
			add_filter('cleaning_services_filter_get_current_taxonomy',		'cleaning_services_woocommerce_get_current_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_is_taxonomy',				'cleaning_services_woocommerce_is_taxonomy', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_title',		'cleaning_services_woocommerce_get_stream_page_title', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_link',		'cleaning_services_woocommerce_get_stream_page_link', 9, 2);
			add_filter('cleaning_services_filter_get_stream_page_id',		'cleaning_services_woocommerce_get_stream_page_id', 9, 2);
			add_filter('cleaning_services_filter_detect_inheritance_key',	'cleaning_services_woocommerce_detect_inheritance_key', 9, 1);
			add_filter('cleaning_services_filter_detect_template_page_id',	'cleaning_services_woocommerce_detect_template_page_id', 9, 2);
			add_filter('cleaning_services_filter_orderby_need',				'cleaning_services_woocommerce_orderby_need', 9, 2);

			add_filter('cleaning_services_filter_list_post_types', 			'cleaning_services_woocommerce_list_post_types', 10, 1);

			add_action('cleaning_services_action_shortcodes_list', 			'cleaning_services_woocommerce_reg_shortcodes', 20);
			if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
				add_action('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_woocommerce_reg_shortcodes_vc', 20);

			if (is_admin()) {
				add_filter( 'cleaning_services_filter_importer_options',				'cleaning_services_woocommerce_importer_set_options' );
				add_action( 'cleaning_services_action_importer_after_import_posts',	'cleaning_services_woocommerce_importer_after_import_posts', 10, 1 );
			}
		}

		if (is_admin()) {
			add_filter( 'cleaning_services_filter_importer_required_plugins',		'cleaning_services_woocommerce_importer_required_plugins' );
			add_filter( 'cleaning_services_filter_required_plugins',					'cleaning_services_woocommerce_required_plugins' );
		}
	}
}

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if (!function_exists('cleaning_services_woocommerce_theme_setup1')) {
    add_action( 'after_setup_theme', 'cleaning_services_woocommerce_theme_setup1', 1 );
    function cleaning_services_woocommerce_theme_setup1() {

        add_theme_support( 'woocommerce' );

        // Next setting from the WooCommerce 3.0+ enable built-in image zoom on the single product page
        add_theme_support( 'wc-product-gallery-zoom' );

        // Next setting from the WooCommerce 3.0+ enable built-in image slider on the single product page
        add_theme_support( 'wc-product-gallery-slider' );

        // Next setting from the WooCommerce 3.0+ enable built-in image lightbox on the single product page
        add_theme_support( 'wc-product-gallery-lightbox' );
    }
}

if ( !function_exists( 'cleaning_services_woocommerce_settings_theme_setup2' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_woocommerce_settings_theme_setup2', 3 );
	function cleaning_services_woocommerce_settings_theme_setup2() {
		if (cleaning_services_exists_woocommerce()) {
			// Add WooCommerce pages in the Theme inheritance system
			cleaning_services_add_theme_inheritance( array( 'woocommerce' => array(
				'stream_template' => '',
				'single_template' => '',
				'taxonomy' => array('product_cat'),
				'taxonomy_tags' => array('product_tag'),
				'post_type' => array('product'),
				'override' => 'page'
				) )
			);

			// Add WooCommerce specific options in the Theme Options
			global $CLEANING_SERVICES_GLOBALS;

			cleaning_services_array_insert_before($CLEANING_SERVICES_GLOBALS['options'], 'partition_service', array(
				
				"partition_woocommerce" => array(
					"title" => esc_html__('WooCommerce', 'cleaning-services'),
					"icon" => "iconadmin-basket",
					"type" => "partition"),

				"info_wooc_1" => array(
					"title" => esc_html__('WooCommerce products list parameters', 'cleaning-services'),
					"desc" => esc_html__("Select WooCommerce products list's style and crop parameters", 'cleaning-services'),
					"type" => "info"),
		
				"shop_mode" => array(
					"title" => esc_html__('Shop list style',  'cleaning-services'),
					"desc" => esc_html__("WooCommerce products list's style: thumbs or list with description", 'cleaning-services'),
					"std" => "thumbs",
					"divider" => false,
					"options" => array(
						'thumbs' => esc_html__('Thumbs', 'cleaning-services'),
						'list' => esc_html__('List', 'cleaning-services')
					),
					"type" => "checklist"),
		
				"show_mode_buttons" => array(
					"title" => esc_html__('Show style buttons',  'cleaning-services'),
					"desc" => esc_html__("Show buttons to allow visitors change list style", 'cleaning-services'),
					"std" => "yes",
					"options" => $CLEANING_SERVICES_GLOBALS['options_params']['list_yes_no'],
					"type" => "switch"),

				"shop_loop_columns" => array(
					"title" => esc_html__('Shop columns',  'cleaning-services'),
					"desc" => esc_html__("How many columns used to show products on shop page", 'cleaning-services'),
					"override" => "category,post,page",
					"std" => "3",
					"step" => 1,
					"min" => 1,
					"max" => 6,
					"type" => "spinner"),

				"show_currency" => array(
					"title" => esc_html__('Show currency selector', 'cleaning-services'),
					"desc" => esc_html__('Show currency selector in the user menu', 'cleaning-services'),
					"std" => "yes",
					"options" => $CLEANING_SERVICES_GLOBALS['options_params']['list_yes_no'],
					"type" => "switch"),
		
				"show_cart" => array(
					"title" => esc_html__('Show cart button', 'cleaning-services'),
					"desc" => esc_html__('Show cart button in the user menu', 'cleaning-services'),
					"std" => "shop",
					"options" => array(
						'hide'   => esc_html__('Hide', 'cleaning-services'),
						'always' => esc_html__('Always', 'cleaning-services'),
						'shop'   => esc_html__('Only on shop pages', 'cleaning-services')
					),
					"type" => "checklist"),

				"crop_product_thumb" => array(
					"title" => esc_html__("Crop product's thumbnail",  'cleaning-services'),
					"desc" => esc_html__("Crop product's thumbnails on search results page or scale it", 'cleaning-services'),
					"std" => "no",
					"options" => $CLEANING_SERVICES_GLOBALS['options_params']['list_yes_no'],
					"type" => "switch")
				
				)
			);

		}
	}
}

// WooCommerce hooks
if (!function_exists('cleaning_services_woocommerce_theme_setup3')) {
	add_action( 'cleaning_services_action_after_init_theme', 'cleaning_services_woocommerce_theme_setup3' );
	function cleaning_services_woocommerce_theme_setup3() {

		if (cleaning_services_exists_woocommerce()) {

			add_action(    'woocommerce_before_subcategory_title',		'cleaning_services_woocommerce_open_thumb_wrapper', 9 );
			add_action(    'woocommerce_before_shop_loop_item_title',	'cleaning_services_woocommerce_open_thumb_wrapper', 9 );

			add_action(    'woocommerce_before_subcategory_title',		'cleaning_services_woocommerce_open_item_wrapper', 20 );
			add_action(    'woocommerce_before_shop_loop_item_title',	'cleaning_services_woocommerce_open_item_wrapper', 20 );

			add_action(    'woocommerce_after_subcategory',				'cleaning_services_woocommerce_close_item_wrapper', 20 );
			add_action(    'woocommerce_after_shop_loop_item',			'cleaning_services_woocommerce_close_item_wrapper', 20 );

			add_action(    'woocommerce_after_shop_loop_item_title',	'cleaning_services_woocommerce_after_shop_loop_item_title', 7);

			add_action(    'woocommerce_after_subcategory_title',		'cleaning_services_woocommerce_after_subcategory_title', 10 );

            // Wrap category title into link
            remove_action( 'woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10 );
            add_action( 'woocommerce_shop_loop_subcategory_title',  'cleaning_services_woocommerce_shop_loop_subcategory_title', 9, 1);
		}

		if (cleaning_services_is_woocommerce_page()) {
			
			remove_action( 'woocommerce_sidebar', 						'woocommerce_get_sidebar', 10 );					// Remove WOOC sidebar
			
			remove_action( 'woocommerce_before_main_content',			'woocommerce_output_content_wrapper', 10);
			add_action(    'woocommerce_before_main_content',			'cleaning_services_woocommerce_wrapper_start', 10);
			
			remove_action( 'woocommerce_after_main_content',			'woocommerce_output_content_wrapper_end', 10);		
			add_action(    'woocommerce_after_main_content',			'cleaning_services_woocommerce_wrapper_end', 10);

			add_action(    'woocommerce_show_page_title',				'cleaning_services_woocommerce_show_page_title', 10);

			remove_action( 'woocommerce_single_product_summary',		'woocommerce_template_single_title', 5);		
			add_action(    'woocommerce_single_product_summary',		'cleaning_services_woocommerce_show_product_title', 5 );

			add_action(    'woocommerce_before_shop_loop', 				'cleaning_services_woocommerce_before_shop_loop', 10 );

			remove_action( 'woocommerce_after_shop_loop',				'woocommerce_pagination', 10 );
			add_action(    'woocommerce_after_shop_loop',				'cleaning_services_woocommerce_pagination', 10 );

			add_action(    'woocommerce_product_meta_end',				'cleaning_services_woocommerce_show_product_id', 10);

			add_filter(    'woocommerce_output_related_products_args',	'cleaning_services_woocommerce_output_related_products_args' );
			
			add_filter(    'woocommerce_product_thumbnails_columns',	'cleaning_services_woocommerce_product_thumbnails_columns' );

			add_filter(    'get_product_search_form',					'cleaning_services_woocommerce_get_product_search_form' );

			add_filter(    'post_class',								'cleaning_services_woocommerce_loop_shop_columns_class' );
			add_action(    'the_title',									'cleaning_services_woocommerce_the_title');
			
			cleaning_services_enqueue_popup();
		}
	}
}



// Check if WooCommerce installed and activated
if ( !function_exists( 'cleaning_services_exists_woocommerce' ) ) {
	function cleaning_services_exists_woocommerce() {
		return class_exists('Woocommerce');
	}
}

// Return true, if current page is any woocommerce page
if ( !function_exists( 'cleaning_services_is_woocommerce_page' ) ) {
	function cleaning_services_is_woocommerce_page() {
		$rez = false;
		if (cleaning_services_exists_woocommerce()) {
			global $CLEANING_SERVICES_GLOBALS;
			if (!empty($CLEANING_SERVICES_GLOBALS['pre_query'])) {
				$id = isset($CLEANING_SERVICES_GLOBALS['pre_query']->queried_object_id) ? $CLEANING_SERVICES_GLOBALS['pre_query']->queried_object_id : 0;
				$rez = $CLEANING_SERVICES_GLOBALS['pre_query']->get('post_type')=='product' 
						|| $id==wc_get_page_id('shop')
						|| $id==wc_get_page_id('cart')
						|| $id==wc_get_page_id('checkout')
						|| $id==wc_get_page_id('myaccount')
						|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax( 'product_cat' )
						|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax( 'product_tag' )
						|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax( get_object_taxonomies( 'product' ) );
						
			} else
				$rez = is_shop() || is_product() || is_product_category() || is_product_tag() || is_product_taxonomy() || is_cart() || is_checkout() || is_account_page();
		}
		return $rez;
	}
}

// Filter to detect current page inheritance key
if ( !function_exists( 'cleaning_services_woocommerce_detect_inheritance_key' ) ) {
	//Handler of add_filter('cleaning_services_filter_detect_inheritance_key',	'cleaning_services_woocommerce_detect_inheritance_key', 9, 1);
	function cleaning_services_woocommerce_detect_inheritance_key($key) {
		if (!empty($key)) return $key;
		return cleaning_services_is_woocommerce_page() ? 'woocommerce' : '';
	}
}

// Filter to detect current template page id
if ( !function_exists( 'cleaning_services_woocommerce_detect_template_page_id' ) ) {
	//Handler of add_filter('cleaning_services_filter_detect_template_page_id',	'cleaning_services_woocommerce_detect_template_page_id', 9, 2);
	function cleaning_services_woocommerce_detect_template_page_id($id, $key) {
		if (!empty($id)) return $id;
		if ($key == 'woocommerce_cart')				$id = get_option('woocommerce_cart_page_id');
		else if ($key == 'woocommerce_checkout')	$id = get_option('woocommerce_checkout_page_id');
		else if ($key == 'woocommerce_account')		$id = get_option('woocommerce_account_page_id');
		else if ($key == 'woocommerce')				$id = get_option('woocommerce_shop_page_id');
		return $id;
	}
}

// Filter to detect current page type (slug)
if ( !function_exists( 'cleaning_services_woocommerce_get_blog_type' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_type',	'cleaning_services_woocommerce_get_blog_type', 9, 2);
	function cleaning_services_woocommerce_get_blog_type($page, $query=null) {
		if (!empty($page)) return $page;
		
		if (is_shop()) 					$page = 'woocommerce_shop';
		else if ($query && $query->get('post_type')=='product' || is_product())		$page = 'woocommerce_product';
		else if ($query && $query->get('product_tag')!='' || is_product_tag())		$page = 'woocommerce_tag';
		else if ($query && $query->get('product_cat')!='' || is_product_category())	$page = 'woocommerce_category';
		else if (is_cart())				$page = 'woocommerce_cart';
		else if (is_checkout())			$page = 'woocommerce_checkout';
		else if (is_account_page())		$page = 'woocommerce_account';
		else if (is_woocommerce())		$page = 'woocommerce';
		return $page;
	}
}

// Filter to detect current page title
if ( !function_exists( 'cleaning_services_woocommerce_get_blog_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_title',	'cleaning_services_woocommerce_get_blog_title', 9, 2);
	function cleaning_services_woocommerce_get_blog_title($title, $page) {
		if (!empty($title)) return $title;
		
		if ( cleaning_services_strpos($page, 'woocommerce')!==false ) {
			if ( $page == 'woocommerce_category' ) {
				$term = get_term_by( 'slug', get_query_var( 'product_cat' ), 'product_cat', OBJECT);
				$title = $term->name;
			} else if ( $page == 'woocommerce_tag' ) {
				$term = get_term_by( 'slug', get_query_var( 'product_tag' ), 'product_tag', OBJECT);
				$title = esc_html__('Tag:', 'cleaning-services') . ' ' . esc_html($term->name);
			} else if ( $page == 'woocommerce_cart' ) {
				$title = esc_html__( 'Your cart', 'cleaning-services' );
			} else if ( $page == 'woocommerce_checkout' ) {
				$title = esc_html__( 'Checkout', 'cleaning-services' );
			} else if ( $page == 'woocommerce_account' ) {
				$title = esc_html__( 'Account', 'cleaning-services' );
			} else if ( $page == 'woocommerce_product' ) {
				$title = cleaning_services_get_post_title();
			} else if (($page_id=get_option('woocommerce_shop_page_id')) > 0) {
				$title = cleaning_services_get_post_title($page_id);
			} else {
				$title = esc_html__( 'Shop', 'cleaning-services' );
			}
		}
		
		return $title;
	}
}

// Filter to detect stream page title
if ( !function_exists( 'cleaning_services_woocommerce_get_stream_page_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_woocommerce_get_stream_page_title', 9, 2);
	function cleaning_services_woocommerce_get_stream_page_title($title, $page) {
		if (!empty($title)) return $title;
		if (cleaning_services_strpos($page, 'woocommerce')!==false) {
			if (($page_id = cleaning_services_woocommerce_get_stream_page_id(0, $page)) > 0)
				$title = cleaning_services_get_post_title($page_id);
			else
				$title = esc_html__('Shop', 'cleaning-services');				
		}
		return $title;
	}
}

// Filter to detect stream page ID
if ( !function_exists( 'cleaning_services_woocommerce_get_stream_page_id' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_woocommerce_get_stream_page_id', 9, 2);
	function cleaning_services_woocommerce_get_stream_page_id($id, $page) {
		if (!empty($id)) return $id;
		if (cleaning_services_strpos($page, 'woocommerce')!==false) {
			$id = get_option('woocommerce_shop_page_id');
		}
		return $id;
	}
}

// Filter to detect stream page link
if ( !function_exists( 'cleaning_services_woocommerce_get_stream_page_link' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_woocommerce_get_stream_page_link', 9, 2);
	function cleaning_services_woocommerce_get_stream_page_link($url, $page) {
		if (!empty($url)) return $url;
		if (cleaning_services_strpos($page, 'woocommerce')!==false) {
			$id = cleaning_services_woocommerce_get_stream_page_id(0, $page);
			if ($id) $url = get_permalink($id);
		}
		return $url;
	}
}

// Filter to detect current taxonomy
if ( !function_exists( 'cleaning_services_woocommerce_get_current_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_woocommerce_get_current_taxonomy', 9, 2);
	function cleaning_services_woocommerce_get_current_taxonomy($tax, $page) {
		if (!empty($tax)) return $tax;
		if ( cleaning_services_strpos($page, 'woocommerce')!==false ) {
			$tax = 'product_cat';
		}
		return $tax;
	}
}

// Return taxonomy name (slug) if current page is this taxonomy page
if ( !function_exists( 'cleaning_services_woocommerce_is_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_is_taxonomy',	'cleaning_services_woocommerce_is_taxonomy', 9, 2);
	function cleaning_services_woocommerce_is_taxonomy($tax, $query=null) {
		if (!empty($tax))
			return $tax;
		else 
			return $query && $query->get('product_cat')!='' || is_product_category() ? 'product_cat' : '';
	}
}

// Return false if current plugin not need theme orderby setting
if ( !function_exists( 'cleaning_services_woocommerce_orderby_need' ) ) {
	//Handler of add_filter('cleaning_services_filter_orderby_need',	'cleaning_services_woocommerce_orderby_need', 9, 2);
	function cleaning_services_woocommerce_orderby_need($need, $query=null) {
		if ($need == false)
			return $need;
		else
			return $query && !($query->get('post_type')=='product' || $query->get('product_cat')!='' || $query->get('product_tag')!='');
	}
}

// Add custom post type into list
if ( !function_exists( 'cleaning_services_woocommerce_list_post_types' ) ) {
	//Handler of add_filter('cleaning_services_filter_list_post_types', 	'cleaning_services_woocommerce_list_post_types', 10, 1);
	function cleaning_services_woocommerce_list_post_types($list) {
		$list['product'] = esc_html__('Products', 'cleaning-services');
		return $list;
	}
}


	
// Enqueue WooCommerce custom styles
if ( !function_exists( 'cleaning_services_woocommerce_frontend_scripts' ) ) {
	//Handler of add_action( 'cleaning_services_action_add_styles', 'cleaning_services_woocommerce_frontend_scripts' );
	function cleaning_services_woocommerce_frontend_scripts() {
		if (cleaning_services_is_woocommerce_page() || cleaning_services_get_custom_option('show_cart')=='always')
			wp_enqueue_style( 'cleaning-services-woo-style',  cleaning_services_get_file_url('css/woo-style.css'), array(), null );
	}
}

// Before main content
if ( !function_exists( 'cleaning_services_woocommerce_wrapper_start' ) ) {
	//Handler of add_action('woocommerce_before_main_content', 'cleaning_services_woocommerce_wrapper_start', 10);
	function cleaning_services_woocommerce_wrapper_start() {
		global $CLEANING_SERVICES_GLOBALS;
		if (is_product() || is_cart() || is_checkout() || is_account_page()) {
			?>
			<article class="post_item post_item_single post_item_product">
			<?php
		} else {
			?>
			<div class="list_products shop_mode_<?php echo !empty($CLEANING_SERVICES_GLOBALS['shop_mode']) ? $CLEANING_SERVICES_GLOBALS['shop_mode'] : 'thumbs'; ?>">
			<?php
		}
	}
}

// After main content
if ( !function_exists( 'cleaning_services_woocommerce_wrapper_end' ) ) {
	//Handler of add_action('woocommerce_after_main_content', 'cleaning_services_woocommerce_wrapper_end', 10);
	function cleaning_services_woocommerce_wrapper_end() {
		if (is_product() || is_cart() || is_checkout() || is_account_page()) {
			?>
			</article>	<!-- .post_item -->
			<?php
		} else {
			?>
			</div>	<!-- .list_products -->
			<?php
		}
	}
}

// Check to show page title
if ( !function_exists( 'cleaning_services_woocommerce_show_page_title' ) ) {
	//Handler of add_action('woocommerce_show_page_title', 'cleaning_services_woocommerce_show_page_title', 10);
	function cleaning_services_woocommerce_show_page_title($defa=true) {
		return cleaning_services_get_custom_option('show_page_title')=='no';
	}
}

// Check to show product title
if ( !function_exists( 'cleaning_services_woocommerce_show_product_title' ) ) {
	//Handler of add_action( 'woocommerce_single_product_summary', 'cleaning_services_woocommerce_show_product_title', 5 );
	function cleaning_services_woocommerce_show_product_title() {
		if (cleaning_services_get_custom_option('show_post_title')=='yes' || cleaning_services_get_custom_option('show_page_title')=='no') {
			wc_get_template( 'single-product/title.php' );
		}
	}
}

// Add list mode buttons
if ( !function_exists( 'cleaning_services_woocommerce_before_shop_loop' ) ) {
	//Handler of add_action( 'woocommerce_before_shop_loop', 'cleaning_services_woocommerce_before_shop_loop', 10 );
	function cleaning_services_woocommerce_before_shop_loop() {
		global $CLEANING_SERVICES_GLOBALS;
		if (cleaning_services_get_custom_option('show_mode_buttons')=='yes') {
			echo '<div class="mode_buttons"><form action="' . esc_url( (home_url('/')) . (add_query_arg(array()))).'" method="post">'
				. '<input type="hidden" name="cleaning_services_shop_mode" value="'.esc_attr($CLEANING_SERVICES_GLOBALS['shop_mode']).'" />'
				. '<a href="#" class="woocommerce_thumbs icon-th" title="'.esc_attr__('Show products as thumbs', 'cleaning-services').'"></a>'
				. '<a href="#" class="woocommerce_list icon-th-list" title="'.esc_attr__('Show products as list', 'cleaning-services').'"></a>'
				. '</form></div>';
		}
	}
}


// Open thumbs wrapper for categories and products
if ( !function_exists( 'cleaning_services_woocommerce_open_thumb_wrapper' ) ) {
	//Handler of add_action( 'woocommerce_before_subcategory_title', 'cleaning_services_woocommerce_open_thumb_wrapper', 9 );
	//Handler of add_action( 'woocommerce_before_shop_loop_item_title', 'cleaning_services_woocommerce_open_thumb_wrapper', 9 );
	function cleaning_services_woocommerce_open_thumb_wrapper($cat='') {
		cleaning_services_set_global('in_product_item', true);
		?>
		<div class="post_item_wrap">
			<div class="post_featured">
				<div class="post_thumb">
					<a class="hover_icon hover_icon_link" href="<?php echo esc_url(get_permalink()); ?>">
		<?php
	}
}

// Open item wrapper for categories and products
if ( !function_exists( 'cleaning_services_woocommerce_open_item_wrapper' ) ) {
	//Handler of add_action( 'woocommerce_before_subcategory_title', 'cleaning_services_woocommerce_open_item_wrapper', 20 );
	//Handler of add_action( 'woocommerce_before_shop_loop_item_title', 'cleaning_services_woocommerce_open_item_wrapper', 20 );
	function cleaning_services_woocommerce_open_item_wrapper($cat='') {
		?>
				</a>
			</div>
		</div>
		<div class="post_content">
		<?php
	}
}

// Close item wrapper for categories and products
if ( !function_exists( 'cleaning_services_woocommerce_close_item_wrapper' ) ) {
	//Handler of add_action( 'woocommerce_after_subcategory', 'cleaning_services_woocommerce_close_item_wrapper', 20 );
	//Handler of add_action( 'woocommerce_after_shop_loop_item', 'cleaning_services_woocommerce_close_item_wrapper', 20 );
	function cleaning_services_woocommerce_close_item_wrapper($cat='') {
		?>
			</div>
		</div>
		<?php
		cleaning_services_set_global('in_product_item', false);
	}
}

// Add excerpt in output for the product in the list mode
if ( !function_exists( 'cleaning_services_woocommerce_after_shop_loop_item_title' ) ) {
	//Handler of add_action( 'woocommerce_after_shop_loop_item_title', 'cleaning_services_woocommerce_after_shop_loop_item_title', 7);
	function cleaning_services_woocommerce_after_shop_loop_item_title() {
		global $CLEANING_SERVICES_GLOBALS;
		if ($CLEANING_SERVICES_GLOBALS['shop_mode'] == 'list') {
		    $excerpt = apply_filters('the_excerpt', get_the_excerpt());
			echo '<div class="description">'.trim($excerpt).'</div>';
		}
	}
}

// Wrap category title into link
if ( !function_exists( 'cleaning_services_woocommerce_shop_loop_subcategory_title' ) ) {
    //Handler of the add_filter( 'woocommerce_shop_loop_subcategory_title', 'cleaning_services_woocommerce_shop_loop_subcategory_title' );
    function cleaning_services_woocommerce_shop_loop_subcategory_title($cat) {

        $cat->name = sprintf('<a href="%s">%s</a>', esc_url(get_term_link($cat->slug, 'product_cat')), $cat->name);
        ?>
        <h2 class="woocommerce-loop-category__title">
        <?php
            cleaning_services_show_layout($cat->name);

        if ( $cat->count > 0 ) {
            echo apply_filters( 'woocommerce_subcategory_count_html', ' <mark class="count">(' . esc_html( $cat->count ) . ')</mark>', $cat ); // WPCS: XSS ok.
        }
        ?>
        </h2><?php
    }
}

// Add excerpt in output for the product in the list mode
if ( !function_exists( 'cleaning_services_woocommerce_after_subcategory_title' ) ) {
	//Handler of add_action( 'woocommerce_after_subcategory_title', 'cleaning_services_woocommerce_after_subcategory_title', 10 );
	function cleaning_services_woocommerce_after_subcategory_title($category) {
		global $CLEANING_SERVICES_GLOBALS;
		if ($CLEANING_SERVICES_GLOBALS['shop_mode'] == 'list')
			echo '<div class="description">' . trim($category->description) . '</div>';
	}
}

// Add Product ID for single product
if ( !function_exists( 'cleaning_services_woocommerce_show_product_id' ) ) {
	//Handler of add_action( 'woocommerce_product_meta_end', 'cleaning_services_woocommerce_show_product_id', 10);
	function cleaning_services_woocommerce_show_product_id() {
		global $post, $product;
		echo '<span class="product_id">'.esc_html__('Product ID: ', 'cleaning-services') . '<span>' . ($post->ID) . '</span></span>';
	}
}

// Redefine number of related products
if ( !function_exists( 'cleaning_services_woocommerce_output_related_products_args' ) ) {
	//Handler of add_filter( 'woocommerce_output_related_products_args', 'cleaning_services_woocommerce_output_related_products_args' );
	function cleaning_services_woocommerce_output_related_products_args($args) {
		$ppp = $ccc = 0;
		if (cleaning_services_param_is_on(cleaning_services_get_custom_option('show_post_related'))) {
			$ccc_add = in_array(cleaning_services_get_custom_option('body_style'), array('fullwide', 'fullscreen')) ? 1 : 0;
			$ccc =  cleaning_services_get_custom_option('post_related_columns');
			$ccc = $ccc > 0 ? $ccc : (cleaning_services_param_is_off(cleaning_services_get_custom_option('show_sidebar_main')) ? 3+$ccc_add : 2+$ccc_add);
			$ppp = cleaning_services_get_custom_option('post_related_count');
			$ppp = $ppp > 0 ? $ppp : $ccc;
		}
		$args['posts_per_page'] = $ppp;
		$args['columns'] = $ccc;
		return $args;
	}
}

// Number columns for product thumbnails
if ( !function_exists( 'cleaning_services_woocommerce_product_thumbnails_columns' ) ) {
	//Handler of add_filter( 'woocommerce_product_thumbnails_columns', 'cleaning_services_woocommerce_product_thumbnails_columns' );
	function cleaning_services_woocommerce_product_thumbnails_columns($cols) {
		return 5;
	}
}

// Add column class into product item in shop streampage
if ( !function_exists( 'cleaning_services_woocommerce_loop_shop_columns_class' ) ) {
	//Handler of add_filter( 'post_class', 'cleaning_services_woocommerce_loop_shop_columns_class' );
	function cleaning_services_woocommerce_loop_shop_columns_class($class) {
		global $woocommerce_loop;
		if (is_product()) {
			if (!empty($woocommerce_loop['columns']))
			$class[] = ' column-1_'.esc_attr($woocommerce_loop['columns']);
		} else if (!is_product() && !is_cart() && !is_checkout() && !is_account_page()) {
            $cols = function_exists('wc_get_default_products_per_row') ? wc_get_default_products_per_row() : 2;
            $class[] = ' column-1_' . $cols;
		}
		return $class;
	}
}

// Search form
if ( !function_exists( 'cleaning_services_woocommerce_get_product_search_form' ) ) {
	//Handler of add_filter( 'get_product_search_form', 'cleaning_services_woocommerce_get_product_search_form' );
	function cleaning_services_woocommerce_get_product_search_form($form) {
		return '
		<form role="search" method="get" class="search_form" action="' . esc_url( home_url( '/'  ) ) . '">
			<input type="text" class="search_field" placeholder="' . esc_attr__('Search for products &hellip;', 'cleaning-services') . '" value="' . get_search_query() . '" name="s" title="' . esc_attr__('Search for products:', 'cleaning-services') . '" /><button class="search_button icon-search" type="submit"></button>
			<input type="hidden" name="post_type" value="product" />
		</form>
		';
	}
}

// Wrap product title into link
if ( !function_exists( 'cleaning_services_woocommerce_the_title' ) ) {
	//Handler of add_filter( 'the_title', 'cleaning_services_woocommerce_the_title' );
	function cleaning_services_woocommerce_the_title($title) {
		if (cleaning_services_get_global('in_product_item') && get_post_type()=='product') {
			$title = '<a href="'.get_permalink().'">'.($title).'</a>';
		}
		return $title;
	}
}

// Show pagination links
if ( !function_exists( 'cleaning_services_woocommerce_pagination' ) ) {
	//Handler of add_filter( 'woocommerce_after_shop_loop', 'cleaning_services_woocommerce_pagination', 10 );
	function cleaning_services_woocommerce_pagination() {
		$style = cleaning_services_get_custom_option('blog_pagination');
		cleaning_services_show_pagination(array(
			'class' => 'pagination_wrap pagination_' . esc_attr($style),
			'style' => $style,
			'button_class' => '',
			'first_text'=> '',
			'last_text' => '',
			'prev_text' => '',
			'next_text' => '',
			'pages_in_group' => $style=='pages' ? 10 : 20
			)
		);
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'cleaning_services_woocommerce_required_plugins' ) ) {
	//Handler of add_filter('cleaning_services_filter_required_plugins',	'cleaning_services_woocommerce_required_plugins');
	function cleaning_services_woocommerce_required_plugins($list=array()) {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('woocommerce', $CLEANING_SERVICES_GLOBALS['required_plugins']))
			$list[] = array(
					'name' 		=> 'WooCommerce',
					'slug' 		=> 'woocommerce',
					'required' 	=> false
				);

		return $list;
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check WooC in the required plugins
if ( !function_exists( 'cleaning_services_woocommerce_importer_required_plugins' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_required_plugins',	'cleaning_services_woocommerce_importer_required_plugins' );
	function cleaning_services_woocommerce_importer_required_plugins($not_installed='') {
	    global $CLEANING_SERVICES_GLOBALS;
		if (in_array('woocommerce', $CLEANING_SERVICES_GLOBALS['required_plugins']) && !cleaning_services_exists_woocommerce() )
			$not_installed .= '<br>WooCommerce';
		return $not_installed;
	}
}

// Set options for one-click importer
if ( !function_exists( 'cleaning_services_woocommerce_importer_set_options' ) ) {
	//Handler of add_filter( 'cleaning_services_filter_importer_options',	'cleaning_services_woocommerce_importer_set_options' );
	function cleaning_services_woocommerce_importer_set_options($options=array()) {
		if (is_array($options)) {
			$options['additional_options'][] = 'shop_%';		// Add slugs to export options for this plugin
			$options['additional_options'][] = 'woocommerce_%';
		}
		return $options;
	}
}

// Setup WooC pages after import posts complete
if ( !function_exists( 'cleaning_services_woocommerce_importer_after_import_posts' ) ) {
	//Handler of add_action( 'cleaning_services_action_importer_after_import_posts',	'cleaning_services_woocommerce_importer_after_import_posts', 10, 1 );
	function cleaning_services_woocommerce_importer_after_import_posts($importer) {
		$wooc_pages = array(						// Options slugs and pages titles for WooCommerce pages
			'woocommerce_shop_page_id' 				=> 'Shop',
			'woocommerce_cart_page_id' 				=> 'Cart',
			'woocommerce_checkout_page_id' 			=> 'Checkout',
			'woocommerce_pay_page_id' 				=> 'Checkout &#8594; Pay',
			'woocommerce_thanks_page_id' 			=> 'Order Received',
			'woocommerce_myaccount_page_id' 		=> 'My Account',
			'woocommerce_edit_address_page_id'		=> 'Edit My Address',
			'woocommerce_view_order_page_id'		=> 'View Order',
			'woocommerce_change_password_page_id'	=> 'Change Password',
			'woocommerce_logout_page_id'			=> 'Logout',
			'woocommerce_lost_password_page_id'		=> 'Lost Password'
		);
		foreach ($wooc_pages as $woo_page_name => $woo_page_title) {
			$woopage = get_page_by_title( $woo_page_title );
			if ($woopage->ID) {
				update_option($woo_page_name, $woopage->ID);
			}
		}
		// We no longer need to install pages
		delete_option( '_wc_needs_pages' );
		delete_transient( '_wc_activation_redirect' );
	}
}



// Add shortcodes to the internal builder
//------------------------------------------------------------------------
if ( !function_exists( 'cleaning_services_woocommerce_reg_shortcodes' ) ) {
	//Handler of add_action('cleaning_services_action_shortcodes_list', 'cleaning_services_woocommerce_reg_shortcodes', 20);
	function cleaning_services_woocommerce_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;

		// WooCommerce - Cart
		$CLEANING_SERVICES_GLOBALS['shortcodes']["woocommerce_cart"] = array(
			"title" => esc_html__("Woocommerce: Cart", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show Cart page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array()
		);
		
		// WooCommerce - Checkout
		$CLEANING_SERVICES_GLOBALS['shortcodes']["woocommerce_checkout"] = array(
			"title" => esc_html__("Woocommerce: Checkout", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show Checkout page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array()
		);
		
		// WooCommerce - My Account
		$CLEANING_SERVICES_GLOBALS['shortcodes']["woocommerce_my_account"] = array(
			"title" => esc_html__("Woocommerce: My Account", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show My Account page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array()
		);
		
		// WooCommerce - Order Tracking
		$CLEANING_SERVICES_GLOBALS['shortcodes']["woocommerce_order_tracking"] = array(
			"title" => esc_html__("Woocommerce: Order Tracking", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show Order Tracking page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array()
		);
		
		// WooCommerce - Shop Messages
		$CLEANING_SERVICES_GLOBALS['shortcodes']["shop_messages"] = array(
			"title" => esc_html__("Woocommerce: Shop Messages", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show shop messages", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array()
		);
		
		// WooCommerce - Product Page
		$CLEANING_SERVICES_GLOBALS['shortcodes']["product_page"] = array(
			"title" => esc_html__("Woocommerce: Product Page", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: display single product page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"sku" => array(
					"title" => esc_html__("SKU", 'cleaning-services'),
					"desc" => wp_kses( __("SKU code of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"id" => array(
					"title" => esc_html__("ID", 'cleaning-services'),
					"desc" => wp_kses( __("ID of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"posts_per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "1",
					"min" => 1,
					"type" => "spinner"
				),
				"post_type" => array(
					"title" => esc_html__("Post type", 'cleaning-services'),
					"desc" => wp_kses( __("Post type for the WP query (leave 'product')", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "product",
					"type" => "text"
				),
				"post_status" => array(
					"title" => esc_html__("Post status", 'cleaning-services'),
					"desc" => wp_kses( __("Display posts only with this status", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "publish",
					"type" => "select",
					"options" => array(
						"publish" => esc_html__('Publish', 'cleaning-services'),
						"protected" => esc_html__('Protected', 'cleaning-services'),
						"private" => esc_html__('Private', 'cleaning-services'),
						"pending" => esc_html__('Pending', 'cleaning-services'),
						"draft" => esc_html__('Draft', 'cleaning-services')
					)
				)
			)
		);
		
		// WooCommerce - Product
		$CLEANING_SERVICES_GLOBALS['shortcodes']["product"] = array(
			"title" => esc_html__("Woocommerce: Product", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: display one product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"sku" => array(
					"title" => esc_html__("SKU", 'cleaning-services'),
					"desc" => wp_kses( __("SKU code of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"id" => array(
					"title" => esc_html__("ID", 'cleaning-services'),
					"desc" => wp_kses( __("ID of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				)
			)
		);
		
		// WooCommerce - Best Selling Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["best_selling_products"] = array(
			"title" => esc_html__("Woocommerce: Best Selling Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show best selling products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				)
			)
		);
		
		// WooCommerce - Recent Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["recent_products"] = array(
			"title" => esc_html__("Woocommerce: Recent Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show recent products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				)
			)
		);
		
		// WooCommerce - Related Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["related_products"] = array(
			"title" => esc_html__("Woocommerce: Related Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show related products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"posts_per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				)
			)
		);
		
		// WooCommerce - Featured Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["featured_products"] = array(
			"title" => esc_html__("Woocommerce: Featured Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show featured products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				)
			)
		);
		
		// WooCommerce - Top Rated Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["featured_products"] = array(
			"title" => esc_html__("Woocommerce: Top Rated Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show top rated products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				)
			)
		);
		
		// WooCommerce - Sale Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["featured_products"] = array(
			"title" => esc_html__("Woocommerce: Sale Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: list products on sale", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				)
			)
		);
		
		// WooCommerce - Product Category
		$CLEANING_SERVICES_GLOBALS['shortcodes']["product_category"] = array(
			"title" => esc_html__("Woocommerce: Products from category", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: list products in specified category(-ies)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				),
				"category" => array(
					"title" => esc_html__("Categories", 'cleaning-services'),
					"desc" => wp_kses( __("Comma separated category slugs", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => '',
					"type" => "text"
				),
				"operator" => array(
					"title" => esc_html__("Operator", 'cleaning-services'),
					"desc" => wp_kses( __("Categories operator", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "IN",
					"type" => "checklist",
					"size" => "medium",
					"options" => array(
						"IN" => esc_html__('IN', 'cleaning-services'),
						"NOT IN" => esc_html__('NOT IN', 'cleaning-services'),
						"AND" => esc_html__('AND', 'cleaning-services')
					)
				)
			)
		);
		
		// WooCommerce - Products
		$CLEANING_SERVICES_GLOBALS['shortcodes']["products"] = array(
			"title" => esc_html__("Woocommerce: Products", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: list all products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"skus" => array(
					"title" => esc_html__("SKUs", 'cleaning-services'),
					"desc" => wp_kses( __("Comma separated SKU codes of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"ids" => array(
					"title" => esc_html__("IDs", 'cleaning-services'),
					"desc" => wp_kses( __("Comma separated ID of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				)
			)
		);
		
		// WooCommerce - Product attribute
		$CLEANING_SERVICES_GLOBALS['shortcodes']["product_attribute"] = array(
			"title" => esc_html__("Woocommerce: Products by Attribute", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show products with specified attribute", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"per_page" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				),
				"attribute" => array(
					"title" => esc_html__("Attribute", 'cleaning-services'),
					"desc" => wp_kses( __("Attribute name", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"filter" => array(
					"title" => esc_html__("Filter", 'cleaning-services'),
					"desc" => wp_kses( __("Attribute value", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				)
			)
		);
		
		// WooCommerce - Products Categories
		$CLEANING_SERVICES_GLOBALS['shortcodes']["product_categories"] = array(
			"title" => esc_html__("Woocommerce: Product Categories", 'cleaning-services'),
			"desc" => wp_kses( __("WooCommerce shortcode: show categories with products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
			"decorate" => false,
			"container" => false,
			"params" => array(
				"number" => array(
					"title" => esc_html__("Number", 'cleaning-services'),
					"desc" => wp_kses( __("How many categories showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 1,
					"type" => "spinner"
				),
				"columns" => array(
					"title" => esc_html__("Columns", 'cleaning-services'),
					"desc" => wp_kses( __("How many columns per row use for categories output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => 4,
					"min" => 2,
					"max" => 4,
					"type" => "spinner"
				),
				"orderby" => array(
					"title" => esc_html__("Order by", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "date",
					"type" => "select",
					"options" => array(
						"date" => esc_html__('Date', 'cleaning-services'),
						"title" => esc_html__('Title', 'cleaning-services')
					)
				),
				"order" => array(
					"title" => esc_html__("Order", 'cleaning-services'),
					"desc" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "desc",
					"type" => "switch",
					"size" => "big",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
				),
				"parent" => array(
					"title" => esc_html__("Parent", 'cleaning-services'),
					"desc" => wp_kses( __("Parent category slug", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"ids" => array(
					"title" => esc_html__("IDs", 'cleaning-services'),
					"desc" => wp_kses( __("Comma separated ID of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "",
					"type" => "text"
				),
				"hide_empty" => array(
					"title" => esc_html__("Hide empty", 'cleaning-services'),
					"desc" => wp_kses( __("Hide empty categories", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"value" => "yes",
					"type" => "switch",
					"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
				)
			)
		);
	}
}



// Add shortcodes to the VC builder
//------------------------------------------------------------------------
if ( !function_exists( 'cleaning_services_woocommerce_reg_shortcodes_vc' ) ) {
	//Handler of add_action('cleaning_services_action_shortcodes_list_vc', 'cleaning_services_woocommerce_reg_shortcodes_vc');
	function cleaning_services_woocommerce_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;
	
		if (false && function_exists('cleaning_services_exists_woocommerce') && cleaning_services_exists_woocommerce()) {
		
			// WooCommerce - Cart
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "woocommerce_cart",
				"name" => esc_html__("Cart", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show cart page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_wooc_cart',
				"class" => "trx_sc_alone trx_sc_woocommerce_cart",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => false,
				"params" => array(
					array(
						"param_name" => "dummy",
						"heading" => esc_html__("Dummy data", 'cleaning-services'),
						"description" => wp_kses( __("Dummy data - not used in shortcodes", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Woocommerce_Cart extends CLEANING_SERVICES_VC_ShortCodeAlone {}
		
		
			// WooCommerce - Checkout
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "woocommerce_checkout",
				"name" => esc_html__("Checkout", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show checkout page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_wooc_checkout',
				"class" => "trx_sc_alone trx_sc_woocommerce_checkout",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => false,
				"params" => array(
					array(
						"param_name" => "dummy",
						"heading" => esc_html__("Dummy data", 'cleaning-services'),
						"description" => wp_kses( __("Dummy data - not used in shortcodes", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Woocommerce_Checkout extends CLEANING_SERVICES_VC_ShortCodeAlone {}
		
		
			// WooCommerce - My Account
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "woocommerce_my_account",
				"name" => esc_html__("My Account", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show my account page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_wooc_my_account',
				"class" => "trx_sc_alone trx_sc_woocommerce_my_account",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => false,
				"params" => array(
					array(
						"param_name" => "dummy",
						"heading" => esc_html__("Dummy data", 'cleaning-services'),
						"description" => wp_kses( __("Dummy data - not used in shortcodes", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Woocommerce_My_Account extends CLEANING_SERVICES_VC_ShortCodeAlone {}
		
		
			// WooCommerce - Order Tracking
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "woocommerce_order_tracking",
				"name" => esc_html__("Order Tracking", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show order tracking page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_wooc_order_tracking',
				"class" => "trx_sc_alone trx_sc_woocommerce_order_tracking",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => false,
				"params" => array(
					array(
						"param_name" => "dummy",
						"heading" => esc_html__("Dummy data", 'cleaning-services'),
						"description" => wp_kses( __("Dummy data - not used in shortcodes", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Woocommerce_Order_Tracking extends CLEANING_SERVICES_VC_ShortCodeAlone {}
		
		
			// WooCommerce - Shop Messages
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "shop_messages",
				"name" => esc_html__("Shop Messages", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show shop messages", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_wooc_shop_messages',
				"class" => "trx_sc_alone trx_sc_shop_messages",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => false,
				"params" => array(
					array(
						"param_name" => "dummy",
						"heading" => esc_html__("Dummy data", 'cleaning-services'),
						"description" => wp_kses( __("Dummy data - not used in shortcodes", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Shop_Messages extends CLEANING_SERVICES_VC_ShortCodeAlone {}
		
		
			// WooCommerce - Product Page
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "product_page",
				"name" => esc_html__("Product Page", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: display single product page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_product_page',
				"class" => "trx_sc_single trx_sc_product_page",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "sku",
						"heading" => esc_html__("SKU", 'cleaning-services'),
						"description" => wp_kses( __("SKU code of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "id",
						"heading" => esc_html__("ID", 'cleaning-services'),
						"description" => wp_kses( __("ID of displayed product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "posts_per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "post_type",
						"heading" => esc_html__("Post type", 'cleaning-services'),
						"description" => wp_kses( __("Post type for the WP query (leave 'product')", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "product",
						"type" => "textfield"
					),
					array(
						"param_name" => "post_status",
						"heading" => esc_html__("Post status", 'cleaning-services'),
						"description" => wp_kses( __("Display posts only with this status", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array(
							esc_html__('Publish', 'cleaning-services') => 'publish',
							esc_html__('Protected', 'cleaning-services') => 'protected',
							esc_html__('Private', 'cleaning-services') => 'private',
							esc_html__('Pending', 'cleaning-services') => 'pending',
							esc_html__('Draft', 'cleaning-services') => 'draft'
						),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Product_Page extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Product
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "product",
				"name" => esc_html__("Product", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: display one product", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_product',
				"class" => "trx_sc_single trx_sc_product",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "sku",
						"heading" => esc_html__("SKU", 'cleaning-services'),
						"description" => wp_kses( __("Product's SKU code", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "id",
						"heading" => esc_html__("ID", 'cleaning-services'),
						"description" => wp_kses( __("Product's ID", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Product extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
			// WooCommerce - Best Selling Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "best_selling_products",
				"name" => esc_html__("Best Selling Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show best selling products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_best_selling_products',
				"class" => "trx_sc_single trx_sc_best_selling_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Best_Selling_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Recent Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "recent_products",
				"name" => esc_html__("Recent Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show recent products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_recent_products',
				"class" => "trx_sc_single trx_sc_recent_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"

					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Recent_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Related Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "related_products",
				"name" => esc_html__("Related Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show related products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_related_products',
				"class" => "trx_sc_single trx_sc_related_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "posts_per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Related_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Featured Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "featured_products",
				"name" => esc_html__("Featured Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show featured products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_featured_products',
				"class" => "trx_sc_single trx_sc_featured_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Featured_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Top Rated Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "top_rated_products",
				"name" => esc_html__("Top Rated Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show top rated products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_top_rated_products',
				"class" => "trx_sc_single trx_sc_top_rated_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Top_Rated_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Sale Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "sale_products",
				"name" => esc_html__("Sale Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: list products on sale", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_sale_products',
				"class" => "trx_sc_single trx_sc_sale_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Sale_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Product Category
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "product_category",
				"name" => esc_html__("Products from category", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: list products in specified category(-ies)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_product_category',
				"class" => "trx_sc_single trx_sc_product_category",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "category",
						"heading" => esc_html__("Categories", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated category slugs", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "operator",
						"heading" => esc_html__("Operator", 'cleaning-services'),
						"description" => wp_kses( __("Categories operator", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('IN', 'cleaning-services') => 'IN',
							esc_html__('NOT IN', 'cleaning-services') => 'NOT IN',
							esc_html__('AND', 'cleaning-services') => 'AND'
						),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Product_Category extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Products
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "products",
				"name" => esc_html__("Products", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: list all products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_products',
				"class" => "trx_sc_single trx_sc_products",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "skus",
						"heading" => esc_html__("SKUs", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated SKU codes of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("IDs", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated ID of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					)
				)
			) );
			
			class WPBakeryShortCode_Products extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
		
			// WooCommerce - Product Attribute
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "product_attribute",
				"name" => esc_html__("Products by Attribute", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show products with specified attribute", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_product_attribute',
				"class" => "trx_sc_single trx_sc_product_attribute",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "per_page",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many products showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "attribute",
						"heading" => esc_html__("Attribute", 'cleaning-services'),
						"description" => wp_kses( __("Attribute name", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "filter",
						"heading" => esc_html__("Filter", 'cleaning-services'),
						"description" => wp_kses( __("Attribute value", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					)
				)
			) );
			
			class WPBakeryShortCode_Product_Attribute extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		
		
		
			// WooCommerce - Products Categories
			//-------------------------------------------------------------------------------------
			
			vc_map( array(
				"base" => "product_categories",
				"name" => esc_html__("Product Categories", 'cleaning-services'),
				"description" => wp_kses( __("WooCommerce shortcode: show categories with products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('WooCommerce', 'cleaning-services'),
				'icon' => 'icon_trx_product_categories',
				"class" => "trx_sc_single trx_sc_product_categories",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array(
					array(
						"param_name" => "number",
						"heading" => esc_html__("Number", 'cleaning-services'),
						"description" => wp_kses( __("How many categories showed", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns per row use for categories output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Order by", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array(
							esc_html__('Date', 'cleaning-services') => 'date',
							esc_html__('Title', 'cleaning-services') => 'title'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Order", 'cleaning-services'),
						"description" => wp_kses( __("Sorting order for products output", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "parent",
						"heading" => esc_html__("Parent", 'cleaning-services'),
						"description" => wp_kses( __("Parent category slug", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "date",
						"type" => "textfield"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("IDs", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated ID of products", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "hide_empty",
						"heading" => esc_html__("Hide empty", 'cleaning-services'),
						"description" => wp_kses( __("Hide empty categories", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array("Hide empty" => "1" ),
						"type" => "checkbox"
					)
				)
			) );
			
			class WPBakeryShortCode_Products_Categories extends CLEANING_SERVICES_VC_ShortCodeSingle {}
		}
	}
}
?>