<?php
/**
 * Cleaning Services Framework: Services post type settings
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Theme init
if (!function_exists('cleaning_services_services_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_services_theme_setup',1 );
	function cleaning_services_services_theme_setup() {
		
		// Detect current page type, taxonomy and title (for custom post_types use priority < 10 to fire it handles early, than for standard post types)
		add_filter('cleaning_services_filter_get_blog_type',			'cleaning_services_services_get_blog_type', 9, 2);
		add_filter('cleaning_services_filter_get_blog_title',		'cleaning_services_services_get_blog_title', 9, 2);
		add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_services_get_current_taxonomy', 9, 2);
		add_filter('cleaning_services_filter_is_taxonomy',			'cleaning_services_services_is_taxonomy', 9, 2);
		add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_services_get_stream_page_title', 9, 2);
		add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_services_get_stream_page_link', 9, 2);
		add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_services_get_stream_page_id', 9, 2);
		add_filter('cleaning_services_filter_query_add_filters',		'cleaning_services_services_query_add_filters', 9, 2);
		add_filter('cleaning_services_filter_detect_inheritance_key','cleaning_services_services_detect_inheritance_key', 9, 1);

		// Extra column for services lists
		if (cleaning_services_get_theme_option('show_overriden_posts')=='yes') {
			add_filter('manage_edit-services_columns',			'cleaning_services_post_add_options_column', 9);
			add_filter('manage_services_posts_custom_column',	'cleaning_services_post_fill_options_column', 9, 2);
		}

		// Add shortcodes [trx_services] and [trx_services_item]
		add_action('cleaning_services_action_shortcodes_list',		'cleaning_services_services_reg_shortcodes');
		if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
			add_action('cleaning_services_action_shortcodes_list_vc','cleaning_services_services_reg_shortcodes_vc');
		
		// Prepare type "Team"
		cleaning_services_require_data( 'post_type', 'services', array(
			'label'               => esc_html__( 'Service item', 'cleaning-services' ),
			'description'         => esc_html__( 'Service Description', 'cleaning-services' ),
			'labels'              => array(
				'name'                => esc_html__( 'Services', 'cleaning-services' ),
				'singular_name'       => esc_html__( 'Service item', 'cleaning-services' ),
				'menu_name'           => esc_html__( 'Services', 'cleaning-services' ),
				'parent_item_colon'   => esc_html__( 'Parent Item:', 'cleaning-services' ),
				'all_items'           => esc_html__( 'All Services', 'cleaning-services' ),
				'view_item'           => esc_html__( 'View Item', 'cleaning-services' ),
				'add_new_item'        => esc_html__( 'Add New Service', 'cleaning-services' ),
				'add_new'             => esc_html__( 'Add New', 'cleaning-services' ),
				'edit_item'           => esc_html__( 'Edit Item', 'cleaning-services' ),
				'update_item'         => esc_html__( 'Update Item', 'cleaning-services' ),
				'search_items'        => esc_html__( 'Search Item', 'cleaning-services' ),
				'not_found'           => esc_html__( 'Not found', 'cleaning-services' ),
				'not_found_in_trash'  => esc_html__( 'Not found in Trash', 'cleaning-services' ),
			),
			'supports'            => array( 'title', 'excerpt', 'editor', 'author', 'thumbnail', 'comments', 'custom-fields'),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'menu_icon'			  => 'dashicons-info',
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_in_admin_bar'   => true,
			'menu_position'       => '52.2',
			'can_export'          => true,
			'has_archive'         => false,
			'exclude_from_search' => false,
			'publicly_queryable'  => true,
			'query_var'           => true,
			'capability_type'     => 'page',
			'rewrite'             => true
			)
		);
			
		// Prepare taxonomy for team
		cleaning_services_require_data( 'taxonomy', 'services_group', array(
			'post_type'			=> array( 'services' ),
			'hierarchical'      => true,
			'labels'            => array(
				'name'              => esc_html__( 'Services Group', 'cleaning-services' ),
				'singular_name'     => esc_html__( 'Group', 'cleaning-services' ),
				'search_items'      => esc_html__( 'Search Groups', 'cleaning-services' ),
				'all_items'         => esc_html__( 'All Groups', 'cleaning-services' ),
				'parent_item'       => esc_html__( 'Parent Group', 'cleaning-services' ),
				'parent_item_colon' => esc_html__( 'Parent Group:', 'cleaning-services' ),
				'edit_item'         => esc_html__( 'Edit Group', 'cleaning-services' ),
				'update_item'       => esc_html__( 'Update Group', 'cleaning-services' ),
				'add_new_item'      => esc_html__( 'Add New Group', 'cleaning-services' ),
				'new_item_name'     => esc_html__( 'New Group Name', 'cleaning-services' ),
				'menu_name'         => esc_html__( 'Services Group', 'cleaning-services' ),
			),
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'services_group' ),
			)
		);
	}
}

if ( !function_exists( 'cleaning_services_services_settings_theme_setup2' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_services_settings_theme_setup2', 3 );
	function cleaning_services_services_settings_theme_setup2() {
		// Add post type 'services' and taxonomy 'services_group' into theme inheritance list
		cleaning_services_add_theme_inheritance( array('services' => array(
			'stream_template' => 'blog-services',
			'single_template' => 'single-service',
			'taxonomy' => array('services_group'),
			'taxonomy_tags' => array(),
			'post_type' => array('services'),
			'override' => 'page'
			) )
		);
	}
}



// Return true, if current page is services page
if ( !function_exists( 'cleaning_services_is_services_page' ) ) {
	function cleaning_services_is_services_page() {
		global $CLEANING_SERVICES_GLOBALS;
		$is = in_array($CLEANING_SERVICES_GLOBALS['page_template'], array('blog-services', 'single-service'));
		if (!$is) {
			if (!empty($CLEANING_SERVICES_GLOBALS['pre_query']))
				$is = $CLEANING_SERVICES_GLOBALS['pre_query']->get('post_type')=='services' 
						|| $CLEANING_SERVICES_GLOBALS['pre_query']->is_tax('services_group') 
						|| ($CLEANING_SERVICES_GLOBALS['pre_query']->is_page() 
								&& ($id=cleaning_services_get_template_page_id('blog-services')) > 0 
								&& $id==(isset($CLEANING_SERVICES_GLOBALS['pre_query']->queried_object_id) 
											? $CLEANING_SERVICES_GLOBALS['pre_query']->queried_object_id 
											: 0)
						);
			else
				$is = get_query_var('post_type')=='services' 
						|| is_tax('services_group') 
						|| (is_page() && ($id=cleaning_services_get_template_page_id('blog-services')) > 0 && $id==get_the_ID());
		}
		return $is;
	}
}

// Filter to detect current page inheritance key
if ( !function_exists( 'cleaning_services_services_detect_inheritance_key' ) ) {
	//Handler of add_filter('cleaning_services_filter_detect_inheritance_key',	'cleaning_services_services_detect_inheritance_key', 9, 1);
	function cleaning_services_services_detect_inheritance_key($key) {
		if (!empty($key)) return $key;
		return cleaning_services_is_services_page() ? 'services' : '';
	}
}

// Filter to detect current page slug
if ( !function_exists( 'cleaning_services_services_get_blog_type' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_type',	'cleaning_services_services_get_blog_type', 9, 2);
	function cleaning_services_services_get_blog_type($page, $query=null) {
		if (!empty($page)) return $page;
		if ($query && $query->is_tax('services_group') || is_tax('services_group'))
			$page = 'services_category';
		else if ($query && $query->get('post_type')=='services' || get_query_var('post_type')=='services')
			$page = $query && $query->is_single() || is_single() ? 'services_item' : 'services';
		return $page;
	}
}

// Filter to detect current page title
if ( !function_exists( 'cleaning_services_services_get_blog_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_blog_title',	'cleaning_services_services_get_blog_title', 9, 2);
	function cleaning_services_services_get_blog_title($title, $page) {
		if (!empty($title)) return $title;
		if ( cleaning_services_strpos($page, 'services')!==false ) {
			if ( $page == 'services_category' ) {
				$term = get_term_by( 'slug', get_query_var( 'services_group' ), 'services_group', OBJECT);
				$title = $term->name;
			} else if ( $page == 'services_item' ) {
				$title = cleaning_services_get_post_title();
			} else {
				$title = esc_html__('All services', 'cleaning-services');
			}
		}
		return $title;
	}
}

// Filter to detect stream page title
if ( !function_exists( 'cleaning_services_services_get_stream_page_title' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_title',	'cleaning_services_services_get_stream_page_title', 9, 2);
	function cleaning_services_services_get_stream_page_title($title, $page) {
		if (!empty($title)) return $title;
		if (cleaning_services_strpos($page, 'services')!==false) {
			if (($page_id = cleaning_services_services_get_stream_page_id(0, $page=='services' ? 'blog-services' : $page)) > 0)
				$title = cleaning_services_get_post_title($page_id);
			else
				$title = esc_html__('All services', 'cleaning-services');				
		}
		return $title;
	}
}

// Filter to detect stream page ID
if ( !function_exists( 'cleaning_services_services_get_stream_page_id' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_id',	'cleaning_services_services_get_stream_page_id', 9, 2);
	function cleaning_services_services_get_stream_page_id($id, $page) {
		if (!empty($id)) return $id;
		if (cleaning_services_strpos($page, 'services')!==false) $id = cleaning_services_get_template_page_id('blog-services');
		return $id;
	}
}

// Filter to detect stream page URL
if ( !function_exists( 'cleaning_services_services_get_stream_page_link' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_stream_page_link',	'cleaning_services_services_get_stream_page_link', 9, 2);
	function cleaning_services_services_get_stream_page_link($url, $page) {
		if (!empty($url)) return $url;
		if (cleaning_services_strpos($page, 'services')!==false) {
			$id = cleaning_services_get_template_page_id('blog-services');
			if ($id) $url = get_permalink($id);
		}
		return $url;
	}
}

// Filter to detect current taxonomy
if ( !function_exists( 'cleaning_services_services_get_current_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_get_current_taxonomy',	'cleaning_services_services_get_current_taxonomy', 9, 2);
	function cleaning_services_services_get_current_taxonomy($tax, $page) {
		if (!empty($tax)) return $tax;
		if ( cleaning_services_strpos($page, 'services')!==false ) {
			$tax = 'services_group';
		}
		return $tax;
	}
}

// Return taxonomy name (slug) if current page is this taxonomy page
if ( !function_exists( 'cleaning_services_services_is_taxonomy' ) ) {
	//Handler of add_filter('cleaning_services_filter_is_taxonomy',	'cleaning_services_services_is_taxonomy', 9, 2);
	function cleaning_services_services_is_taxonomy($tax, $query=null) {
		if (!empty($tax))
			return $tax;
		else 
			return $query && $query->get('services_group')!='' || is_tax('services_group') ? 'services_group' : '';
	}
}

// Add custom post type and/or taxonomies arguments to the query
if ( !function_exists( 'cleaning_services_services_query_add_filters' ) ) {
	//Handler of add_filter('cleaning_services_filter_query_add_filters',	'cleaning_services_services_query_add_filters', 9, 2);
	function cleaning_services_services_query_add_filters($args, $filter) {
		if ($filter == 'services') {
			$args['post_type'] = 'services';
		}
		return $args;
	}
}





// ---------------------------------- [trx_services] ---------------------------------------

if ( !function_exists( 'cleaning_services_sc_services' ) ) {
	function cleaning_services_sc_services($atts, $content=null){	
		if (cleaning_services_in_shortcode_blogger()) return '';
		extract(cleaning_services_html_decode(shortcode_atts(array(
			// Individual params
			"style" => "services-1",
			"columns" => 4,
			"slider" => "no",
			"slides_space" => 0,
			"controls" => "no",
			"interval" => "",
			"autoheight" => "no",
			"align" => "",
			"custom" => "no",
			"type" => "icons",	// icons | images
			"ids" => "",
			"cat" => "",
			"count" => 4,
			"offset" => "",
			"orderby" => "date",
			"order" => "desc",
			"readmore" => '',
			"title" => "",
			"subtitle" => "",
			"description" => "",
			"link_caption" => esc_html__('Learn more', 'cleaning-services'),
			"link" => '',
			"scheme" => '',
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"width" => "",
			"height" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
	
		if (empty($id)) $id = "sc_services_".str_replace('.', '', mt_rand());
		if (empty($width)) $width = "100%";
		if (!empty($height) && cleaning_services_param_is_on($autoheight)) $autoheight = "no";
		if (empty($interval)) $interval = mt_rand(5000, 10000);
		
		$class .= ($class ? ' ' : '') . cleaning_services_get_css_position_as_classes($top, $right, $bottom, $left);

		$ws = cleaning_services_get_css_dimensions_from_values($width);
		$hs = cleaning_services_get_css_dimensions_from_values('', $height);
		$css .= ($hs) . ($ws);

		$count = max(1, (int) $count);
		$columns = max(1, min(12, (int) $columns));
		if (cleaning_services_param_is_off($custom) && $count < $columns) $columns = $count;

		if (cleaning_services_param_is_on($slider)) cleaning_services_enqueue_slider('swiper');

		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['sc_services_id'] = $id;
		$CLEANING_SERVICES_GLOBALS['sc_services_style'] = $style;
		$CLEANING_SERVICES_GLOBALS['sc_services_columns'] = $columns;
		$CLEANING_SERVICES_GLOBALS['sc_services_counter'] = 0;
		$CLEANING_SERVICES_GLOBALS['sc_services_slider'] = $slider;
		$CLEANING_SERVICES_GLOBALS['sc_services_css_wh'] = $ws . $hs;
		$CLEANING_SERVICES_GLOBALS['sc_services_readmore'] = $readmore;
		
		$output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '') 
						. ' class="sc_services_wrap'
						. ($scheme && !cleaning_services_param_is_off($scheme) && !cleaning_services_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '') 
						.'">'
					. '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') 
						. ' class="sc_services'
							. ' sc_services_style_'.esc_attr($style)
							. ' sc_services_type_'.esc_attr($type)
							. ' ' . esc_attr(cleaning_services_get_template_property($style, 'container_classes'))
							. ' ' . esc_attr(cleaning_services_get_slider_controls_classes($controls))
							. (cleaning_services_param_is_on($slider)
								? ' sc_slider_swiper swiper-slider-container'
									. (cleaning_services_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
									. ($hs ? ' sc_slider_height_fixed' : '')
								: '')
							. (!empty($class) ? ' '.esc_attr($class) : '')
							. ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
							. '"'
						. ($css!='' ? ' style="'.esc_attr($css).'"' : '') 
						. (!empty($width) && cleaning_services_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
						. (!empty($height) && cleaning_services_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
						. ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
						. ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
						. ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
						. (!cleaning_services_param_is_off($animation) ? ' data-animation="'.esc_attr(cleaning_services_get_animation_classes($animation)).'"' : '')
					. '>'
					. (!empty($subtitle) ? '<h6 class="sc_services_subtitle sc_item_subtitle">' . trim(cleaning_services_strmacros($subtitle)) . '</h6>' : '')
					. (!empty($title) ? '<h2 class="sc_services_title sc_item_title">' . trim(cleaning_services_strmacros($title)) . '</h2>' : '')
					. (!empty($description) ? '<div class="sc_services_descr sc_item_descr">' . trim(cleaning_services_strmacros($description)) . '</div>' : '')
					. (cleaning_services_param_is_on($slider) 
						? '<div class="slides swiper-wrapper">' 
						: ($columns > 1 
							? '<div class="sc_columns columns_wrap">' 
							: '')
						);
	
		$content = do_shortcode($content);
	
		if (cleaning_services_param_is_on($custom) && $content) {
			$output .= $content;
		} else {
			global $post;
	
			if (!empty($ids)) {
				$posts = explode(',', $ids);
				$count = count($posts);
			}
			
			$args = array(
				'post_type' => 'services',
				'post_status' => 'publish',
				'posts_per_page' => $count,
				'ignore_sticky_posts' => true,
				'order' => $order=='asc' ? 'asc' : 'desc',
				'readmore' => $readmore
			);
		
			if ($offset > 0 && empty($ids)) {
				$args['offset'] = $offset;
			}
		
			$args = cleaning_services_query_add_sort_order($args, $orderby, $order);
			$args = cleaning_services_query_add_posts_and_cats($args, $ids, 'services', $cat, 'services_group');
			$query = new WP_Query( $args );
	
			$post_number = 0;
				
			while ( $query->have_posts() ) { 
				$query->the_post();
				$post_number++;
				$args = array(
					'layout' => $style,
					'show' => false,
					'number' => $post_number,
					'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
					"descr" => cleaning_services_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
					"orderby" => $orderby,
					'content' => false,
					'terms_list' => false,
					'readmore' => $readmore,
					'tag_type' => $type,
					'columns_count' => $columns,
					'slider' => $slider,
					'tag_id' => $id ? $id . '_' . $post_number : '',
					'tag_class' => '',
					'tag_animation' => '',
					'tag_css' => '',
					'tag_css_wh' => $ws . $hs
				);
				$output .= cleaning_services_show_post_layout($args);
			}
			wp_reset_postdata();
		}
	
		if (cleaning_services_param_is_on($slider)) {
			$output .= '</div>'
				. '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
				. '<div class="sc_slider_pagination_wrap"></div>';
		} else if ($columns > 1) {
			$output .= '</div>';
		}

		$output .=  (!empty($link) ? '<div class="sc_services_button sc_item_button">'.cleaning_services_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
					. '</div><!-- /.sc_services -->'
				. '</div><!-- /.sc_services_wrap -->';
	
		// Add template specific scripts and styles
		do_action('cleaning_services_action_blog_scripts', $style);
	
		return apply_filters('cleaning_services_shortcode_output', $output, 'trx_services', $atts, $content);
	}
	cleaning_services_require_shortcode('trx_services', 'cleaning_services_sc_services');
}


if ( !function_exists( 'cleaning_services_sc_services_item' ) ) {
	function cleaning_services_sc_services_item($atts, $content=null) {
		if (cleaning_services_in_shortcode_blogger()) return '';
		extract(cleaning_services_html_decode(shortcode_atts( array(
			// Individual params
			"icon" => "",
			"image" => "",
			"title" => "",
			"link" => "",
			"readmore" => "(none)",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => ""
		), $atts)));
	
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['sc_services_counter']++;

		$id = $id ? $id : ($CLEANING_SERVICES_GLOBALS['sc_services_id'] ? $CLEANING_SERVICES_GLOBALS['sc_services_id'] . '_' . $CLEANING_SERVICES_GLOBALS['sc_services_counter'] : '');

		$descr = trim(chop(do_shortcode($content)));
		$readmore = $readmore=='(none)' ? $CLEANING_SERVICES_GLOBALS['sc_services_readmore'] : $readmore;

		if (!empty($icon)) {
			$type = 'icons';
		} else if (!empty($image)) {
			$type = 'images';
			if ($image > 0) {
				$attach = wp_get_attachment_image_src( $image, 'full' );
				if (isset($attach[0]) && $attach[0]!='')
					$image = $attach[0];
			}
			$thumb_sizes = cleaning_services_get_thumb_sizes(array('layout' => $CLEANING_SERVICES_GLOBALS['sc_services_style']));
			$image = cleaning_services_get_resized_image_tag($image, $thumb_sizes['w'], $thumb_sizes['h']);
		}
	
		$post_data = array(
			'post_title' => $title,
			'post_excerpt' => $descr,
			'post_thumb' => $image,
			'post_icon' => $icon,
			'post_link' => $link,
			'post_protected' => false,
			'post_format' => 'standard'
		);
		$args = array(
			'layout' => $CLEANING_SERVICES_GLOBALS['sc_services_style'],
			'number' => $CLEANING_SERVICES_GLOBALS['sc_services_counter'],
			'columns_count' => $CLEANING_SERVICES_GLOBALS['sc_services_columns'],
			'slider' => $CLEANING_SERVICES_GLOBALS['sc_services_slider'],
			'show' => false,
			'descr'  => -1,		// -1 - don't strip tags, 0 - strip_tags, >0 - strip_tags and truncate string
			'readmore' => $readmore,
			'tag_type' => $type,
			'tag_id' => $id,
			'tag_class' => $class,
			'tag_animation' => $animation,
			'tag_css' => $css,
			'tag_css_wh' => $CLEANING_SERVICES_GLOBALS['sc_services_css_wh']
		);
		$output = cleaning_services_show_post_layout($args, $post_data);
		return apply_filters('cleaning_services_shortcode_output', $output, 'trx_services_item', $atts, $content);
	}
	cleaning_services_require_shortcode('trx_services_item', 'cleaning_services_sc_services_item');
}
// ---------------------------------- [/trx_services] ---------------------------------------



// Add [trx_services] and [trx_services_item] in the shortcodes list
if (!function_exists('cleaning_services_services_reg_shortcodes')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list',	'cleaning_services_services_reg_shortcodes');
	function cleaning_services_services_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$services_groups = cleaning_services_get_list_terms(false, 'services_group');
			$services_styles = cleaning_services_get_list_templates('services');
			$controls 		 = cleaning_services_get_list_slider_controls();

			cleaning_services_array_insert_after($CLEANING_SERVICES_GLOBALS['shortcodes'], 'trx_section', array(

				// Services
				"trx_services" => array(
					"title" => esc_html__("Services", 'cleaning-services'),
					"desc" => wp_kses( __("Insert services list in your page (post)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"title" => array(
							"title" => esc_html__("Title", 'cleaning-services'),
							"desc" => wp_kses( __("Title for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"subtitle" => array(
							"title" => esc_html__("Subtitle", 'cleaning-services'),
							"desc" => wp_kses( __("Subtitle for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"description" => array(
							"title" => esc_html__("Description", 'cleaning-services'),
							"desc" => wp_kses( __("Short description for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "textarea"
						),
						"style" => array(
							"title" => esc_html__("Services style", 'cleaning-services'),
							"desc" => wp_kses( __("Select style to display services list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "services-1",
							"type" => "select",
							"options" => $services_styles
						),
						"type" => array(
							"title" => esc_html__("Icon's type", 'cleaning-services'),
							"desc" => wp_kses( __("Select type of icons: font icon or image", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "icons",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => array(
								'icons'  => esc_html__('Icons', 'cleaning-services'),
								'images' => esc_html__('Images', 'cleaning-services')
							)
						),
						"columns" => array(
							"title" => esc_html__("Columns", 'cleaning-services'),
							"desc" => wp_kses( __("How many columns use to show services list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => 4,
							"min" => 2,
							"max" => 6,
							"step" => 1,
							"type" => "spinner"
						),
						"scheme" => array(
							"title" => esc_html__("Color scheme", 'cleaning-services'),
							"desc" => wp_kses( __("Select color scheme for this block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "checklist",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['schemes']
						),
						"slider" => array(
							"title" => esc_html__("Slider", 'cleaning-services'),
							"desc" => wp_kses( __("Use slider to show services", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "no",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"controls" => array(
							"title" => esc_html__("Controls", 'cleaning-services'),
							"desc" => wp_kses( __("Slider controls style and position", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $controls
						),
						"slides_space" => array(
							"title" => esc_html__("Space between slides", 'cleaning-services'),
							"desc" => wp_kses( __("Size of space (in px) between slides", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 0,
							"min" => 0,
							"max" => 100,
							"step" => 10,
							"type" => "spinner"
						),
						"interval" => array(
							"title" => esc_html__("Slides change interval", 'cleaning-services'),
							"desc" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 7000,
							"step" => 500,
							"min" => 0,
							"type" => "spinner"
						),
						"autoheight" => array(
							"title" => esc_html__("Autoheight", 'cleaning-services'),
							"desc" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => "yes",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"align" => array(
							"title" => esc_html__("Alignment", 'cleaning-services'),
							"desc" => wp_kses( __("Alignment of the services block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['align']
						),
						"custom" => array(
							"title" => esc_html__("Custom", 'cleaning-services'),
							"desc" => wp_kses( __("Allow get services items from inner shortcodes (custom) or get it from specified group (cat)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "no",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"cat" => array(
							"title" => esc_html__("Categories", 'cleaning-services'),
							"desc" => wp_kses( __("Select categories (groups) to show services list. If empty - select services from any category (group) or from IDs list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"divider" => true,
							"value" => "",
							"type" => "select",
							"style" => "list",
							"multiple" => true,
							"options" => cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $services_groups)
						),
						"count" => array(
							"title" => esc_html__("Number of posts", 'cleaning-services'),
							"desc" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 4,
							"min" => 1,
							"max" => 100,
							"type" => "spinner"
						),
						"offset" => array(
							"title" => esc_html__("Offset before select posts", 'cleaning-services'),
							"desc" => wp_kses( __("Skip posts before select next part.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 0,
							"min" => 0,
							"type" => "spinner"
						),
						"orderby" => array(
							"title" => esc_html__("Post order by", 'cleaning-services'),
							"desc" => wp_kses( __("Select desired posts sorting method", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "title",
							"type" => "select",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['sorting']
						),
						"order" => array(
							"title" => esc_html__("Post order", 'cleaning-services'),
							"desc" => wp_kses( __("Select desired posts order", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "asc",
							"type" => "switch",
							"size" => "big",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
						),
						"ids" => array(
							"title" => esc_html__("Post IDs list", 'cleaning-services'),
							"desc" => wp_kses( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "",
							"type" => "text"
						),
						"readmore" => array(
							"title" => esc_html__("Read more", 'cleaning-services'),
							"desc" => wp_kses( __("Caption for the Read more link (if empty - link not showed)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"link" => array(
							"title" => esc_html__("Button URL", 'cleaning-services'),
							"desc" => wp_kses( __("Link URL for the button at the bottom of the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"link_caption" => array(
							"title" => esc_html__("Button caption", 'cleaning-services'),
							"desc" => wp_kses( __("Caption for the button at the bottom of the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"width" => cleaning_services_shortcodes_width(),
						"height" => cleaning_services_shortcodes_height(),
						"top" => $CLEANING_SERVICES_GLOBALS['sc_params']['top'],
						"bottom" => $CLEANING_SERVICES_GLOBALS['sc_params']['bottom'],
						"left" => $CLEANING_SERVICES_GLOBALS['sc_params']['left'],
						"right" => $CLEANING_SERVICES_GLOBALS['sc_params']['right'],
						"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
						"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
						"animation" => $CLEANING_SERVICES_GLOBALS['sc_params']['animation'],
						"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
					),
					"children" => array(
						"name" => "trx_services_item",
						"title" => esc_html__("Service item", 'cleaning-services'),
						"desc" => wp_kses( __("Service item", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"container" => true,
						"params" => array(
							"title" => array(
								"title" => esc_html__("Title", 'cleaning-services'),
								"desc" => wp_kses( __("Item's title", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"divider" => true,
								"value" => "",
								"type" => "text"
							),
							"icon" => array(
								"title" => esc_html__("Item's icon",  'cleaning-services'),
								"desc" => wp_kses( __('Select icon for the item from Fontello icons set',  'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "icons",
								"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['icons']
							),
							"image" => array(
								"title" => esc_html__("Item's image", 'cleaning-services'),
								"desc" => wp_kses( __("Item's image (if icon not selected)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"dependency" => array(
									'icon' => array('is_empty', 'none')
								),
								"value" => "",
								"readonly" => false,
								"type" => "media"
							),
							"link" => array(
								"title" => esc_html__("Link", 'cleaning-services'),
								"desc" => wp_kses( __("Link on service's item page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"divider" => true,
								"value" => "",
								"type" => "text"
							),
							"readmore" => array(
								"title" => esc_html__("Read more", 'cleaning-services'),
								"desc" => wp_kses( __("Caption for the Read more link (if empty - link not showed)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"_content_" => array(
								"title" => esc_html__("Description", 'cleaning-services'),
								"desc" => wp_kses( __("Item's short description", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"divider" => true,
								"rows" => 4,
								"value" => "",
								"type" => "textarea"
							),
							"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
							"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
							"animation" => $CLEANING_SERVICES_GLOBALS['sc_params']['animation'],
							"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
						)
					)
				)

			));
		}
	}
}


// Add [trx_services] and [trx_services_item] in the VC shortcodes list
if (!function_exists('cleaning_services_services_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_services_reg_shortcodes_vc');
	function cleaning_services_services_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;

		$services_groups = cleaning_services_get_list_terms(false, 'services_group');
		$services_styles = cleaning_services_get_list_templates('services');
		$controls		 = cleaning_services_get_list_slider_controls();

		// Services
		vc_map( array(
				"base" => "trx_services",
				"name" => esc_html__("Services", 'cleaning-services'),
				"description" => wp_kses( __("Insert services list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('Content', 'cleaning-services'),
				"icon" => 'icon_trx_services',
				"class" => "trx_sc_columns trx_sc_services",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_services_item'),
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => esc_html__("Services style", 'cleaning-services'),
						"description" => wp_kses( __("Select style to display services list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"admin_label" => true,
						"value" => array_flip($services_styles),
						"type" => "dropdown"
					),
					array(
						"param_name" => "type",
						"heading" => esc_html__("Icon's type", 'cleaning-services'),
						"description" => wp_kses( __("Select type of icons: font icon or image", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"admin_label" => true,
						"value" => array(
							esc_html__('Icons', 'cleaning-services') => 'icons',
							esc_html__('Images', 'cleaning-services') => 'images'
						),
						"type" => "dropdown"
					),
					array(
						"param_name" => "scheme",
						"heading" => esc_html__("Color scheme", 'cleaning-services'),
						"description" => wp_kses( __("Select color scheme for this block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['schemes']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slider",
						"heading" => esc_html__("Slider", 'cleaning-services'),
						"description" => wp_kses( __("Use slider to show services", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						"class" => "",
						"std" => "no",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "controls",
						"heading" => esc_html__("Controls", 'cleaning-services'),
						"description" => wp_kses( __("Slider controls style and position", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"std" => "no",
						"value" => array_flip($controls),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slides_space",
						"heading" => esc_html__("Space between slides", 'cleaning-services'),
						"description" => wp_kses( __("Size of space (in px) between slides", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "interval",
						"heading" => esc_html__("Slides change interval", 'cleaning-services'),
						"description" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "7000",
						"type" => "textfield"
					),
					array(
						"param_name" => "autoheight",
						"heading" => esc_html__("Autoheight", 'cleaning-services'),
						"description" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => array("Autoheight" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => esc_html__("Alignment", 'cleaning-services'),
						"description" => wp_kses( __("Alignment of the services block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "custom",
						"heading" => esc_html__("Custom", 'cleaning-services'),
						"description" => wp_kses( __("Allow get services from inner shortcodes (custom) or get it from specified group (cat)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array("Custom services" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", 'cleaning-services'),
						"description" => wp_kses( __("Title for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => esc_html__("Subtitle", 'cleaning-services'),
						"description" => wp_kses( __("Subtitle for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => esc_html__("Description", 'cleaning-services'),
						"description" => wp_kses( __("Description for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textarea"
					),
					array(
						"param_name" => "cat",
						"heading" => esc_html__("Categories", 'cleaning-services'),
						"description" => wp_kses( __("Select category to show services. If empty - select services from any category (group) or from IDs list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip(cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $services_groups)),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns use to show services list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => esc_html__("Number of posts", 'cleaning-services'),
						"description" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "4",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => esc_html__("Offset before select posts", 'cleaning-services'),
						"description" => wp_kses( __("Skip posts before select next part.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Post sorting", 'cleaning-services'),
						"description" => wp_kses( __("Select desired posts sorting method", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Post order", 'cleaning-services'),
						"description" => wp_kses( __("Select desired posts order", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("Service's IDs list", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated list of service's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "readmore",
						"heading" => esc_html__("Read more", 'cleaning-services'),
						"description" => wp_kses( __("Caption for the Read more link (if empty - link not showed)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link",
						"heading" => esc_html__("Button URL", 'cleaning-services'),
						"description" => wp_kses( __("Link URL for the button at the bottom of the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link_caption",
						"heading" => esc_html__("Button caption", 'cleaning-services'),
						"description" => wp_kses( __("Caption for the button at the bottom of the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					cleaning_services_vc_width(),
					cleaning_services_vc_height(),
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_top'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_bottom'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_left'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_right'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['animation'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css']
				),
				'default_content' => '
					[trx_services_item title="' . esc_html__( 'Service item 1', 'cleaning-services' ) . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 2', 'cleaning-services' ) . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 3', 'cleaning-services' ) . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 4', 'cleaning-services' ) . '"][/trx_services_item]
				',
				'js_view' => 'VcTrxColumnsView'
			) );
			
			
		vc_map( array(
				"base" => "trx_services_item",
				"name" => esc_html__("Services item", 'cleaning-services'),
				"description" => wp_kses( __("Custom services item - all data pull out from shortcode parameters", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"show_settings_on_create" => true,
				"class" => "trx_sc_collection trx_sc_column_item trx_sc_services_item",
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_services_item',
				"as_child" => array('only' => 'trx_services'),
				"as_parent" => array('except' => 'trx_services'),
				"params" => array(
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", 'cleaning-services'),
						"description" => wp_kses( __("Item's title", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "icon",
						"heading" => esc_html__("Icon", 'cleaning-services'),
						"description" => wp_kses( __("Select icon for the item from Fontello icons set", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => $CLEANING_SERVICES_GLOBALS['sc_params']['icons'],
						"type" => "dropdown"
					),
					array(
						"param_name" => "image",
						"heading" => esc_html__("Image", 'cleaning-services'),
						"description" => wp_kses( __("Item's image (if icon is empty)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "link",
						"heading" => esc_html__("Link", 'cleaning-services'),
						"description" => wp_kses( __("Link on item's page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "readmore",
						"heading" => esc_html__("Read more", 'cleaning-services'),
						"description" => wp_kses( __("Caption for the Read more link (if empty - link not showed)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['animation'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnItemView'
			) );
			
		class WPBakeryShortCode_Trx_Services extends CLEANING_SERVICES_VC_ShortCodeColumns {}
		class WPBakeryShortCode_Trx_Services_Item extends CLEANING_SERVICES_VC_ShortCodeCollection {}

	}
}
?>