<?php
/**
 * Cleaning Services Framework: Testimonial post type settings
 *
 * @package	cleaning_services
 * @since	cleaning_services 1.0
 */

// Theme init
if (!function_exists('cleaning_services_testimonial_theme_setup')) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_testimonial_theme_setup', 1 );
	function cleaning_services_testimonial_theme_setup() {
	
		// Add item in the admin menu
		add_filter('trx_utils_filter_override_options',		'cleaning_services_testimonial_add_override_options');

		// Save data from meta box
		add_action('save_post',				'cleaning_services_testimonial_save_data');

		// Add shortcodes [trx_testimonials] and [trx_testimonials_item]
		add_action('cleaning_services_action_shortcodes_list',		'cleaning_services_testimonials_reg_shortcodes');
		if (function_exists('cleaning_services_exists_visual_composer') && cleaning_services_exists_visual_composer())
			add_action('cleaning_services_action_shortcodes_list_vc','cleaning_services_testimonials_reg_shortcodes_vc');

		// Meta box fields
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['testimonial_override_options'] = array(
			'id' => 'testimonial-meta-box',
			'title' => esc_html__('Testimonial Details', 'cleaning-services'),
			'page' => 'testimonial',
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(
				"testimonial_author" => array(
					"title" => esc_html__('Testimonial author',  'cleaning-services'),
					"desc" => wp_kses( __("Name of the testimonial's author", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_author",
					"std" => "",
					"type" => "text"),
				"testimonial_position" => array(
					"title" => esc_html__("Author's position",  'cleaning-services'),
					"desc" => wp_kses( __("Position of the testimonial's author", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_author",
					"std" => "",
					"type" => "text"),
				"testimonial_email" => array(
					"title" => esc_html__("Author's e-mail",  'cleaning-services'),
					"desc" => wp_kses( __("E-mail of the testimonial's author - need to take Gravatar (if registered)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_email",
					"std" => "",
					"type" => "text"),
				"testimonial_link" => array(
					"title" => esc_html__('Testimonial link',  'cleaning-services'),
					"desc" => wp_kses( __("URL of the testimonial source or author profile page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"class" => "testimonial_link",
					"std" => "",
					"type" => "text")
			)
		);
		
		// Prepare type "Testimonial"
		cleaning_services_require_data( 'post_type', 'testimonial', array(
			'label'               => esc_html__( 'Testimonial', 'cleaning-services' ),
			'description'         => esc_html__( 'Testimonial Description', 'cleaning-services' ),
			'labels'              => array(
				'name'                => esc_html__( 'Testimonials', 'cleaning-services' ),
				'singular_name'       => esc_html__( 'Testimonial', 'cleaning-services' ),
				'menu_name'           => esc_html__( 'Testimonials', 'cleaning-services' ),
				'parent_item_colon'   => esc_html__( 'Parent Item:', 'cleaning-services' ),
				'all_items'           => esc_html__( 'All Testimonials', 'cleaning-services' ),
				'view_item'           => esc_html__( 'View Item', 'cleaning-services' ),
				'add_new_item'        => esc_html__( 'Add New Testimonial', 'cleaning-services' ),
				'add_new'             => esc_html__( 'Add New', 'cleaning-services' ),
				'edit_item'           => esc_html__( 'Edit Item', 'cleaning-services' ),
				'update_item'         => esc_html__( 'Update Item', 'cleaning-services' ),
				'search_items'        => esc_html__( 'Search Item', 'cleaning-services' ),
				'not_found'           => esc_html__( 'Not found', 'cleaning-services' ),
				'not_found_in_trash'  => esc_html__( 'Not found in Trash', 'cleaning-services' ),
			),
			'supports'            => array( 'title', 'editor', 'author', 'thumbnail'),
			'hierarchical'        => false,
			'public'              => false,
			'show_ui'             => true,
			'menu_icon'			  => 'dashicons-cloud',
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_in_admin_bar'   => true,
			'menu_position'       => '52.4',
			'can_export'          => true,
			'has_archive'         => false,
			'exclude_from_search' => true,
			'publicly_queryable'  => false,
			'capability_type'     => 'page',
			)
		);
		
		// Prepare taxonomy for testimonial
		cleaning_services_require_data( 'taxonomy', 'testimonial_group', array(
			'post_type'			=> array( 'testimonial' ),
			'hierarchical'      => true,
			'labels'            => array(
				'name'              => esc_html__( 'Testimonials Group', 'cleaning-services' ),
				'singular_name'     => esc_html__( 'Group', 'cleaning-services' ),
				'search_items'      => esc_html__( 'Search Groups', 'cleaning-services' ),
				'all_items'         => esc_html__( 'All Groups', 'cleaning-services' ),
				'parent_item'       => esc_html__( 'Parent Group', 'cleaning-services' ),
				'parent_item_colon' => esc_html__( 'Parent Group:', 'cleaning-services' ),
				'edit_item'         => esc_html__( 'Edit Group', 'cleaning-services' ),
				'update_item'       => esc_html__( 'Update Group', 'cleaning-services' ),
				'add_new_item'      => esc_html__( 'Add New Group', 'cleaning-services' ),
				'new_item_name'     => esc_html__( 'New Group Name', 'cleaning-services' ),
				'menu_name'         => esc_html__( 'Testimonial Group', 'cleaning-services' ),
			),
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'testimonial_group' ),
			)
		);
	}
}


// Add meta box
if (!function_exists('cleaning_services_testimonial_add_override_options')) {
	//Handler of add_filter('trx_utils_filter_override_options', 'cleaning_services_testimonial_add_override_options');
	function cleaning_services_testimonial_add_override_options($boxes = array()) {
        $boxes[] = array_merge(cleaning_services_storage_get('testimonial_override_options'), array('callback' => 'cleaning_services_testimonial_show_override_options'));
        return $boxes;
	}
}

// Callback function to show fields in meta box
if (!function_exists('cleaning_services_testimonial_show_override_options')) {
	function cleaning_services_testimonial_show_override_options() {
		global $post, $CLEANING_SERVICES_GLOBALS;

		// Use nonce for verification
		echo '<input type="hidden" name="override_options_testimonial_nonce" value="', esc_attr($CLEANING_SERVICES_GLOBALS['admin_nonce']), '" />';
		
		$data = get_post_meta($post->ID, 'testimonial_data', true);
	
		$fields = $CLEANING_SERVICES_GLOBALS['testimonial_override_options']['fields'];
		?>
		<table class="testimonial_area">
		<?php
		if (is_array($fields) && count($fields) > 0) {
			foreach ($fields as $id=>$field) { 
				$meta = isset($data[$id]) ? $data[$id] : '';
				?>
				<tr class="testimonial_field <?php echo esc_attr($field['class']); ?>" valign="top">
					<td><label for="<?php echo esc_attr($id); ?>"><?php echo esc_attr($field['title']); ?></label></td>
					<td><input type="text" name="<?php echo esc_attr($id); ?>" id="<?php echo esc_attr($id); ?>" value="<?php echo esc_attr($meta); ?>" size="30" />
						<br><small><?php echo esc_attr($field['desc']); ?></small></td>
				</tr>
				<?php
			}
		}
		?>
		</table>
		<?php
	}
}


// Save data from meta box
if (!function_exists('cleaning_services_testimonial_save_data')) {
	//Handler of add_action('save_post', 'cleaning_services_testimonial_save_data');
	function cleaning_services_testimonial_save_data($post_id) {
		global $CLEANING_SERVICES_GLOBALS;
		// verify nonce
		if (!isset($_POST['override_options_testimonial_nonce']) || !wp_verify_nonce($_POST['override_options_testimonial_nonce'], $CLEANING_SERVICES_GLOBALS['admin_url'])) {
			return $post_id;
		}

		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post_id;
		}

		// check permissions
		if ($_POST['post_type']!='testimonial' || !current_user_can('edit_post', $post_id)) {
			return $post_id;
		}

		$data = array();

		$fields = $CLEANING_SERVICES_GLOBALS['testimonial_override_options']['fields'];

		// Post type specific data handling
		if (is_array($fields) && count($fields) > 0) {
			foreach ($fields as $id=>$field) { 
				if (isset($_POST[$id])) 
					$data[$id] = stripslashes($_POST[$id]);
			}
		}

		update_post_meta($post_id, 'testimonial_data', $data);
	}
}






// ---------------------------------- [trx_testimonials] ---------------------------------------

if (!function_exists('cleaning_services_sc_testimonials')) {
	function cleaning_services_sc_testimonials($atts, $content=null){	
		if (cleaning_services_in_shortcode_blogger()) return '';
		extract(cleaning_services_html_decode(shortcode_atts(array(
			// Individual params
			"style" => "testimonials-1",
			"columns" => 1,
			"slider" => "yes",
			"slides_space" => 0,
			"controls" => "no",
			"interval" => "",
			"autoheight" => "no",
			"align" => "",
			"custom" => "no",
			"ids" => "",
			"cat" => "",
			"count" => "3",
			"offset" => "",
			"orderby" => "date",
			"order" => "desc",
			"scheme" => "",
			"bg_color" => "",
			"bg_image" => "",
			"bg_overlay" => "",
			"bg_texture" => "",
			"title" => "",
			"subtitle" => "",
			"description" => "",
			// Common params
			"id" => "",
			"class" => "",
			"animation" => "",
			"css" => "",
			"width" => "",
			"height" => "",
			"top" => "",
			"bottom" => "",
			"left" => "",
			"right" => ""
		), $atts)));
	
		if (empty($id)) $id = "sc_testimonials_".str_replace('.', '', mt_rand());
		if (empty($width)) $width = "100%";
		if (!empty($height) && cleaning_services_param_is_on($autoheight)) $autoheight = "no";
		if (empty($interval)) $interval = mt_rand(5000, 10000);
	
		if ($bg_image > 0) {
			$attach = wp_get_attachment_image_src( $bg_image, 'full' );
			if (isset($attach[0]) && $attach[0]!='')
				$bg_image = $attach[0];
		}
	
		if ($bg_overlay > 0) {
			if ($bg_color=='') $bg_color = cleaning_services_get_scheme_color('bg');
			$rgb = cleaning_services_hex2rgb($bg_color);
		}
		
		$class .= ($class ? ' ' : '') . cleaning_services_get_css_position_as_classes($top, $right, $bottom, $left);

		$ws = cleaning_services_get_css_dimensions_from_values($width);
		$hs = cleaning_services_get_css_dimensions_from_values('', $height);
		$css .= ($hs) . ($ws);

		$count = max(1, (int) $count);
		$columns = max(1, min(12, (int) $columns));
		if (cleaning_services_param_is_off($custom) && $count < $columns) $columns = $count;
		
		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_id'] = $id;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_style'] = $style;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_columns'] = $columns;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_counter'] = 0;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_slider'] = $slider;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_css_wh'] = $ws . $hs;

		if (cleaning_services_param_is_on($slider)) cleaning_services_enqueue_slider('swiper');
	
		$output = ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || cleaning_services_strlen($bg_texture)>2 || ($scheme && !cleaning_services_param_is_off($scheme) && !cleaning_services_param_is_inherit($scheme))
					? '<div class="sc_testimonials_wrap sc_section'
							. ($scheme && !cleaning_services_param_is_off($scheme) && !cleaning_services_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '') 
							. '"'
						.' style="'
							. ($bg_color !== '' && $bg_overlay==0 ? 'background-color:' . esc_attr($bg_color) . ';' : '')
							. ($bg_image !== '' ? 'background-image:url(' . esc_url($bg_image) . ');' : '')
							. '"'
						. (!cleaning_services_param_is_off($animation) ? ' data-animation="'.esc_attr(cleaning_services_get_animation_classes($animation)).'"' : '')
						. '>'
						. '<div class="sc_section_overlay'.($bg_texture>0 ? ' texture_bg_'.esc_attr($bg_texture) : '') . '"'
								. ' style="' . ($bg_overlay>0 ? 'background-color:rgba('.(int)$rgb['r'].','.(int)$rgb['g'].','.(int)$rgb['b'].','.min(1, max(0, $bg_overlay)).');' : '')
									. (cleaning_services_strlen($bg_texture)>2 ? 'background-image:url('.esc_url($bg_texture).');' : '')
									. '"'
									. ($bg_overlay > 0 ? ' data-overlay="'.esc_attr($bg_overlay).'" data-bg_color="'.esc_attr($bg_color).'"' : '')
									. '>' 
					: '')
				. '<div' . ($id ? ' id="'.esc_attr($id).'"' : '') 
				. ' class="sc_testimonials sc_testimonials_style_'.esc_attr($style)
 					. ' ' . esc_attr(cleaning_services_get_template_property($style, 'container_classes'))
 					. (cleaning_services_param_is_on($slider)
						? ' sc_slider_swiper swiper-slider-container'
							. ' ' . esc_attr(cleaning_services_get_slider_controls_classes($controls))
							. (cleaning_services_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
							. ($hs ? ' sc_slider_height_fixed' : '')
						: '')
					. (!empty($class) ? ' '.esc_attr($class) : '')
					. ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
					. '"'
				. ($bg_color=='' && $bg_image=='' && $bg_overlay==0 && ($bg_texture=='' || $bg_texture=='0') && !cleaning_services_param_is_off($animation) ? ' data-animation="'.esc_attr(cleaning_services_get_animation_classes($animation)).'"' : '')
				. (!empty($width) && cleaning_services_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
				. (!empty($height) && cleaning_services_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
				. ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
				. ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
				. ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
				. ($css!='' ? ' style="'.esc_attr($css).'"' : '')
			. '>'
			. (!empty($subtitle) ? '<h6 class="sc_testimonials_subtitle sc_item_subtitle">' . trim(cleaning_services_strmacros($subtitle)) . '</h6>' : '')
			. (!empty($title) ? '<h2 class="sc_testimonials_title sc_item_title">' . trim(cleaning_services_strmacros($title)) . '</h2>' : '')
			. (!empty($description) ? '<div class="sc_testimonials_descr sc_item_descr">' . trim(cleaning_services_strmacros($description)) . '</div>' : '')
			. (cleaning_services_param_is_on($slider) 
				? '<div class="slides swiper-wrapper">' 
				: ($columns > 1 
					? '<div class="sc_columns columns_wrap">' 
					: '')
				);
	
		$content = do_shortcode($content);
			
		if (cleaning_services_param_is_on($custom) && $content) {
			$output .= $content;
		} else {
			global $post;
		
			if (!empty($ids)) {
				$posts = explode(',', $ids);
				$count = count($posts);
			}
			
			$args = array(
				'post_type' => 'testimonial',
				'post_status' => 'publish',
				'posts_per_page' => $count,
				'ignore_sticky_posts' => true,
				'order' => $order=='asc' ? 'asc' : 'desc',
			);
		
			if ($offset > 0 && empty($ids)) {
				$args['offset'] = $offset;
			}
		
			$args = cleaning_services_query_add_sort_order($args, $orderby, $order);
			$args = cleaning_services_query_add_posts_and_cats($args, $ids, 'testimonial', $cat, 'testimonial_group');
	
			$query = new WP_Query( $args );
	
			$post_number = 0;
				
			while ( $query->have_posts() ) { 
				$query->the_post();
				$post_number++;
				$args = array(
					'layout' => $style,
					'show' => false,
					'number' => $post_number,
					'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
					"descr" => cleaning_services_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
					"orderby" => $orderby,
					'content' => false,
					'terms_list' => false,
					'columns_count' => $columns,
					'slider' => $slider,
					'tag_id' => $id ? $id . '_' . $post_number : '',
					'tag_class' => '',
					'tag_animation' => '',
					'tag_css' => '',
					'tag_css_wh' => $ws . $hs
				);
				$post_data = cleaning_services_get_post_data($args);
				$post_data['post_content'] = wpautop($post_data['post_content']);	// Add <p> around text and paragraphs. Need separate call because 'content'=>false (see above)
				$post_meta = get_post_meta($post_data['post_id'], 'testimonial_data', true);
				$thumb_sizes = cleaning_services_get_thumb_sizes(array('layout' => $style));
				$args['author'] = $post_meta['testimonial_author'];
				$args['position'] = $post_meta['testimonial_position'];
				$args['link'] = !empty($post_meta['testimonial_link']) ? $post_meta['testimonial_link'] : '';
				$args['email'] = $post_meta['testimonial_email'];
				$args['photo'] = $post_data['post_thumb'];
				if (empty($args['photo']) && !empty($args['email'])) $args['photo'] = get_avatar($args['email'], $thumb_sizes['w']*min(2, max(1, cleaning_services_get_theme_option("retina_ready"))));
				$output .= cleaning_services_show_post_layout($args, $post_data);
			}
			wp_reset_postdata();
		}
	
		if (cleaning_services_param_is_on($slider)) {
			$output .= '</div>'
				. '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
				. '<div class="sc_slider_pagination_wrap"></div>';
		} else if ($columns > 1) {
			$output .= '</div>';
		}

		$output .= '</div>'
					. ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || cleaning_services_strlen($bg_texture)>2
						?  '</div></div>'
						: '');
	
		// Add template specific scripts and styles
		do_action('cleaning_services_action_blog_scripts', $style);

		return apply_filters('cleaning_services_shortcode_output', $output, 'trx_testimonials', $atts, $content);
	}
	cleaning_services_require_shortcode('trx_testimonials', 'cleaning_services_sc_testimonials');
}
	
	
if (!function_exists('cleaning_services_sc_testimonials_item')) {
	function cleaning_services_sc_testimonials_item($atts, $content=null){	
		if (cleaning_services_in_shortcode_blogger()) return '';
		extract(cleaning_services_html_decode(shortcode_atts(array(
			// Individual params
			"author" => "",
			"position" => "",
			"link" => "",
			"photo" => "",
			"email" => "",
			// Common params
			"id" => "",
			"class" => "",
			"css" => "",
		), $atts)));

		global $CLEANING_SERVICES_GLOBALS;
		$CLEANING_SERVICES_GLOBALS['sc_testimonials_counter']++;
	
		$id = $id ? $id : ($CLEANING_SERVICES_GLOBALS['sc_testimonials_id'] ? $CLEANING_SERVICES_GLOBALS['sc_testimonials_id'] . '_' . $CLEANING_SERVICES_GLOBALS['sc_testimonials_counter'] : '');
	
		$thumb_sizes = cleaning_services_get_thumb_sizes(array('layout' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_style']));

		if (empty($photo)) {
			if (!empty($email))
				$photo = get_avatar($email, $thumb_sizes['w']*min(2, max(1, cleaning_services_get_theme_option("retina_ready"))));
		} else {
			if ($photo > 0) {
				$attach = wp_get_attachment_image_src( $photo, 'full' );
				if (isset($attach[0]) && $attach[0]!='')
					$photo = $attach[0];
			}
			$photo = cleaning_services_get_resized_image_tag($photo, $thumb_sizes['w'], $thumb_sizes['h']);
		}

		$post_data = array(
			'post_content' => do_shortcode($content)
		);
		$args = array(
			'layout' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_style'],
			'number' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_counter'],
			'columns_count' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_columns'],
			'slider' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_slider'],
			'show' => false,
			'descr'  => 0,
			'tag_id' => $id,
			'tag_class' => $class,
			'tag_animation' => '',
			'tag_css' => $css,
			'tag_css_wh' => $CLEANING_SERVICES_GLOBALS['sc_testimonials_css_wh'],
			'author' => $author,
			'position' => $position,
			'link' => $link,
			'email' => $email,
			'photo' => $photo
		);
		$output = cleaning_services_show_post_layout($args, $post_data);

		return apply_filters('cleaning_services_shortcode_output', $output, 'trx_testimonials_item', $atts, $content);
	}
	cleaning_services_require_shortcode('trx_testimonials_item', 'cleaning_services_sc_testimonials_item');
}
// ---------------------------------- [/trx_testimonials] ---------------------------------------



// Add [trx_testimonials] and [trx_testimonials_item] in the shortcodes list
if (!function_exists('cleaning_services_testimonials_reg_shortcodes')) {
	function cleaning_services_testimonials_reg_shortcodes() {
		global $CLEANING_SERVICES_GLOBALS;
		if (isset($CLEANING_SERVICES_GLOBALS['shortcodes'])) {

			$testimonials_groups = cleaning_services_get_list_terms(false, 'testimonial_group');
			$testimonials_styles = cleaning_services_get_list_templates('testimonials');
			$controls = cleaning_services_get_list_slider_controls();

			cleaning_services_array_insert_before($CLEANING_SERVICES_GLOBALS['shortcodes'], 'trx_title', array(
			
				// Testimonials
				"trx_testimonials" => array(
					"title" => esc_html__("Testimonials", 'cleaning-services'),
					"desc" => wp_kses( __("Insert testimonials into post (page)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
					"decorate" => true,
					"container" => false,
					"params" => array(
						"title" => array(
							"title" => esc_html__("Title", 'cleaning-services'),
							"desc" => wp_kses( __("Title for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"subtitle" => array(
							"title" => esc_html__("Subtitle", 'cleaning-services'),
							"desc" => wp_kses( __("Subtitle for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "text"
						),
						"description" => array(
							"title" => esc_html__("Description", 'cleaning-services'),
							"desc" => wp_kses( __("Short description for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "textarea"
						),
						"style" => array(
							"title" => esc_html__("Testimonials style", 'cleaning-services'),
							"desc" => wp_kses( __("Select style to display testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "testimonials-1",
							"type" => "select",
							"options" => $testimonials_styles
						),
						"columns" => array(
							"title" => esc_html__("Columns", 'cleaning-services'),
							"desc" => wp_kses( __("How many columns use to show testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => 1,
							"min" => 1,
							"max" => 6,
							"step" => 1,
							"type" => "spinner"
						),
						"slider" => array(
							"title" => esc_html__("Slider", 'cleaning-services'),
							"desc" => wp_kses( __("Use slider to show testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "yes",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"controls" => array(
							"title" => esc_html__("Controls", 'cleaning-services'),
							"desc" => wp_kses( __("Slider controls style and position", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"divider" => true,
							"value" => "no",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $controls
						),
						"slides_space" => array(
							"title" => esc_html__("Space between slides", 'cleaning-services'),
							"desc" => wp_kses( __("Size of space (in px) between slides", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 0,
							"min" => 0,
							"max" => 100,
							"step" => 10,
							"type" => "spinner"
						),
						"interval" => array(
							"title" => esc_html__("Slides change interval", 'cleaning-services'),
							"desc" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => 7000,
							"step" => 500,
							"min" => 0,
							"type" => "spinner"
						),
						"autoheight" => array(
							"title" => esc_html__("Autoheight", 'cleaning-services'),
							"desc" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'slider' => array('yes')
							),
							"value" => "yes",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"align" => array(
							"title" => esc_html__("Alignment", 'cleaning-services'),
							"desc" => wp_kses( __("Alignment of the testimonials block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "",
							"type" => "checklist",
							"dir" => "horizontal",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['align']
						),
						"custom" => array(
							"title" => esc_html__("Custom", 'cleaning-services'),
							"desc" => wp_kses( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"divider" => true,
							"value" => "no",
							"type" => "switch",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']
						),
						"cat" => array(
							"title" => esc_html__("Categories", 'cleaning-services'),
							"desc" => wp_kses( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"divider" => true,
							"value" => "",
							"type" => "select",
							"style" => "list",
							"multiple" => true,
							"options" => cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $testimonials_groups)
						),
						"count" => array(
							"title" => esc_html__("Number of posts", 'cleaning-services'),
							"desc" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 3,
							"min" => 1,
							"max" => 100,
							"type" => "spinner"
						),
						"offset" => array(
							"title" => esc_html__("Offset before select posts", 'cleaning-services'),
							"desc" => wp_kses( __("Skip posts before select next part.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => 0,
							"min" => 0,
							"type" => "spinner"
						),
						"orderby" => array(
							"title" => esc_html__("Post order by", 'cleaning-services'),
							"desc" => wp_kses( __("Select desired posts sorting method", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "date",
							"type" => "select",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['sorting']
						),
						"order" => array(
							"title" => esc_html__("Post order", 'cleaning-services'),
							"desc" => wp_kses( __("Select desired posts order", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "desc",
							"type" => "switch",
							"size" => "big",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['ordering']
						),
						"ids" => array(
							"title" => esc_html__("Post IDs list", 'cleaning-services'),
							"desc" => wp_kses( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"dependency" => array(
								'custom' => array('no')
							),
							"value" => "",
							"type" => "text"
						),
						"scheme" => array(
							"title" => esc_html__("Color scheme", 'cleaning-services'),
							"desc" => wp_kses( __("Select color scheme for this block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "checklist",
							"options" => $CLEANING_SERVICES_GLOBALS['sc_params']['schemes']
						),
						"bg_color" => array(
							"title" => esc_html__("Background color", 'cleaning-services'),
							"desc" => wp_kses( __("Any background color for this section", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"value" => "",
							"type" => "color"
						),
						"bg_image" => array(
							"title" => esc_html__("Background image URL", 'cleaning-services'),
							"desc" => wp_kses( __("Select or upload image or write URL from other site for the background", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"readonly" => false,
							"value" => "",
							"type" => "media"
						),
						"bg_overlay" => array(
							"title" => esc_html__("Overlay", 'cleaning-services'),
							"desc" => wp_kses( __("Overlay color opacity (from 0.0 to 1.0)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"min" => "0",
							"max" => "1",
							"step" => "0.1",
							"value" => "0",
							"type" => "spinner"
						),
						"bg_texture" => array(
							"title" => esc_html__("Texture", 'cleaning-services'),
							"desc" => wp_kses( __("Predefined texture style from 1 to 11. 0 - without texture.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
							"min" => "0",
							"max" => "11",
							"step" => "1",
							"value" => "0",
							"type" => "spinner"
						),
						"width" => cleaning_services_shortcodes_width(),
						"height" => cleaning_services_shortcodes_height(),
						"top" => $CLEANING_SERVICES_GLOBALS['sc_params']['top'],
						"bottom" => $CLEANING_SERVICES_GLOBALS['sc_params']['bottom'],
						"left" => $CLEANING_SERVICES_GLOBALS['sc_params']['left'],
						"right" => $CLEANING_SERVICES_GLOBALS['sc_params']['right'],
						"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
						"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
						"animation" => $CLEANING_SERVICES_GLOBALS['sc_params']['animation'],
						"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
					),
					"children" => array(
						"name" => "trx_testimonials_item",
						"title" => esc_html__("Item", 'cleaning-services'),
						"desc" => wp_kses( __("Testimonials item (custom parameters)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"container" => true,
						"params" => array(
							"author" => array(
								"title" => esc_html__("Author", 'cleaning-services'),
								"desc" => wp_kses( __("Name of the testimonmials author", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"link" => array(
								"title" => esc_html__("Link", 'cleaning-services'),
								"desc" => wp_kses( __("Link URL to the testimonmials author page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"email" => array(
								"title" => esc_html__("E-mail", 'cleaning-services'),
								"desc" => wp_kses( __("E-mail of the testimonmials author (to get gravatar)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "text"
							),
							"photo" => array(
								"title" => esc_html__("Photo", 'cleaning-services'),
								"desc" => wp_kses( __("Select or upload photo of testimonmials author or write URL of photo from other site", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"value" => "",
								"type" => "media"
							),
							"_content_" => array(
								"title" => esc_html__("Testimonials text", 'cleaning-services'),
								"desc" => wp_kses( __("Current testimonials text", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
								"divider" => true,
								"rows" => 4,
								"value" => "",
								"type" => "textarea"
							),
							"id" => $CLEANING_SERVICES_GLOBALS['sc_params']['id'],
							"class" => $CLEANING_SERVICES_GLOBALS['sc_params']['class'],
							"css" => $CLEANING_SERVICES_GLOBALS['sc_params']['css']
						)
					)
				)

			));
		}
	}
}


// Add [trx_testimonials] and [trx_testimonials_item] in the VC shortcodes list
if (!function_exists('cleaning_services_testimonials_reg_shortcodes_vc')) {
	//Handler of add_filter('cleaning_services_action_shortcodes_list_vc',	'cleaning_services_testimonials_reg_shortcodes_vc');
	function cleaning_services_testimonials_reg_shortcodes_vc() {
		global $CLEANING_SERVICES_GLOBALS;

		$testimonials_groups = cleaning_services_get_list_terms(false, 'testimonial_group');
		$testimonials_styles = cleaning_services_get_list_templates('testimonials');
		$controls			 = cleaning_services_get_list_slider_controls();
			
		// Testimonials			
		vc_map( array(
				"base" => "trx_testimonials",
				"name" => esc_html__("Testimonials", 'cleaning-services'),
				"description" => wp_kses( __("Insert testimonials slider", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"category" => esc_html__('Content', 'cleaning-services'),
				'icon' => 'icon_trx_testimonials',
				"class" => "trx_sc_columns trx_sc_testimonials",
				"content_element" => true,
				"is_container" => true,
				"show_settings_on_create" => true,
				"as_parent" => array('only' => 'trx_testimonials_item'),
				"params" => array(
					array(
						"param_name" => "style",
						"heading" => esc_html__("Testimonials style", 'cleaning-services'),
						"description" => wp_kses( __("Select style to display testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"admin_label" => true,
						"value" => array_flip($testimonials_styles),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slider",
						"heading" => esc_html__("Slider", 'cleaning-services'),
						"description" => wp_kses( __("Use slider to show testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						"class" => "",
						"std" => "yes",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['yes_no']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "controls",
						"heading" => esc_html__("Controls", 'cleaning-services'),
						"description" => wp_kses( __("Slider controls style and position", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"std" => "no",
						"value" => array_flip($controls),
						"type" => "dropdown"
					),
					array(
						"param_name" => "slides_space",
						"heading" => esc_html__("Space between slides", 'cleaning-services'),
						"description" => wp_kses( __("Size of space (in px) between slides", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "interval",
						"heading" => esc_html__("Slides change interval", 'cleaning-services'),
						"description" => wp_kses( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => "7000",
						"type" => "textfield"
					),
					array(
						"param_name" => "autoheight",
						"heading" => esc_html__("Autoheight", 'cleaning-services'),
						"description" => wp_kses( __("Change whole slider's height (make it equal current slide's height)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Slider', 'cleaning-services'),
						'dependency' => array(
							'element' => 'slider',
							'value' => 'yes'
						),
						"class" => "",
						"value" => array("Autoheight" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "align",
						"heading" => esc_html__("Alignment", 'cleaning-services'),
						"description" => wp_kses( __("Alignment of the testimonials block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['align']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "custom",
						"heading" => esc_html__("Custom", 'cleaning-services'),
						"description" => wp_kses( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => array("Custom slides" => "yes" ),
						"type" => "checkbox"
					),
					array(
						"param_name" => "title",
						"heading" => esc_html__("Title", 'cleaning-services'),
						"description" => wp_kses( __("Title for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "subtitle",
						"heading" => esc_html__("Subtitle", 'cleaning-services'),
						"description" => wp_kses( __("Subtitle for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "description",
						"heading" => esc_html__("Description", 'cleaning-services'),
						"description" => wp_kses( __("Description for the block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Captions', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textarea"
					),
					array(
						"param_name" => "cat",
						"heading" => esc_html__("Categories", 'cleaning-services'),
						"description" => wp_kses( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip(cleaning_services_array_merge(array(0 => esc_html__('- Select category -', 'cleaning-services')), $testimonials_groups)),
						"type" => "dropdown"
					),
					array(
						"param_name" => "columns",
						"heading" => esc_html__("Columns", 'cleaning-services'),
						"description" => wp_kses( __("How many columns use to show testimonials", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						"admin_label" => true,
						"class" => "",
						"value" => "1",
						"type" => "textfield"
					),
					array(
						"param_name" => "count",
						"heading" => esc_html__("Number of posts", 'cleaning-services'),
						"description" => wp_kses( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "3",
						"type" => "textfield"
					),
					array(
						"param_name" => "offset",
						"heading" => esc_html__("Offset before select posts", 'cleaning-services'),
						"description" => wp_kses( __("Skip posts before select next part.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "0",
						"type" => "textfield"
					),
					array(
						"param_name" => "orderby",
						"heading" => esc_html__("Post sorting", 'cleaning-services'),
						"description" => wp_kses( __("Select desired posts sorting method", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['sorting']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "order",
						"heading" => esc_html__("Post order", 'cleaning-services'),
						"description" => wp_kses( __("Select desired posts order", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['ordering']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "ids",
						"heading" => esc_html__("Post IDs list", 'cleaning-services'),
						"description" => wp_kses( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Query', 'cleaning-services'),
						'dependency' => array(
							'element' => 'custom',
							'is_empty' => true
						),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "scheme",
						"heading" => esc_html__("Color scheme", 'cleaning-services'),
						"description" => wp_kses( __("Select color scheme for this block", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'cleaning-services'),
						"class" => "",
						"value" => array_flip($CLEANING_SERVICES_GLOBALS['sc_params']['schemes']),
						"type" => "dropdown"
					),
					array(
						"param_name" => "bg_color",
						"heading" => esc_html__("Background color", 'cleaning-services'),
						"description" => wp_kses( __("Any background color for this section", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "colorpicker"
					),
					array(
						"param_name" => "bg_image",
						"heading" => esc_html__("Background image URL", 'cleaning-services'),
						"description" => wp_kses( __("Select background image from library for this section", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					array(
						"param_name" => "bg_overlay",
						"heading" => esc_html__("Overlay", 'cleaning-services'),
						"description" => wp_kses( __("Overlay color opacity (from 0.0 to 1.0)", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "bg_texture",
						"heading" => esc_html__("Texture", 'cleaning-services'),
						"description" => wp_kses( __("Texture style from 1 to 11. Empty or 0 - without texture.", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"group" => esc_html__('Colors and Images', 'cleaning-services'),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					cleaning_services_vc_width(),
					cleaning_services_vc_height(),
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_top'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_bottom'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_left'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['margin_right'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['animation'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnsView'
		) );
			
			
		vc_map( array(
				"base" => "trx_testimonials_item",
				"name" => esc_html__("Testimonial", 'cleaning-services'),
				"description" => wp_kses( __("Single testimonials item", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
				"show_settings_on_create" => true,
				"class" => "trx_sc_collection trx_sc_column_item trx_sc_testimonials_item",
				"content_element" => true,
				"is_container" => true,
				'icon' => 'icon_trx_testimonials_item',
				"as_child" => array('only' => 'trx_testimonials'),
				"as_parent" => array('except' => 'trx_testimonials'),
				"params" => array(
					array(
						"param_name" => "author",
						"heading" => esc_html__("Author", 'cleaning-services'),
						"description" => wp_kses( __("Name of the testimonmials author", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"admin_label" => true,
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "link",
						"heading" => esc_html__("Link", 'cleaning-services'),
						"description" => wp_kses( __("Link URL to the testimonmials author page", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "email",
						"heading" => esc_html__("E-mail", 'cleaning-services'),
						"description" => wp_kses( __("E-mail of the testimonmials author", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "textfield"
					),
					array(
						"param_name" => "photo",
						"heading" => esc_html__("Photo", 'cleaning-services'),
						"description" => wp_kses( __("Select or upload photo of testimonmials author or write URL of photo from other site", 'cleaning-services'), $CLEANING_SERVICES_GLOBALS['allowed_tags'] ),
						"class" => "",
						"value" => "",
						"type" => "attach_image"
					),
					$CLEANING_SERVICES_GLOBALS['vc_params']['id'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['class'],
					$CLEANING_SERVICES_GLOBALS['vc_params']['css']
				),
				'js_view' => 'VcTrxColumnItemView'
		) );
			
		class WPBakeryShortCode_Trx_Testimonials extends CLEANING_SERVICES_VC_ShortCodeColumns {}
		class WPBakeryShortCode_Trx_Testimonials_Item extends CLEANING_SERVICES_VC_ShortCodeCollection {}
		
	}
}
?>