<?php
/**
 * Skin file for the theme.
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('cleaning_services_action_skin_theme_setup')) {
	add_action( 'cleaning_services_action_init_theme', 'cleaning_services_action_skin_theme_setup', 1 );
	function cleaning_services_action_skin_theme_setup() {

		// Add skin fonts in the used fonts list
		add_filter('cleaning_services_filter_used_fonts',			'cleaning_services_filter_skin_used_fonts');
		// Add skin fonts (from Google fonts) in the main fonts list (if not present).
		add_filter('cleaning_services_filter_list_fonts',			'cleaning_services_filter_skin_list_fonts');

		// Add skin stylesheets
		add_action('cleaning_services_action_add_styles',			'cleaning_services_action_skin_add_styles');
		// Add skin inline styles
		add_filter('cleaning_services_filter_add_styles_inline',		'cleaning_services_filter_skin_add_styles_inline');
		// Add skin responsive styles
		add_action('cleaning_services_action_add_responsive',		'cleaning_services_action_skin_add_responsive');
		// Add skin responsive inline styles
		add_filter('cleaning_services_filter_add_responsive_inline',	'cleaning_services_filter_skin_add_responsive_inline');

		// Add skin scripts
		add_action('cleaning_services_action_add_scripts',			'cleaning_services_action_skin_add_scripts');
		// Add skin scripts inline
		add_filter('cleaning_services_action_add_scripts_inline',	'cleaning_services_action_skin_add_scripts_inline');

		// Add skin less files into list for compilation
		add_filter('cleaning_services_filter_compile_less',			'cleaning_services_filter_skin_compile_less');

		// Add color schemes
		cleaning_services_add_color_scheme('original', array(

			'title'					=> esc_html__('Original', 'cleaning-services'),

			// Accent colors
			'accent1'				=> '#00b9c1',       //
			'accent1_hover'			=> '#409fa4',       //
			'accent2'				=> '#f5928b',       //
			'accent2_hover'			=> '#dc6961',       //
			'accent3'				=> '#a7e3c1',       //
			'accent3_hover'			=> '#7eb696',       //
			
			// Headers, text and links colors
			'text'					=> '#808080',       //text
			'text_light'			=> '#808080',       //menu
			'text_dark'				=> '#444349',       //headers
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#d5d75c',       //serv icon
			'inverse_dark'			=> '#a3c56f',       //serv icon
			'inverse_link'			=> '#f2a934',       //soc3
			'inverse_hover'			=> '#6385b3',       //soc2
			
			// Whole block border and background
			'bd_color'				=> '#e4e7e8',
			'bg_color'				=> '#ffffff',
			'bg_image'				=>  cleaning_services_get_file_url('images/bg_green_stripes.png'),
			'bg_image_position'		=> 'left top',
			'bg_image_repeat'		=> 'repeat',
			'bg_image_attachment'	=> 'scroll',
			'bg_image2'				=> '',
			'bg_image2_position'	=> 'left top',
			'bg_image2_repeat'		=> 'repeat',
			'bg_image2_attachment'	=> 'scroll',
		
			// Alternative blocks (submenu items, form's fields, etc.)
			'alter_text'			=> '#69c4c7',       //button
			'alter_light'			=> '#acb4b6',
			'alter_dark'			=> '#232a34',
			'alter_link'			=> '#20c7ca',
			'alter_hover'			=> '#189799',
			'alter_bd_color'		=> '#d0d0d0',
			'alter_bd_hover'		=> '#bebebe',   //socials in team
			'alter_bg_color'		=> '#f5f5f5',   //in many block
			'alter_bg_hover'		=> '#f0f0f0',
			'alter_bg_image'			=> cleaning_services_get_file_url('images/bg_cyan_stripes.png'),
			'alter_bg_image_position'	=> 'left top',
			'alter_bg_image_repeat'		=> 'repeat',
			'alter_bg_image_attachment'	=> 'scroll',
			)
		);

//		// Add color schemes
		cleaning_services_add_color_scheme('light', array(

			'title'					=> esc_html__('Light', 'cleaning-services'),

                // Accent colors
                'accent1'				=> '#ff7f66',       //
                'accent1_hover'			=> '#d45439',       //
                'accent2'				=> '#ff7f66',       //
                'accent2_hover'			=> '#dc6961',       //
                'accent3'				=> '#a7e3c1',       //
                'accent3_hover'			=> '#7eb696',       //

                // Headers, text and links colors
                'text'					=> '#808080',       //text
                'text_light'			=> '#808080',       //menu
                'text_dark'				=> '#444349',       //headers
                'inverse_text'			=> '#ffffff',
                'inverse_light'			=> '#d5d75c',       //serv icon
                'inverse_dark'			=> '#a3c56f',       //serv icon
                'inverse_link'			=> '#f2a934',       //soc3
                'inverse_hover'			=> '#6385b3',       //soc2

                // Whole block border and background
                'bd_color'				=> '#e4e7e8',
                'bg_color'				=> '#ffffff',
                'bg_image'				=>  cleaning_services_get_file_url('images/bg_red_stripes.jpg'),
                'bg_image_position'		=> 'left top',
                'bg_image_repeat'		=> 'repeat',
                'bg_image_attachment'	=> 'scroll',
                'bg_image2'				=> '',
                'bg_image2_position'	=> 'left top',
                'bg_image2_repeat'		=> 'repeat',
                'bg_image2_attachment'	=> 'scroll',

                // Alternative blocks (submenu items, form's fields, etc.)
                'alter_text'			=> '#ff7f66',       //button
                'alter_light'			=> '#acb4b6',
                'alter_dark'			=> '#232a34',
                'alter_link'			=> '#20c7ca',
                'alter_hover'			=> '#189799',
                'alter_bd_color'		=> '#d0d0d0',
                'alter_bd_hover'		=> '#bebebe',   //socials in team
                'alter_bg_color'		=> '#f5f5f5',   //in many block
                'alter_bg_hover'		=> '#f0f0f0',
                'alter_bg_image'			=> cleaning_services_get_file_url('images/bg_red_stripes.jpg'),
                'alter_bg_image_position'	=> 'left top',
                'alter_bg_image_repeat'		=> 'repeat',
                'alter_bg_image_attachment'	=> 'scroll',
			)
		);
//
//		// Add color schemes
		cleaning_services_add_color_scheme('dark', array(

			'title'					=> esc_html__('Dark', 'cleaning-services'),

                // Accent colors
                'accent1'				=> '#ccbaa6',       //
                'accent1_hover'			=> '#b7ab9b',       //
                'accent2'				=> '#ccbaa6',       //
                'accent2_hover'			=> '#baaea0',       //
                'accent3'				=> '#a7e3c1',       //
                'accent3_hover'			=> '#7eb696',       //

                // Headers, text and links colors
                'text'					=> '#808080',       //text
                'text_light'			=> '#808080',       //menu
                'text_dark'				=> '#444349',       //headers
                'inverse_text'			=> '#ffffff',
                'inverse_light'			=> '#d5d75c',       //serv icon
                'inverse_dark'			=> '#a3c56f',       //serv icon
                'inverse_link'			=> '#f2a934',       //soc3
                'inverse_hover'			=> '#6385b3',       //soc2

                // Whole block border and background
                'bd_color'				=> '#e4e7e8',
                'bg_color'				=> '#ffffff',
                'bg_image'				=>  cleaning_services_get_file_url('images/bg_brown_stripes.jpg'),
                'bg_image_position'		=> 'left top',
                'bg_image_repeat'		=> 'repeat',
                'bg_image_attachment'	=> 'scroll',
                'bg_image2'				=> '',
                'bg_image2_position'	=> 'left top',
                'bg_image2_repeat'		=> 'repeat',
                'bg_image2_attachment'	=> 'scroll',

                // Alternative blocks (submenu items, form's fields, etc.)
                'alter_text'			=> '#ccbaa6',       //button
                'alter_light'			=> '#acb4b6',
                'alter_dark'			=> '#232a34',
                'alter_link'			=> '#20c7ca',
                'alter_hover'			=> '#189799',
                'alter_bd_color'		=> '#d0d0d0',
                'alter_bd_hover'		=> '#bebebe',   //socials in team
                'alter_bg_color'		=> '#f5f5f5',   //in many block
                'alter_bg_hover'		=> '#f0f0f0',
                'alter_bg_image'			=> cleaning_services_get_file_url('images/bg_brown_stripes.jpg'),
                'alter_bg_image_position'	=> 'left top',
                'alter_bg_image_repeat'		=> 'repeat',
                'alter_bg_image_attachment'	=> 'scroll',
			)
		);

        //		// Add color schemes
        cleaning_services_add_color_scheme('purple', array(

                'title'					=> esc_html__('Purlpe', 'cleaning-services'),

                // Accent colors
                'accent1'				=> '#f774a8',       //
                'accent1_hover'			=> '#d5618e',       //
                'accent2'				=> '#f774a8',       //
                'accent2_hover'			=> '#d5618e',       //
                'accent3'				=> '#a7e3c1',       //
                'accent3_hover'			=> '#7eb696',       //

                // Headers, text and links colors
                'text'					=> '#808080',       //text
                'text_light'			=> '#808080',       //menu
                'text_dark'				=> '#444349',       //headers
                'inverse_text'			=> '#ffffff',
                'inverse_light'			=> '#d5d75c',       //serv icon
                'inverse_dark'			=> '#a3c56f',       //serv icon
                'inverse_link'			=> '#f2a934',       //soc3
                'inverse_hover'			=> '#6385b3',       //soc2

                // Whole block border and background
                'bd_color'				=> '#e4e7e8',
                'bg_color'				=> '#ffffff',
                'bg_image'				=>  cleaning_services_get_file_url('images/bg_purple_stripes.jpg'),
                'bg_image_position'		=> 'left top',
                'bg_image_repeat'		=> 'repeat',
                'bg_image_attachment'	=> 'scroll',
                'bg_image2'				=> '',
                'bg_image2_position'	=> 'left top',
                'bg_image2_repeat'		=> 'repeat',
                'bg_image2_attachment'	=> 'scroll',

                // Alternative blocks (submenu items, form's fields, etc.)
                'alter_text'			=> '#f774a8',       //button
                'alter_light'			=> '#acb4b6',
                'alter_dark'			=> '#232a34',
                'alter_link'			=> '#20c7ca',
                'alter_hover'			=> '#189799',
                'alter_bd_color'		=> '#d0d0d0',
                'alter_bd_hover'		=> '#bebebe',   //socials in team
                'alter_bg_color'		=> '#f5f5f5',   //in many block
                'alter_bg_hover'		=> '#f0f0f0',
                'alter_bg_image'			=> cleaning_services_get_file_url('images/bg_purple_stripes.jpg'),
                'alter_bg_image_position'	=> 'left top',
                'alter_bg_image_repeat'		=> 'repeat',
                'alter_bg_image_attachment'	=> 'scroll',
            )
        );

		// Add Custom fonts
		cleaning_services_add_custom_font('h1', array(
			'title'			=> esc_html__('Heading 1', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> 'Pacifico',
			'font-size' 	=> '3.5em',
			'font-weight'	=> '400',
			'font-style'	=> '',
			'line-height'	=> '1.75em',
			'margin-top'	=> '0.5em',
			'margin-bottom'	=> '0.35em'
			)
		);
		cleaning_services_add_custom_font('h2', array(
			'title'			=> esc_html__('Heading 2', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '3em',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.146em',
			'margin-top'	=> '1.07em',
			'margin-bottom'	=> '0.35em'
			)
		);
		cleaning_services_add_custom_font('h3', array(
			'title'			=> esc_html__('Heading 3', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '1.5em',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.5em',
			'margin-top'	=> '2.15em',
			'margin-bottom'	=> '0.8em'
			)
		);
		cleaning_services_add_custom_font('h4', array(
			'title'			=> esc_html__('Heading 4', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '1em',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '3.55em',
			'margin-bottom'	=> '1.55em'
			)
		);
		cleaning_services_add_custom_font('h5', array(
			'title'			=> esc_html__('Heading 5', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '0.875em',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '4.1em',
			'margin-bottom'	=> '1.8em'
			)
		);
		cleaning_services_add_custom_font('h6', array(
			'title'			=> esc_html__('Heading 6', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '0.875em',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '4.1em',
			'margin-bottom'	=> '1.8em'
			)
		);
		cleaning_services_add_custom_font('p', array(
			'title'			=> esc_html__('Text', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> 'Hind',
			'font-size' 	=> '16px',
			'font-weight'	=> '400',
			'font-style'	=> '',
			'line-height'	=> '1.75em',
			'margin-top'	=> '',
			'margin-bottom'	=> '1em'
			)
		);
		cleaning_services_add_custom_font('link', array(
			'title'			=> esc_html__('Links', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> ''
			)
		);
		cleaning_services_add_custom_font('info', array(
			'title'			=> esc_html__('Post info', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '13px',
			'font-weight'	=> '600',
			'font-style'	=> '',
			'line-height'	=> '1.3em',
			'margin-top'	=> '',
			'margin-bottom'	=> '1.5em'
			)
		);
		cleaning_services_add_custom_font('menu', array(
			'title'			=> esc_html__('Main menu items', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '0.9375em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '1.334em',
			'margin-top'	=> '',
			'margin-bottom'	=> ''
			)
		);
		cleaning_services_add_custom_font('submenu', array(
			'title'			=> esc_html__('Dropdown menu items', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
            'font-size' 	=> '15px',
            'font-weight'	=> '700',
            'font-style'	=> '',
            'line-height'	=> '1.334em',
			'margin-top'	=> '',
			'margin-bottom'	=> ''
			)
		);
		cleaning_services_add_custom_font('logo', array(
			'title'			=> esc_html__('Logo', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '2.8571em',
			'font-weight'	=> '700',
			'font-style'	=> '',
			'line-height'	=> '0.75em',
			'margin-top'	=> '2.2em',
			'margin-bottom'	=> '2em'
			)
		);
		cleaning_services_add_custom_font('button', array(
			'title'			=> esc_html__('Buttons', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> '',
			'line-height'	=> '1.3em'
			)
		);
		cleaning_services_add_custom_font('input', array(
			'title'			=> esc_html__('Input fields', 'cleaning-services'),
			'description'	=> '',
			'font-family'	=> '',
			'font-size' 	=> '',
			'font-weight'	=> '',
			'font-style'	=> '',
			'line-height'	=> '1.7em'
			)
		);

	}
}





//------------------------------------------------------------------------------
// Skin's fonts
//------------------------------------------------------------------------------

// Add skin fonts in the used fonts list
if (!function_exists('cleaning_services_filter_skin_used_fonts')) {
	//Handler of add_filter('cleaning_services_filter_used_fonts', 'cleaning_services_filter_skin_used_fonts');
	function cleaning_services_filter_skin_used_fonts($theme_fonts) {
        $theme_fonts['Hind'] = 1;
        $theme_fonts['Pacifico'] = 1;
		return $theme_fonts;
	}
}

// Add skin fonts (from Google fonts) in the main fonts list (if not present).
// To use custom font-face you not need add it into list in this function
// How to install custom @font-face fonts into the theme?
// All @font-face fonts are located in "theme_name/css/font-face/" folder in the separate subfolders for the each font. Subfolder name is a font-family name!
// Place full set of the font files (for each font style and weight) and css-file named stylesheet.css in the each subfolder.
// Create your @font-face kit by using Fontsquirrel @font-face Generator (http://www.fontsquirrel.com/fontface/generator)
// and then extract the font kit (with folder in the kit) into the "theme_name/css/font-face" folder to install
if (!function_exists('cleaning_services_filter_skin_list_fonts')) {
	//Handler of add_filter('cleaning_services_filter_list_fonts', 'cleaning_services_filter_skin_list_fonts');
	function cleaning_services_filter_skin_list_fonts($list) {

        if (!isset($list['Hind']))
        $list['Hind'] = array(
            'family'=>'sans-serif',
            'link'=>'Hind:400,300,500,600,700'
        );

		if (!isset($list['Pacifico']))
        $list['Pacifico'] = array(
            'family'=>'cursive',
            'link'=>'Pacifico'
        );

		return $list;
	}
}



//------------------------------------------------------------------------------
// Skin's stylesheets
//------------------------------------------------------------------------------
// Add skin stylesheets
if (!function_exists('cleaning_services_action_skin_add_styles')) {
	//Handler of add_action('cleaning_services_action_add_styles', 'cleaning_services_action_skin_add_styles');
	function cleaning_services_action_skin_add_styles() {
		// Add stylesheet files
		wp_enqueue_style( 'cleaning-services-skin-style', cleaning_services_get_file_url('skin.css'), array(), null );
		if (file_exists(cleaning_services_get_file_dir('skin.customizer.css')))
			wp_enqueue_style( 'cleaning-services-skin-customizer-style', cleaning_services_get_file_url('skin.customizer.css'), array(), null );
	}
}

// Add skin inline styles
if (!function_exists('cleaning_services_filter_skin_add_styles_inline')) {
	//Handler of add_filter('cleaning_services_filter_add_styles_inline', 'cleaning_services_filter_skin_add_styles_inline');
	function cleaning_services_filter_skin_add_styles_inline($custom_style) {
		// Todo: add skin specific styles in the $custom_style to override
		return $custom_style;	
	}
}

// Add skin responsive styles
if (!function_exists('cleaning_services_action_skin_add_responsive')) {
	//Handler of add_action('cleaning_services_action_add_responsive', 'cleaning_services_action_skin_add_responsive');
	function cleaning_services_action_skin_add_responsive() {
		$suffix = cleaning_services_param_is_off(cleaning_services_get_custom_option('show_sidebar_outer')) ? '' : '-outer';
		if (file_exists(cleaning_services_get_file_dir('skin.responsive'.($suffix).'.css'))) 
			wp_enqueue_style( 'cleaning-services-skin-responsive-style', cleaning_services_get_file_url('skin.responsive'.($suffix).'.css'), array(), null );
	}
}

// Add skin responsive inline styles
if (!function_exists('cleaning_services_filter_skin_add_responsive_inline')) {
	//Handler of add_filter('cleaning_services_filter_add_responsive_inline', 'cleaning_services_filter_skin_add_responsive_inline');
	function cleaning_services_filter_skin_add_responsive_inline($custom_style) {
		return $custom_style;	
	}
}

// Add skin.less into list files for compilation
if (!function_exists('cleaning_services_filter_skin_compile_less')) {
	//Handler of add_filter('cleaning_services_filter_compile_less', 'cleaning_services_filter_skin_compile_less');
	function cleaning_services_filter_skin_compile_less($files) {
		if (file_exists(cleaning_services_get_file_dir('skin.less'))) {
		 	$files[] = cleaning_services_get_file_dir('skin.less');
		}
		return $files;	
	}
}



//------------------------------------------------------------------------------
// Skin's scripts
//------------------------------------------------------------------------------

// Add skin scripts
if (!function_exists('cleaning_services_action_skin_add_scripts')) {
	//Handler of add_action('cleaning_services_action_add_scripts', 'cleaning_services_action_skin_add_scripts');
	function cleaning_services_action_skin_add_scripts() {
		if (file_exists(cleaning_services_get_file_dir('skin.js')))
			wp_enqueue_script( 'cleaning-services-skin-script', cleaning_services_get_file_url('skin.js'), array(), null );
		if (cleaning_services_get_theme_option('show_theme_customizer') == 'yes' && file_exists(cleaning_services_get_file_dir('skin.customizer.js')))
			wp_enqueue_script( 'cleaning-services-skin-customizer-script', cleaning_services_get_file_url('skin.customizer.js'), array(), null );
        if (file_exists(cleaning_services_get_file_dir('add_title_to_link.js')))
            wp_enqueue_script( 'cleaning-services-skin-link-script', cleaning_services_get_file_url('add_title_to_link.js'), array(), null );
	}
}

// Add skin scripts inline
if (!function_exists('cleaning_services_action_skin_add_scripts_inline')) {
	//Handler of add_action('cleaning_services_action_add_scripts_inline', 'cleaning_services_action_skin_add_scripts_inline');
	function cleaning_services_action_skin_add_scripts_inline($vars=array()) {
        // Todo: add skin specific script's vars
        return $vars;
	}
}
?>