<?php

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'cleaning_services_template_header_8_theme_setup' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_template_header_8_theme_setup', 1 );
	function cleaning_services_template_header_8_theme_setup() {
		cleaning_services_add_template(array(
			'layout' => 'header_8',
			'mode'   => 'header',
			'title'  => esc_html__('Header 8', 'cleaning-services'),
			'icon'   => cleaning_services_get_file_url('templates/headers/images/8.jpg')
			));
	}
}

// Template output
if ( !function_exists( 'cleaning_services_template_header_8_output' ) ) {
	function cleaning_services_template_header_8_output($post_options, $post_data) {
		global $CLEANING_SERVICES_GLOBALS;

		// WP custom header
		$header_css = '';
		if ($post_options['position'] != 'over') {
			$header_image = get_header_image();
			$header_css = $header_image!='' 
				? ' style="background: url('.esc_url($header_image).') repeat center top"' 
				: '';
		}
		?>

		<div class="top_panel_fixed_wrap"></div>

		<header class="top_panel_wrap top_panel_style_8 scheme_<?php echo esc_attr($post_options['scheme']); ?>">
			
			<div class="top_panel_wrap_inner top_panel_inner_style_8 top_panel_position_<?php echo esc_attr(cleaning_services_get_custom_option('top_panel_position')); ?>">

                <?php if (cleaning_services_get_custom_option('show_top_panel_top')=='yes') { ?>
                    <div class="top_panel_top">
                        <div class="content_wrap clearfix">
                            <?php
                            $top_panel_top_components = array('phone','open_hours', 'login', 'currency', 'bookmarks', 'socials','button1', 'button2');
                            require_once cleaning_services_get_file_dir('templates/headers/_parts/top-panel-top.php');
                            ?>
                        </div>
                    </div>
                <?php } ?>

				<div class="top_panel_middle" <?php cleaning_services_show_layout($header_css); ?>>
					<div class="content_wrap">
                        <div class="columns_wrap columns_fluid"><div
                                class="column-1_3 contact_logo">
                                <?php cleaning_services_show_logo(true, true); ?>
                            </div><div  class="column-2_3 menu_main_wrap">
                                <div class="menu_pushy_wrap clearfix">
                                    <a href="#" class="menu_pushy_button icon-menu"></a>
                                </div>
                            </div>
                        </div>
					</div>
				</div>

			</div>

		</header>

		<nav class="menu_pushy_nav_area pushy pushy-left scheme_<?php echo esc_attr(cleaning_services_get_custom_option('pushy_panel_scheme')); ?>">
			<div class="pushy_inner">
	
				<a href="#" class="close-pushy"></a>
	
				<?php 
				cleaning_services_show_logo(false, false, false, true);
	
				if (empty($CLEANING_SERVICES_GLOBALS['menu_main'])) $CLEANING_SERVICES_GLOBALS['menu_main'] = cleaning_services_get_nav_menu('menu_main');
				if (empty($CLEANING_SERVICES_GLOBALS['menu_main'])) $CLEANING_SERVICES_GLOBALS['menu_main'] = cleaning_services_get_nav_menu();
				echo str_replace('menu_main', 'menu_pushy', $CLEANING_SERVICES_GLOBALS['menu_main']);
	
				$address_1 = cleaning_services_get_theme_option('contact_address_1');
				$address_2 = cleaning_services_get_theme_option('contact_address_2');
				$phone = cleaning_services_get_theme_option('contact_phone');
				$fax = cleaning_services_get_theme_option('contact_fax');
				if (!empty($address_1) || !empty($address_2) || !empty($phone) || !empty($fax)) {
					?>
					<div class="contact_info">
						<?php if (!empty($address_1) || !empty($address_2)) { ?>
							<address class="contact_address">
								<?php cleaning_services_show_layout(($address_1) . (!empty($address_1) ? ', ' : '') . ($address_2)); ?>
							</address>
						<?php } ?>
						<?php if (!empty($phone) || !empty($fax)) { ?>
							<address class="contact_phones">
								<?php echo esc_html__('Call:', 'cleaning-services') . ' ' . ($phone) . (!empty($phone) ? ', ' : '') . ($fax); ?>
							</address>
						<?php } ?>
					</div>
					<?php
				}
	
				if (cleaning_services_get_custom_option('show_socials')=='yes' && function_exists('cleaning_services_sc_socials')) {
					?>
					<div class="contact_socials">
						<?php cleaning_services_show_layout(cleaning_services_sc_socials(array('size'=>'tiny', 'shape'=>'round'))); ?>
					</div>
					<?php
				}
				?>

			</div>
        </nav>

        <!-- Site Overlay -->
        <div class="site-overlay"></div>
		<?php
	}
}
?>