<?php

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'cleaning_services_template_single_team_theme_setup' ) ) {
	add_action( 'cleaning_services_action_before_init_theme', 'cleaning_services_template_single_team_theme_setup', 1 );
	function cleaning_services_template_single_team_theme_setup() {
		cleaning_services_add_template(array(
			'layout' => 'single-team',
			'mode'   => 'team',
			'need_content' => true,
			'need_terms' => true,
			'title'  => esc_html__('Single Team member', 'cleaning-services'),
			'thumb_title'  => esc_html__('Large image (crop)', 'cleaning-services'),
			'w'		 => 870,
			'h'		 => 490
		));
	}
}

// Template output
if ( !function_exists( 'cleaning_services_template_single_team_output' ) ) {
	function cleaning_services_template_single_team_output($post_options, $post_data) {
		$post_data['post_views']++;
		$show_title = cleaning_services_get_custom_option('show_post_title')=='yes';
		$title_tag = cleaning_services_get_custom_option('show_page_title')=='yes' ? 'h3' : 'h1';

		cleaning_services_open_wrapper('<article class="' 
				. join(' ', get_post_class('itemscope'
					. ' post_item post_item_single_team'
					. ' post_featured_' . esc_attr($post_options['post_class'])
					. ' post_format_' . esc_attr($post_data['post_format'])))
				. '"'
				. ' itemscope itemtype="http://schema.org/Article'
				. '">');

		if ($show_title && $post_options['location'] == 'center' && cleaning_services_get_custom_option('show_page_title')=='no') {
			?>
			<<?php echo esc_html($title_tag); ?> itemprop="headline" class="post_title entry-title"><span class="post_icon <?php echo esc_attr($post_data['post_icon']); ?>"></span><?php cleaning_services_show_layout($post_data['post_title']); ?></<?php echo esc_html($title_tag); ?>>
			<?php 
		}

		if (!$post_data['post_protected'] && (
			!empty($post_options['dedicated']) ||
			(cleaning_services_get_custom_option('show_featured_image')=='yes' && $post_data['post_thumb'])
		)) {
			?>
			<section class="post_featured">
			<?php
			if (!empty($post_options['dedicated'])) {
				cleaning_services_show_layout($post_options['dedicated']);
			} else {
				cleaning_services_enqueue_popup();
				?>
				<div class="post_thumb" data-image="<?php echo esc_url($post_data['post_attachment']); ?>" data-title="<?php echo esc_attr($post_data['post_title']); ?>">
					<a class="hover_icon hover_icon_view" href="<?php echo esc_url($post_data['post_attachment']); ?>" title="<?php echo esc_attr($post_data['post_title']); ?>"><?php cleaning_services_show_layout($post_data['post_thumb']); ?></a>
				</div>
				<?php 
			}
			?>
			</section>
			<?php
		}
			
		
		if ($show_title && $post_options['location'] != 'center' && cleaning_services_get_custom_option('show_page_title')=='no') {
			?>
			<<?php echo esc_html($title_tag); ?> itemprop="name" class="post_title entry-title"><span class="post_icon <?php echo esc_attr($post_data['post_icon']); ?>"></span><?php cleaning_services_show_layout($post_data['post_title']); ?></<?php echo esc_html($title_tag); ?>>
			<?php 
		}

		cleaning_services_open_wrapper('<section class="post_content'.(!$post_data['post_protected'] && $post_data['post_edit_enable'] ? ' '.esc_attr('post_content_editor_present') : '').'" itemprop="articleBody">');
			
		// Post content
		if ($post_data['post_protected']) { 
			cleaning_services_show_layout($post_data['post_excerpt']);
			echo get_the_password_form(); 
		} else {
			cleaning_services_show_layout(cleaning_services_gap_wrapper(cleaning_services_reviews_wrapper($post_data['post_content'])));
			require cleaning_services_get_file_dir('templates/_parts/single-pagination.php');
			if ( cleaning_services_get_custom_option('show_post_tags') == 'yes' && !empty($post_data['post_terms'][$post_data['post_taxonomy_tags']]->terms_links)) {
				?>
				<div class="post_info post_info_bottom">
					<span class="post_info_item post_info_tags"><?php esc_html_e('Tags:', 'cleaning-services'); ?> <?php echo join(', ', $post_data['post_terms'][$post_data['post_taxonomy_tags']]->terms_links); ?></span>
				</div>
				<?php 
			}
		} 
			
		if (!$post_data['post_protected'] && $post_data['post_edit_enable']) {
			require cleaning_services_get_file_dir('templates/_parts/editor-area.php');
		}

		cleaning_services_close_wrapper();	// .post_content
			
		if (!$post_data['post_protected']) {
			require cleaning_services_get_file_dir('templates/_parts/share.php');
		}

		cleaning_services_close_wrapper();	// .post_item

		if (!$post_data['post_protected']) {
			require cleaning_services_get_file_dir('templates/_parts/related-posts.php');
			require cleaning_services_get_file_dir('templates/_parts/comments.php');
		}
	}
}
?>